@@ -18,15 +18,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- ***************************************************************************/ 
+ ***************************************************************************/
 /*
 The main class of this module, MyMoneyGncReader, contains only a readFile()
 function, which controls the import of data from an XML file created by the
 current GnuCash version (1.8.8).
- 
+
 The XML is processed in class XmlReader, which is an implementation of the Qt
-SAX2 reader class. 
- 
+SAX2 reader class.
+
 Data in the input file is processed as a set of objects which fortunately,
 though perhaps not surprisingly, have almost a one-for-one correspondence with
 KMyMoney objects. These objects are bounded by start and end XML elements, and
@@ -36,18 +36,18 @@ items, also delimited by start and end elements. For example:
   <act:name>Account Name</act:name> * data string with start and end elements
   ...
 </gnc:account> * end of sub objects
- 
+
 A GnuCash file may consist of more than one 'book', or set of data. It is not
 clear how we could currently implement this, so only the first book in a file is
 processed. This should satisfy most user situations.
- 
+
 GnuCash is somewhat inconsistent in its division of the major sections of the
 file. For example, multiple price history entries are delimited by <gnc:pricedb>
 elements, while each account starts with  its own top-level element. In general,
 the 'container' elements are ignored.
- 
+
 XmlReader
- 
+
 This is an implementation of the Qt QXmlDefaultHandler class, which provides
 three main function calls in addition to start and end of document. The
 startElement() and endElement() calls are self-explanatory, the characters()
@@ -59,29 +59,29 @@ would be
   endElement() for act:name
   ...
   endElement() for gnc:account
- 
+
 Objects
- 
+
 Since the processing requirements of XML for most elements are very similar, the
 common code is implemented in a GncObject class, from which the others are
 derived, with virtual function calls to cater for any differences. The
 'grandfather' object, GncFile representing the file (or more correctly, 'book')
 as a whole, is created in the startDocument() function call.
- 
+
 The constructor function of each object is responsible for providing two lists
 for the XmlReader to scan, a list of element names which represent sub objects
 (called sub elements in the code), and a similar list of names representing data
 elements. In addition, an array of variables (m_v) is provided and initialized,
 to contain the actual data strings.
- 
+
 Implementation
- 
+
 Since objects may be nested, a stack is used, with the top element pointing to
 the 'current object'. The startDocument() call creates the first, GncFile,
 object at the top of the stack.
- 
+
 As each startElement() call occurs, the two element lists created by the current
-object are scanned. 
+object are scanned.
 If this element represents the start of a sub object, the current object's subEl()
 function is called to create an instance of the appropriate type. This is then
 pushed to the top of the stack, and the new object's initiate() function is
@@ -90,7 +90,7 @@ GnuCash makes little use of these.
 If this represents the start of a data element, a pointer (m_dataPointer) is set
 to point to an entry in the array (m_v) in which a subsequent characters() call
 can store the actual data.
- 
+
 When an endElement() call occurs, a check is made to see if it matches the
 element name which started the current object. If so, the object's terminate()
 function is called. If the object represents a similar KMM object, this will
@@ -104,24 +104,24 @@ For example, a GncSplit object makes little sense outside the context of its
 transaction, so will be saved by the transaction. A GncTransaction object on the
 other hand will be converted, along with its attendant splits, and then deleted
 by its parent.
- 
+
 Since at any one time an object will only be processing either a subobject or a
 data element, a single object variable, m_state, is used to determine the actual
 type. In effect, it acts as the current index into either the subElement or
 dataElement list. As an object variable, it will be saved on the stack across
 subobject processing.
- 
+
 Exceptions and Problems
- 
-Fatal exceptions are processed via the standard MyMoneyException method. 
+
+Fatal exceptions are processed via the standard MyMoneyException method.
 Due to differences in implementation between GnuCash and KMM, it is not always
 possible to provide an absolutely correct conversion. When such a problem
 situation is recognized, a message, along with any relevant variable data, is
 passed to the main class, and used to produce a report when processing
 terminates. The GncMessages and GncMessageArg classes implement this.
- 
+
 Anonymizer
- 
+
 When debugging problems, it is often useful to have a trace of what is happening
 within the module. However, in view of the sensitive nature of personal finance
 data, most users will be reluctant to provide this. Accordingly, an anonymize
@@ -138,6 +138,11 @@ allow us to test the structure, if not the data content, of the file.
 
 #ifndef MYMONEYSTORAGEGNC_H
 #define MYMONEYSTORAGEGNC_H
+
+// Some STL headers in GCC4.3 contain operator new. Memory checker mangles these
+#ifdef _CHECK_MEMORY
+  #undef new
+#endif
 // system includes
 #include <stdlib.h>
 
@@ -156,6 +161,10 @@ class QIODevice;
 
 // ----------------------------------------------------------------------------
 // Project Includes
+#ifdef _CHECK_MEMORY
+  #include <kmymoney/mymoneyutils.h>
+#endif
+
 #ifndef _GNCFILEANON
 #include "../mymoney/storage/imymoneyserialize.h" // not used any more, but call interface requires it
 #include "../mymoney/storage/imymoneystorageformat.h"
@@ -184,7 +193,7 @@ class GncObject {
 public:
   GncObject();
   ; // to save delete loop when finished
-  virtual ~GncObject() {}; // make sure to have impl  of all virtual rtns to avoid vtable errors?
+  virtual ~GncObject() {}  // make sure to have impl  of all virtual rtns to avoid vtable errors?
 protected:
   friend class XmlReader;
   friend class MyMoneyGncReader;
@@ -226,11 +235,11 @@ protected:
   virtual const QString var (int i) const;
   // anonymize data
   virtual QString hide (QString, unsigned int);
-  
+
   MyMoneyGncReader *pMain;    // pointer to 'main' class
   // used at start of each transaction so same money hide factor is applied to all splits
   void adjustHideFactor();
-  
+
   QString m_elementName; // save 'this' element's name
   QString m_version;     // and it's gnucash version
   const QString *m_subElementList; // list of sub object element names for 'this'
@@ -239,9 +248,9 @@ protected:
   unsigned int m_dataElementListCount;
   QString *m_dataPtr; // pointer to m_v variable for current data item
   mutable QPtrList<QString> m_v; // storage for variable pointers
-  
+
   unsigned int m_state; // effectively, the index to subElementList or dataElementList, whichever is currently in use
-  
+
   const unsigned int *m_anonClassList;
   enum anonActions {ASIS, SUPPRESS, NXTACC, NXTEQU, NXTPAY, NXTSCHD, MAYBEQ, MONEY1, MONEY2}; // anonymize actions - see hide()
   unsigned int m_anonClass; // class of current data item for anonymizer
@@ -274,7 +283,7 @@ public:
 protected:
   friend class MyMoneyGncReader;
   friend class GncTransaction;
-  const bool isCurrency() const { return (*m_v.at(CMDTYSPC) == QString("ISO4217"));};
+  bool isCurrency() const { return (*m_v.at(CMDTYSPC) == QString("ISO4217"));};
   const QString id() const { return (*m_v.at(CMDTYID));};
   const QString space() const { return (*m_v.at(CMDTYSPC));};
 private:
@@ -318,7 +327,7 @@ protected:
   const QString key() const { return (var(KEY));};
   const QString value() const { return (var(VALUE));};
   const QString type() const { return (m_kvpType);};
-  const unsigned int kvpCount() const { return (m_kvpList.count());};
+  unsigned int kvpCount() const { return (m_kvpList.count());};
   const GncKvp *getKvp(unsigned int i) const { return (static_cast<GncKvp *>(m_kvpList.at(i)));};
 private:
   // subsidiary objects/elements
@@ -345,7 +354,7 @@ class GncLot : public GncObject {
 /** Following are the main objects within the gnucash file, which correspond largely one-for-one
     with similar objects in the kmymoney structure, apart from schedules which gnc splits between
     template (transaction data) and schedule (date data)
-*/ 
+*/
 //********************************************************************
 class GncCountData : public GncObject {
 public:
@@ -364,7 +373,7 @@ public:
 protected:
   friend class MyMoneyGncReader;
   // access data values
-  const bool isCurrency() const { return (var(SPACE) == QString("ISO4217"));};
+  bool isCurrency() const { return (var(SPACE) == QString("ISO4217"));};
   const QString space() const { return (var(SPACE));};
   const QString id() const { return (var(ID));};
   const QString name() const { return (var(NAME));};
@@ -460,8 +469,8 @@ protected:
   const QString currency() const { return (m_vpCurrency == NULL ? QString () : m_vpCurrency->id());};
   const QDate dateEntered() const { return (m_vpDateEntered->date());};
   const QDate datePosted() const { return (m_vpDatePosted->date());};
-  const bool isTemplate() const { return (m_template);};
-  const unsigned int splitCount() const { return (m_splitList.count());};
+  bool isTemplate() const { return (m_template);};
+  unsigned int splitCount() const { return (m_splitList.count());};
   const GncObject *getSplit (unsigned int i) const { return (m_splitList.at(i));};
 private:
   // subsidiary objects/elements
@@ -490,7 +499,7 @@ protected:
   const QString value() const { return (var(VALUE));};
   const QString qty() const { return (var(QTY));};
   const QString acct() const { return (var(ACCT));};
-  const unsigned int kvpCount() const { return (m_kvpList.count());};
+  unsigned int kvpCount() const { return (m_kvpList.count());};
   const GncKvp *getKvp(unsigned int i) const { return (static_cast<GncKvp *>(m_kvpList.at(i)));};
 private:
   // subsidiary objects/elements
@@ -523,11 +532,11 @@ protected:
   const QString numOccurs() const { return (var(NUMOCC));};
   const QString remOccurs() const { return (var(REMOCC));};
   const QString templId() const { return (var(TEMPLID));};
-  const QDate startDate () const 
+  const QDate startDate () const
     {QDate x = QDate(); return (m_vpStartDate == NULL ? x : m_vpStartDate->date());};
-  const QDate lastDate () const 
+  const QDate lastDate () const
     {QDate x = QDate(); return (m_vpLastDate == NULL ? x : m_vpLastDate->date());};
-  const QDate endDate() const 
+  const QDate endDate() const
     {QDate x = QDate(); return (m_vpEndDate == NULL ? x : m_vpEndDate->date());};
   const GncFreqSpec *getFreqSpec() const { return (m_vpFreqSpec);};
   const GncSchedDef *getSchedDef() const { return (m_vpSchedDef);};
@@ -573,8 +582,8 @@ public:
   ~GncRecurrence();
 protected:
   friend class MyMoneyGncReader;
-  // access data values 
-  const QDate startDate () const 
+  // access data values
+  const QDate startDate () const
     {QDate x = QDate(); return (m_vpStartDate == NULL ? x : m_vpStartDate->date());};
   const QString mult() const {return (var(MULT));};
   const QString periodType() const {return (var(PERIODTYPE));};
@@ -607,12 +616,12 @@ class GncSchedDef : public GncObject {
                                     XML Reader
  The XML reader is an implementation of the Qt SAX2 XML parser. It determines the type
  of object represented by the XMl, and calls the appropriate object functions
-*/ 
+*/
 // *****************************************************************************************
 class XmlReader : public QXmlDefaultHandler {
 protected:
   friend class MyMoneyGncReader;
-  XmlReader (MyMoneyGncReader *pM) : pMain(pM) {}; // keep pointer to 'main'
+  XmlReader (MyMoneyGncReader *pM) : pMain(pM) {}  // keep pointer to 'main'
   void processFile (QIODevice*); // main entry point of reader
   //  define xml content handler functions
   bool startDocument ();
@@ -648,7 +657,7 @@ class GncMessages {
 protected:
   friend class MyMoneyGncReader;
   static QString text (const QString, const unsigned int); // returns text of identified message
-  static const unsigned int argCount (const QString, const unsigned int); // returns no. of args required
+  static unsigned int argCount (const QString, const unsigned int); // returns no. of args required
 private:
   typedef struct {
     const QString source;
@@ -676,7 +685,7 @@ public:
     * Import a GnuCash XML file
     *
     * @param pDevice : pointer to GnuCash file
-    * @param storage : pointer to MyMoneySerialize storage 
+    * @param storage : pointer to MyMoneySerialize storage
     *
     * @return void
     *
@@ -718,7 +727,7 @@ protected:
   void convertSchedule (const GncSchedule *);
   void convertFreqSpec (const GncFreqSpec *);
   void convertRecurrence (const GncRecurrence *);
-#else  
+#else
     /** functions to convert gnc objects to our equivalent */
   void convertCommodity (const GncCommodity *) {return;};
   void convertPrice (const GncPrice *) {return;};
@@ -757,7 +766,7 @@ protected:
     you must select one of the following options.
        0 - create a separate investment account for each stock with the same name as the stock
        1 - create a single investment account to hold all stocks - you will be asked for a name
-       2 - create multiple investment accounts - you will be asked for a name for each stock 
+       2 - create multiple investment accounts - you will be asked for a name for each stock
        N.B. :- option 2 doesn't really work quite as desired at present
   */
   unsigned int m_investmentOption;
@@ -787,7 +796,7 @@ protected:
   bool developerDebug;
 private:
   void setOptions (); // to set user options from dialog
-  void setFileHideFactor (); 
+  void setFileHideFactor ();
   // the following handles the gnucash indicator for a bad value (-1/0) which causes us probs
   const QString convBadValue (QString gncValue) const {return (gncValue == "-1/0" ? "0/1" : gncValue); };
 #ifndef _GNCFILEANON
@@ -814,12 +823,12 @@ private:
   int m_gncAccountCount;
   int m_gncTransactionCount;
   int m_gncScheduleCount;
-  
+
   // flags indicating detection of features not (yet?) supported
   bool m_smallBusinessFound;
   bool m_budgetsFound;
   bool m_lotsFound;
-  
+
   /** counters for reporting */
   int m_commodityCount;
   int m_priceCount;
@@ -841,7 +850,7 @@ private:
   QMap<QCString, QCString> m_mapSchedules;
   QMap<QString, QString> m_mapSources;
   /**
-    * A list of stock accounts (gnc ids) which will be held till the end 
+    * A list of stock accounts (gnc ids) which will be held till the end
       so we can implement the user's investment option
     */
   QValueList<QString> m_stockList;
