@@ -21,6 +21,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <typeinfo>
+
 // ----------------------------------------------------------------------------
 // QT Headers
 
@@ -41,12 +43,36 @@
 // Project Headers
 
 #include "mymoneystatementreader.h"
-#include "../mymoney/mymoneyfile.h"
-#include "../mymoney/mymoneystatement.h"
+#include <kmymoney/mymoneyfile.h>
+#include <kmymoney/mymoneystatement.h>
+#include <kmymoney/kmymoneyglobalsettings.h>
+#include <kmymoney/transactioneditor.h>
 #include "../dialogs/kaccountselectdlg.h"
+#include "../dialogs/transactionmatcher.h"
+#include "../dialogs/kenterscheduledlg.h"
 #include "../kmymoney2.h"
 
+class MyMoneyStatementReaderPrivate
+{
+  public:
+    MyMoneyStatementReaderPrivate() :
+      transactionsCount(0),
+      transactionsAdded(0),
+      transactionsMatched(0),
+      transactionsDuplicate(0)
+    {}
+
+    MyMoneyAccount                 lastAccount;
+    QValueList<MyMoneyTransaction> transactions;
+    QValueList<MyMoneyPayee>       payees;
+    int                            transactionsCount;
+    int                            transactionsAdded;
+    int                            transactionsMatched;
+    int                            transactionsDuplicate;
+};
+
 MyMoneyStatementReader::MyMoneyStatementReader() :
+  d(new MyMoneyStatementReaderPrivate),
   m_userAbort(false),
   m_autoCreatePayee(false),
   m_ft(0),
@@ -56,6 +82,7 @@ MyMoneyStatementReader::MyMoneyStatementReader() :
 
 MyMoneyStatementReader::~MyMoneyStatementReader()
 {
+  delete d;
 }
 
 void MyMoneyStatementReader::setAutoCreatePayee(const bool create)
@@ -63,14 +90,8 @@ void MyMoneyStatementReader::setAutoCreatePayee(const bool create)
   m_autoCreatePayee = create;
 }
 
-const bool MyMoneyStatementReader::startImport(const MyMoneyStatement& s)
+bool MyMoneyStatementReader::import(const MyMoneyStatement& s, QStringList& messages)
 {
-  // right now, it's always true that the import started successfully.
-  // if there are problems, we'll report them in the result code to
-  // finishImport, just so the caller can handle the result in the
-  // same place.
-  bool result = true;
-
   //
   // For testing, save the statement to an XML file
   // (uncomment this line)
@@ -83,50 +104,72 @@ const bool MyMoneyStatementReader::startImport(const MyMoneyStatement& s)
 
   m_account = MyMoneyAccount();
 
-  m_account.setName(s.m_strAccountName);
-  m_account.setNumber(s.m_strAccountNumber);
-
-  switch ( s.m_eType )
-  {
-    case MyMoneyStatement::etCheckings:
-      m_account.setAccountType(MyMoneyAccount::Checkings);
-      break;
-    case MyMoneyStatement::etSavings:
-      m_account.setAccountType(MyMoneyAccount::Savings);
-      break;
-    case MyMoneyStatement::etInvestment:
-      //testing support for investment statements!
-      //m_userAbort = true;
-      //KMessageBox::error(kmymoney2, i18n("This is an investment statement.  These are not supported currently."), i18n("Critical Error"));
-      m_account.setAccountType(MyMoneyAccount::Investment);
-      break;
-    case MyMoneyStatement::etCreditCard:
-      m_account.setAccountType(MyMoneyAccount::CreditCard);
-      break;
-    default:
-      m_account.setAccountType(MyMoneyAccount::Checkings);
-      break;
-  }
-
   m_ft = new MyMoneyFileTransaction();
 
-  if ( !m_userAbort )
-    m_userAbort = ! selectOrCreateAccount(Select, m_account);
-
-  m_account.setValue("lastStatementBalance", s.m_closingBalance.toString());
-  if ( s.m_dateEnd.isValid() ) {
-    m_account.setValue("lastImportedTransactionDate", s.m_dateEnd.toString(Qt::ISODate));
+  // if the statement source left some information about
+  // the account, we use it to get the current data of it
+  if(!s.m_accountId.isEmpty()) {
+    try {
+      m_account = MyMoneyFile::instance()->account(s.m_accountId);
+    } catch(MyMoneyException* e) {
+      qDebug("Received reference '%s' to unknown account in statement", s.m_accountId.data());
+      delete e;
+    }
   }
 
-  try {
-    MyMoneyFile::instance()->modifyAccount(m_account);
-  } catch(MyMoneyException* e) {
-    qDebug("Updating account in MyMoneyStatementReader::startImport failed");
-    delete e;
+  if(m_account.id().isEmpty()) {
+    m_account.setName(s.m_strAccountName);
+    m_account.setNumber(s.m_strAccountNumber);
+
+    switch ( s.m_eType )
+    {
+      case MyMoneyStatement::etCheckings:
+        m_account.setAccountType(MyMoneyAccount::Checkings);
+        break;
+      case MyMoneyStatement::etSavings:
+        m_account.setAccountType(MyMoneyAccount::Savings);
+        break;
+      case MyMoneyStatement::etInvestment:
+        //testing support for investment statements!
+        //m_userAbort = true;
+        //KMessageBox::error(kmymoney2, i18n("This is an investment statement.  These are not supported currently."), i18n("Critical Error"));
+        m_account.setAccountType(MyMoneyAccount::Investment);
+        break;
+      case MyMoneyStatement::etCreditCard:
+        m_account.setAccountType(MyMoneyAccount::CreditCard);
+        break;
+      default:
+        m_account.setAccountType(MyMoneyAccount::Checkings);
+        break;
+    }
+
+
+    if ( !m_userAbort )
+      m_userAbort = ! selectOrCreateAccount(Select, m_account);
+  }
+
+  // see if we need to update some values stored with the account
+  if(m_account.value("lastStatementBalance") != s.m_closingBalance.toString()
+  || m_account.value("lastImportedTransactionDate") != s.m_dateEnd.toString(Qt::ISODate)) {
+    if(s.m_closingBalance != MyMoneyMoney::autoCalc) {
+      m_account.setValue("lastStatementBalance", s.m_closingBalance.toString());
+      if ( s.m_dateEnd.isValid() ) {
+        m_account.setValue("lastImportedTransactionDate", s.m_dateEnd.toString(Qt::ISODate));
+      }
+    }
+
+    try {
+      MyMoneyFile::instance()->modifyAccount(m_account);
+    } catch(MyMoneyException* e) {
+      qDebug("Updating account in MyMoneyStatementReader::startImport failed");
+      delete e;
+    }
   }
 
   signalProgress(0, s.m_listTransactions.count(), "Importing Statement ...");
 
+  messages += i18n("Importing statement for account %1").arg(m_account.name());
+
   //
   // Process the securities
   //
@@ -146,24 +189,50 @@ const bool MyMoneyStatementReader::startImport(const MyMoneyStatement& s)
 
   if ( !m_userAbort )
   {
-    int progress = 0;
-    QValueList<MyMoneyStatement::Transaction>::const_iterator it_t = s.m_listTransactions.begin();
-    while ( it_t != s.m_listTransactions.end() )
-    {
-      processTransactionEntry(*it_t);
-      signalProgress(++progress, 0);
-      ++it_t;
+    try {
+      int progress = 0;
+      QValueList<MyMoneyStatement::Transaction>::const_iterator it_t = s.m_listTransactions.begin();
+      while ( it_t != s.m_listTransactions.end() )
+      {
+        processTransactionEntry(*it_t);
+        signalProgress(++progress, 0);
+        ++it_t;
+      }
+
+    } catch(MyMoneyException* e) {
+      if(e->what() == "USERABORT")
+        m_userAbort = true;
+      else
+        qDebug("Caught exception from processTransactionEntry() not caused by USERABORT: %s", e->what().data());
+      delete e;
     }
   }
 
-  emit importFinished();
-  return result;
-}
-
-const bool MyMoneyStatementReader::finishImport(void)
-{
   bool  rc = false;
 
+  // delete all payees created in vain
+  int payeeCount = d->payees.count();
+  QValueList<MyMoneyPayee>::const_iterator it_p;
+  for(it_p = d->payees.begin(); it_p != d->payees.end(); ++it_p) {
+    try {
+      MyMoneyFile::instance()->removePayee(*it_p);
+      --payeeCount;
+    } catch(MyMoneyException* e) {
+      // if we can't delete it, it must be in use which is ok for us
+      delete e;
+    }
+  }
+
+  messages += i18n("  Statement balance on %1 is reported to be %2").arg(s.m_dateEnd.toString(Qt::ISODate)).arg(s.m_closingBalance.formatMoney("",2));
+  messages += i18n("  Transactions");
+  messages += i18n("    %1 processed").arg(d->transactionsCount);
+  messages += i18n("    %1 added").arg(d->transactionsAdded);
+  messages += i18n("    %1 matched").arg(d->transactionsMatched);
+  messages += i18n("    %1 duplicates").arg(d->transactionsDuplicate);
+  messages += i18n("  Payees");
+  messages += i18n("    %1 created").arg(payeeCount);
+  messages += QString();
+
   // remove the Don't ask again entries
   KConfig* config = KGlobal::config();
   config->setGroup(QString::fromLatin1("Notification Messages"));
@@ -445,16 +514,22 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       // we can stuff the transaction there.
 
       QCString brokerageactid = m_account.value("kmm-brokerage-account").utf8();
+      if (brokerageactid.isEmpty() )
+      {
+        brokerageactid = file->accountByName(m_account.brokerageName()).id();
+      }
       if ( ! brokerageactid.isEmpty() )
       {
         s1.setAccountId(brokerageactid);
         if ( ! t_in.m_strBankID.isEmpty() )
           s1.setBankID(t_in.m_strBankID);
 
+#if 0
         if(!s1.value().isNegative())
           s1.setAction(MyMoneySplit::ActionDeposit);
         else
           s1.setAction(MyMoneySplit::ActionWithdrawal);
+#endif
 
         // Needed to satisfy the bankid check below.
         thisaccount = file->account(brokerageactid);
@@ -475,10 +550,12 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
     if ( ! t_in.m_strBankID.isEmpty() )
       s1.setBankID(t_in.m_strBankID);
 
+#if 0
     if(!s1.value().isNegative())
       s1.setAction(MyMoneySplit::ActionDeposit);
     else
       s1.setAction(MyMoneySplit::ActionWithdrawal);
+#endif
   }
 
   QString payeename = t_in.m_strPayee;
@@ -486,7 +563,80 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
   {
     QCString payeeid;
     try {
-      payeeid = file->payeeByName(payeename).id();
+      QValueList<MyMoneyPayee> pList = file->payeeList();
+      QValueList<MyMoneyPayee>::const_iterator it_p;
+      QMap<QCString, int> matchMap;
+      for(it_p = pList.begin(); it_p != pList.end(); ++it_p) {
+        bool ignoreCase;
+        QStringList keys;
+        QStringList::const_iterator it_s;
+        switch((*it_p).matchData(ignoreCase, keys)) {
+          case MyMoneyPayee::matchDisabled:
+            break;
+
+          case MyMoneyPayee::matchName:
+            keys << (*it_p).name();
+            // tricky fall through here
+
+          case MyMoneyPayee::matchKey:
+            for(it_s = keys.begin(); it_s != keys.end(); ++it_s) {
+              QRegExp exp(*it_s, !ignoreCase);
+              if(exp.search(payeename) != -1) {
+                matchMap[(*it_p).id()] = 0;
+                break;
+              }
+            }
+            break;
+        }
+      }
+
+
+      // at this point we can have several scenarios:
+      // a) multiple matches
+      // b) a single match
+      // c) no match at all
+      //
+      // for c) we just don't do anything, for b) we take the one we found
+      // in case of a) we take the one we find most with this account
+      if(matchMap.count() > 1) {
+      // check if the account changed. If so, we need to reload the transactions
+        if(thisaccount.id() != d->lastAccount.id()) {
+          d->transactions.clear();
+          MyMoneyTransactionFilter filter(thisaccount.id());
+          filter.setReportAllSplits(false);
+          MyMoneyFile::instance()->transactionList(d->transactions, filter);
+          d->lastAccount = thisaccount;
+        }
+
+        QValueList<MyMoneyTransaction>::const_iterator it_t;
+        for(it_t = d->transactions.begin(); it_t != d->transactions.end(); ++it_t) {
+          const QValueList<MyMoneySplit>& splits = (*it_t).splits();
+          QValueList<MyMoneySplit>::const_iterator it_s;
+          for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+            if((*it_s).accountId() == d->lastAccount.id()) {
+              QMap<QCString, int>::iterator it_m;
+              it_m = matchMap.find(((*it_s).payeeId()));
+              if(it_m != matchMap.end()) {
+                (*it_m)++;
+              }
+            }
+          }
+        }
+        int hits = 0;
+        QMap<QCString, int>::iterator it_m;
+        for(it_m = matchMap.begin(); it_m != matchMap.end(); ++it_m) {
+          if((*it_m) > hits) {
+            payeeid = it_m.key();
+            hits = (*it_m);
+          }
+        }
+
+      } else if(matchMap.count() == 1)
+        payeeid = matchMap.begin().key();
+
+      if(payeeid.isEmpty())
+        throw new MYMONEYEXCEPTION("payee not matched");
+
       s1.setPayeeId(payeeid);
     }
     catch (MyMoneyException *e)
@@ -511,15 +661,26 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         rc = KMessageBox::questionYesNoCancel(0, msg, i18n("New payee/receiver"),
                   KStdGuiItem::yes(), KStdGuiItem::no(), askKey);
       }
+      delete e;
 
       if(rc == KMessageBox::Yes) {
-        // for now, we just add the payee to the pool. In the future,
-        // we could open a dialog and ask for all the other attributes
-        // of the payee.
+        // for now, we just add the payee to the pool and turn
+        // on simple name matching, so that future transactions
+        // with the same name don't get here again.
+        //
+        // In the future, we could open a dialog and ask for
+        // all the other attributes of the payee, but since this
+        // is called in the context of an automatic procedure it
+        // might distract the user.
         payee.setName(payeename);
+        QStringList keys;
+        keys << payeename;
+        payee.setMatchData(MyMoneyPayee::matchName, true, keys);
 
         try {
           file->addPayee(payee);
+          qDebug("%s created", payee.name().data());
+          d->payees << payee;
           payeeid = payee.id();
           s1.setPayeeId(payeeid);
 
@@ -537,7 +698,6 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         throw new MYMONEYEXCEPTION("USERABORT");
 
       }
-      delete e;
     }
 
     //
@@ -602,7 +762,6 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         }
       }
     }
-
   }
 
   t.addSplit(s1);
@@ -643,33 +802,75 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
 
   // Add the transaction
   try {
-    // check for duplicates ONLY by Bank ID in this account.
-    // We know Bank ID will definitely
-    // find duplicates.  For "softer" duplicates, we'll wait for the full
-    // matching interface.
-    MyMoneyTransactionFilter filter;
-    filter.setDateFilter(t.postDate().addDays(-4), t.postDate().addDays(4));
-    filter.addAccount(thisaccount.id());
-    QValueList<MyMoneyTransaction> list = file->transactionList(filter);
-    QValueList<MyMoneyTransaction>::Iterator it;
-    for(it = list.begin(); it != list.end(); ++it) {
-      MyMoneySplit thissplit = (*it).splitByAccount(thisaccount.id());
-      if(t_in.m_strBankID == thissplit.bankID() && !t_in.m_strBankID.isNull() && !thissplit.bankID().isNull())
-        break;
-    }
-    if(it == list.end())
-    {
+
+    // check for matches already stored in the engine
+    MyMoneySplit matchedSplit;
+    TransactionMatcher::autoMatchResultE result;
+    TransactionMatcher matcher(thisaccount);
+    matcher.setMatchWindow(KMyMoneyGlobalSettings::matchInterval());
+    const MyMoneyObject *o = matcher.findMatch(t, s1, matchedSplit, result);
+    d->transactionsCount++;
+
+    // if we did not already find this one, we need to process it
+    if(result != TransactionMatcher::matchedDuplicate) {
+      d->transactionsAdded++;
       file->addTransaction(t);
+
+      if(o) {
+        if(typeid(*o) == typeid(MyMoneyTransaction)) {
+          // it matched a simple transaction. that's the easy case
+          MyMoneyTransaction tm(*(dynamic_cast<const MyMoneyTransaction*>(o)));
+          switch(result) {
+            case TransactionMatcher::notMatched:
+            case TransactionMatcher::matchedDuplicate:
+              // no need to do anything here
+              break;
+            case TransactionMatcher::matched:
+              matcher.match(tm, matchedSplit, t, s1);
+              d->transactionsMatched++;
+              break;
+          }
+
+        } else if(typeid(*o) == typeid(MyMoneySchedule)) {
+          // a match has been found in a pending schedule. We'll ask the user if she wants
+          // to enter the schedule and match it agains the new transaction. Otherwise, we
+          // just leave the transaction as imported.
+          MyMoneySchedule schedule(*(dynamic_cast<const MyMoneySchedule*>(o)));
+          if(KMessageBox::questionYesNo(0, QString("<qt>%1</qt>").arg(i18n("KMyMoney has found a scheduled transaction named <b>%1</b> which matches an imported transaction. Do you want KMyMoney to enter this schedule now so that the transaction can be matched? ").arg(schedule.name())), i18n("Schedule found")) == KMessageBox::Yes) {
+            KEnterScheduleDlg dlg(0, schedule);
+            TransactionEditor* editor = dlg.startEdit();
+            if(editor) {
+              MyMoneyTransaction torig;
+              editor->createTransaction(torig, dlg.transaction(), dlg.transaction().splits()[0], true);
+              QCString newId;
+              if(editor->enterTransactions(newId, false, true)) {
+                if(!newId.isEmpty()) {
+                  torig = MyMoneyFile::instance()->transaction(newId);
+                  schedule.setLastPayment(torig.postDate());
+                }
+                schedule.setNextDueDate(schedule.nextPayment(schedule.nextDueDate()));
+                MyMoneyFile::instance()->modifySchedule(schedule);
+              }
+
+              // now match the two transactions
+              matcher.match(torig, matchedSplit, t, s1);
+              d->transactionsMatched++;
+            }
+            delete editor;
+          }
+        }
+      }
+    } else {
+      d->transactionsDuplicate++;
     }
+    delete o;
   } catch (MyMoneyException *e) {
-    QString message(i18n("Problem adding imported transaction #%1: ").arg(t_in.m_strBankID));
-    message += e->what();
+    QString message(i18n("Problem adding or matching imported transaction with id '%1': %2").arg(t_in.m_strBankID).arg(e->what()));
+    delete e;
 
     int result = KMessageBox::warningContinueCancel(0, message);
     if ( result == KMessageBox::Cancel )
-        throw new MYMONEYEXCEPTION("USERABORT");
-
-    delete e;
+      throw new MYMONEYEXCEPTION("USERABORT");
   }
 }
 
