@@ -162,8 +162,7 @@ void KEditScheduleDlg::slotSetupSize(void)
 
 TransactionEditor* KEditScheduleDlg::startEdit(void)
 {
-  QValueList<KMyMoneyRegister::SelectedTransaction> list;
-  m_register->selectedTransactions(list);
+  KMyMoneyRegister::SelectedTransactions list(m_register);
   TransactionEditor* editor = d->m_item->createEditor(m_form, list, QDate());
 
   // check that we use the same transaction commodity in all selected transactions
@@ -184,7 +183,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     connect(editor, SIGNAL(returnPressed()), buttonOk, SLOT(animateClick()));
 
     connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), editor, SLOT(slotReloadEditWidgets()));
-    // connect(editor, SIGNAL(finishEdit(const QValueList<KMyMoneyRegister::SelectedTransaction >&)), this, SLOT(slotLeaveEditMode(const QValueList<KMyMoneyRegister::SelectedTransaction >&)));
+    // connect(editor, SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
     connect(editor, SIGNAL(createPayee(const QString&, QCString&)), kmymoney2, SLOT(slotPayeeNew(const QString&, QCString&)));
     connect(editor, SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
     connect(editor, SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
