@@ -261,7 +261,7 @@ void KFindTransactionDlg::slotUpdateSelections(void)
   m_selectedCriteria->setText(i18n("Current selections: ") + txt);
 }
 
-const bool KFindTransactionDlg::allItemsSelected(const QListViewItem *item) const
+bool KFindTransactionDlg::allItemsSelected(const QListViewItem *item) const
 {
   QListViewItem* it_v;
 
@@ -275,7 +275,7 @@ const bool KFindTransactionDlg::allItemsSelected(const QListViewItem *item) cons
   return true;
 }
 
-const bool KFindTransactionDlg::allItemsSelected(const QListView* view) const
+bool KFindTransactionDlg::allItemsSelected(const QListView* view) const
 {
   QListViewItem* it_v;
 
@@ -399,12 +399,16 @@ void KFindTransactionDlg::slotDateRangeChanged(int idx)
 void KFindTransactionDlg::slotDateChanged(void)
 {
   int idx;
-  for(idx = MyMoneyTransactionFilter::untilToday; idx < MyMoneyTransactionFilter::userDefined; ++idx) {
+  for(idx = MyMoneyTransactionFilter::asOfToday; idx < MyMoneyTransactionFilter::dateOptionCount; ++idx) {
     if(m_fromDate->date() == m_startDates[idx]
     && m_toDate->date() == m_endDates[idx]) {
       break;
     }
   }
+  //if no filter matched, set to user defined
+  if(idx == MyMoneyTransactionFilter::dateOptionCount)
+    idx = MyMoneyTransactionFilter::userDefined;
+
   m_dateRange->blockSignals(true);
   m_dateRange->setCurrentItem(static_cast<MyMoneyTransactionFilter::dateOptionE>(idx));
   m_dateRange->blockSignals(false);
@@ -723,6 +727,9 @@ void KFindTransactionDlg::loadView(void)
 
   m_register->updateRegister(true);
 
+  m_register->setFocusToTop();
+  m_register->selectItem(m_register->focusItem());
+
 #if KMM_DEBUG
   m_foundText->setText(i18n("Found %1 matching transactions (D %2 / P %3 = %4)")
                       .arg(splitCount).arg(deposit.formatMoney("", 2)).arg(payment.formatMoney("", 2)).arg((deposit-payment).formatMoney("", 2)));
