@@ -330,16 +330,34 @@ bool kMyMoneySplitTable::eventFilter(QObject *o, QEvent *e)
         rc = false;
         break;
     }
+  } else if(e->type() == QEvent::KeyRelease && !isEditMode()) {
+    // for some reason, we only see a KeyRelease event of the Menu key
+    // here. In other locations (e.g. Register::eventFilter()) we see
+    // a KeyPress event. Strange. (ipwizard - 2008-05-10)
+    switch(k->key()) {
+      case Qt::Key_Menu:
+        // if the very last entry is selected, the delete
+        // operation is not available otherwise it is
+        m_contextMenu->setItemEnabled(m_contextMenuDelete,
+              row < static_cast<int> (m_transaction.splits().count()-1));
+        m_contextMenu->setItemEnabled(m_contextMenuDuplicate,
+              row < static_cast<int> (m_transaction.splits().count()-1));
+
+        m_contextMenu->exec(QCursor::pos());
+        rc = true;
+        break;
+      default:
+        break;
+    }
   }
 
   // if the event has not been processed here, forward it to
-  // the base class implementation
+  // the base class implementation if it's not a key event
   if(rc == false) {
-    if(e->type() == QEvent::KeyPress
-    || e->type() == QEvent::KeyRelease) {
-      rc = false;
-    } else
+    if(e->type() != QEvent::KeyPress
+    && e->type() != QEvent::KeyRelease) {
       rc = QTable::eventFilter(o, e);
+    }
   }
 
   return rc;
@@ -616,6 +634,8 @@ void kMyMoneySplitTable::slotDeleteSplit(void)
         // if we removed the last split, select the previous
         if(m_currentRow && m_currentRow == static_cast<int>(list.count())-1)
           setCurrentCell(m_currentRow-1, 0);
+        else
+          setCurrentCell(m_currentRow, 0);
         emit transactionChanged(m_transaction);
       } catch(MyMoneyException *e) {
         qDebug("Cannot remove split: %s", e->what().latin1());
@@ -735,7 +755,7 @@ void kMyMoneySplitTable::slotCancelEdit(void)
   }
 }
 
-const bool kMyMoneySplitTable::isEditMode(void) const
+bool kMyMoneySplitTable::isEditMode(void) const
 {
   return m_editMode;
 }
@@ -773,7 +793,7 @@ QWidget* kMyMoneySplitTable::createEditWidgets(void)
   connect(m_editCategory, SIGNAL(createItem(const QString&, QCString&)), this, SIGNAL(createCategory(const QString&, QCString&)));
   connect(m_editCategory, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
 
-  m_editMemo = new kMyMoneyLineEdit(0, 0, AlignLeft|AlignVCenter);
+  m_editMemo = new kMyMoneyLineEdit(0, 0, false, AlignLeft|AlignVCenter);
   m_editMemo->setHint(i18n("Memo"));
   m_editMemo->setFont(cellFont);
 
