@@ -39,7 +39,7 @@
 #include <kmymoney/kmymoneyedit.h>
 
 #include "../dialogs/knewaccountdlgdecl.h"
-class KMyMoneyAccountTreeItem;
+class KMyMoneyAccountTreeBaseItem;
 namespace reports {
   class KReportChartView;
 };
@@ -56,8 +56,8 @@ private:
   MyMoneyAccount m_parentAccount;
   bool m_bSelectedParentAccount;
 
-  KMyMoneyAccountTreeItem *m_parentItem;
-  KMyMoneyAccountTreeItem *m_accountItem;
+  KMyMoneyAccountTreeBaseItem *m_parentItem;
+  KMyMoneyAccountTreeBaseItem *m_accountItem;
   bool m_categoryEditor;
   bool m_isEditing;
 
@@ -67,7 +67,7 @@ private:
   int m_idPropMinBalance;
 
   void initParentWidget(QCString parentId, const QCString& accountId);
-  void showSubAccounts(QCStringList accounts, KMyMoneyAccountTreeItem *parentItem, const QCString& parentId, const QCString& accountId);
+  void showSubAccounts(QCStringList accounts, KMyMoneyAccountTreeBaseItem *parentItem, const QCString& parentId, const QCString& accountId);
   void loadVatAccounts(void);
   void storeKVP(const QCString& key, kMyMoneyEdit* widget);
   void storeKVP(const QCString& key, KLineEdit* widget);
@@ -110,6 +110,13 @@ public:
 
   void setOpeningBalanceShown(bool shown);
 
+  /**
+   * This method adds an additional tab pointed to with @a w to the tab widget.
+   * This tab is usually defined by a plugin (eg. online banking). If @a w is
+   * zero, this is a NOP. @a name is used as the text to be placed on the tab.
+   */
+  void addTab(QWidget* w, const QString& name);
+
 protected:
   void resizeEvent(QResizeEvent* e);
   void displayOnlineBankingStatus(void);
@@ -123,7 +130,6 @@ protected slots:
   void slotVatAssignmentChanged(bool);
   void slotNewClicked(void);
   void slotCheckFinished(void);
-  void slotOnlineSetupClicked(void);
   void slotLoadInstitutions(const QString&);
   void slotAdjustMinBalanceAbsoluteEdit(const QString&);
   void slotAdjustMinBalanceEarlyEdit(const QString&);
