@@ -21,8 +21,13 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
+
 #include <qvariant.h>
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
@@ -41,6 +46,7 @@
 
 // ----------------------------------------------------------------------------
 // KDE Includes
+
 #include <kapplication.h>
 #include <kpushbutton.h>
 #include <klineedit.h>
@@ -49,27 +55,31 @@
 #include <kguiitem.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kstdguiitem.h>
+#include <klocale.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
+
 #include "kreportconfigurationfilterdlg.h"
-#include "../widgets/kmymoneyregistersearch.h"
-#include "../widgets/kmymoneydateinput.h"
-#include "../widgets/kmymoneyedit.h"
-#include "../widgets/kmymoneylineedit.h"
-#include "../widgets/kmymoneyaccountselector.h"
+#include <kmymoney/kmymoneydateinput.h>
+#include <kmymoney/kmymoneyedit.h>
+#include <kmymoney/kmymoneylineedit.h>
+#include <kmymoney/kmymoneyaccountselector.h>
+#include <kmymoney/mymoneyfile.h>
+#include <kmymoney/mymoneyreport.h>
+#include <kmymoney/kmymoneycombo.h>
 #include "../widgets/kmymoneyreportconfigtab1decl.h"
 #include "../widgets/kmymoneyreportconfigtab2decl.h"
 #include "../widgets/kmymoneyreportconfigtab3decl.h"
-#include "../mymoney/mymoneyfile.h"
-#include "../mymoney/storage/imymoneystorage.h"
-#include "../mymoney/mymoneyreport.h"
+#include "../widgets/kmymoneyreportconfigtabchartdecl.h"
 
 KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
   MyMoneyReport report, QWidget *parent, const char *name)
- : KFindTransactionDlg(parent, name, true),
+ : KFindTransactionDlg(parent, name),
  m_tab2(0),
  m_tab3(0),
+ m_tabChart(0),
  m_initialState(report),
  m_currentState(report)
 {
@@ -77,24 +87,21 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
     // Rework labelling
     //
 
-    setCaption( tr2i18n( "Report Configuration" ) );
+    setCaption( i18n( "Report Configuration" ) );
     delete TextLabel1;
 
     //
     // Rework the buttons
     //
 
+    // the Ok button is always enabled
+    disconnect(SIGNAL(selectionEmpty(bool)));
+    m_searchButton->setGuiItem( KStdGuiItem::ok() );
+    m_searchButton->setEnabled(true);
 
-    m_searchButton->setText( tr2i18n( "OK" ) );
-    m_searchButton->disconnect();
-    m_resetButton->disconnect();
+    // reconnect the close button
     m_closeButton->disconnect();
-    m_helpButton->disconnect();
-    m_helpButton->show();
-    connect(m_searchButton, SIGNAL(clicked()), this, SLOT(slotSearch()));
-    connect(m_resetButton, SIGNAL(clicked()), this, SLOT(slotReset()));
     connect(m_closeButton, SIGNAL(clicked()), this, SLOT(reject()));
-    connect(m_helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
 
     //
     // Add new tabs
@@ -107,6 +114,14 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
     {
       m_tab2 = new kMyMoneyReportConfigTab2Decl( m_criteriaTab, "kMyMoneyReportConfigTab2" );
       m_criteriaTab->insertTab( m_tab2, i18n( "Rows/Columns"), 1 );
+      connect(m_tab2->m_comboRows, SIGNAL(highlighted(int)), this, SLOT(slotRowTypeChanged(int)));
+      //control the state of the includeTransfer check
+      connect(m_categoriesView, SIGNAL(stateChanged()), this, SLOT(slotUpdateCheckTransfers()));
+
+#ifdef HAVE_KDCHART
+      m_tabChart = new kMyMoneyReportConfigTabChartDecl( m_criteriaTab, "kMyMoneyReportConfigTabChart" );
+      m_criteriaTab->insertTab( m_tabChart, i18n( "Chart"), 2 );
+#endif
     }
     else if ( m_initialState.reportType() == MyMoneyReport::eQueryTable )
     {
@@ -122,10 +137,15 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
     m_criteriaTab->showPage( m_tab1 );
     m_criteriaTab->setMinimumSize( 500,200 );
 
+    QValueList<MyMoneyBudget> list = MyMoneyFile::instance()->budgetList();
+    QValueList<MyMoneyBudget>::const_iterator it_b;
+    for(it_b = list.begin(); it_b != list.end(); ++it_b) {
+      m_budgets.push_back(*it_b);
+    }
+
     //
     // Now set up the widgets with proper values
     //
-
     slotReset();
 }
 
@@ -133,7 +153,7 @@ KReportConfigurationFilterDlg::~KReportConfigurationFilterDlg()
 {
 }
 
-void KReportConfigurationFilterDlg::slotSearch()
+void KReportConfigurationFilterDlg::slotSearch(void)
 {
   // setup the filter from the dialog widgets
   setupFilter();
@@ -149,13 +169,38 @@ void KReportConfigurationFilterDlg::slotSearch()
 
   if ( m_tab2 )
   {
-    m_currentState.setShowSubAccounts( ! m_tab2->m_checkShowTop->isChecked() );
+    MyMoneyReport::EDetailLevel dl[4] = { MyMoneyReport::eDetailAll, MyMoneyReport::eDetailTop, MyMoneyReport::eDetailGroup, MyMoneyReport::eDetailTotal };
 
-    MyMoneyReport::ERowType rt[2] = { MyMoneyReport::eExpenseIncome, MyMoneyReport::eAssetLiability };
-    m_currentState.setRowType( rt[m_tab2->m_comboRows->currentItem()] );
+    m_currentState.setDetailLevel( dl[m_tab2->m_comboDetail->currentItem()] );
 
-    MyMoneyReport::EColumnType ct[4] = { MyMoneyReport::eMonths, MyMoneyReport::eBiMonths, MyMoneyReport::eQuarters, MyMoneyReport::eYears };
+    // modify the rowtype only if the widget is enabled
+    if(m_tab2->m_comboRows->isEnabled()) {
+      MyMoneyReport::ERowType rt[2] = { MyMoneyReport::eExpenseIncome, MyMoneyReport::eAssetLiability };
+      m_currentState.setRowType( rt[m_tab2->m_comboRows->currentItem()] );
+    }
+
+    m_currentState.setShowingRowTotals(false);
+    if(m_tab2->m_comboRows->currentItem() == 0)
+      m_currentState.setShowingRowTotals(m_tab2->m_checkTotalColumn->isChecked());
+
+    MyMoneyReport::EColumnType ct[6] = { MyMoneyReport::eDays, MyMoneyReport::eWeeks, MyMoneyReport::eMonths, MyMoneyReport::eBiMonths, MyMoneyReport::eQuarters, MyMoneyReport::eYears };
+    bool dy[6] = { true, true, false, false, false, false };
     m_currentState.setColumnType( ct[m_tab2->m_comboColumns->currentItem()] );
+
+    //TODO (Ace) This should be implicit in the call above.  MMReport needs fixin'
+    m_currentState.setColumnsAreDays( dy[m_tab2->m_comboColumns->currentItem()] );
+
+    m_currentState.setIncludingSchedules( m_tab2->m_checkScheduled->isChecked() );
+
+    m_currentState.setIncludingTransfers( m_tab2->m_checkTransfers->isChecked() );
+
+    m_currentState.setIncludingUnusedAccounts( m_tab2->m_checkUnused->isChecked() );
+
+    if(m_tab2->m_comboBudget->isEnabled()) {
+      m_currentState.setBudget(m_budgets[m_tab2->m_comboBudget->currentItem()].id(), m_initialState.rowType() == MyMoneyReport::eBudgetActual);
+    } else {
+      m_currentState.setBudget(QCString(), false);
+    }
   }
   else if ( m_tab3 )
   {
@@ -164,6 +209,10 @@ void KReportConfigurationFilterDlg::slotSearch()
 
     unsigned qc = MyMoneyReport::eQCnone;
 
+    if (m_currentState.queryColumns() & MyMoneyReport::eQCloan)
+      // once a loan report, always a loan report
+      qc = MyMoneyReport::eQCloan;
+
     if ( m_tab3->m_checkNumber->isChecked() )
       qc |= MyMoneyReport::eQCnumber;
     if ( m_tab3->m_checkPayee->isChecked() )
@@ -182,20 +231,41 @@ void KReportConfigurationFilterDlg::slotSearch()
       qc |= MyMoneyReport::eQCshares;
     if ( m_tab3->m_checkPrice->isChecked() )
       qc |= MyMoneyReport::eQCprice;
+    if( m_tab3->m_checkBalance->isChecked() )
+      qc |= MyMoneyReport::eQCbalance;
 
     m_currentState.setQueryColumns(static_cast<MyMoneyReport::EQueryColumns>(qc));
 
     m_currentState.setTax( m_tab3->m_checkTax->isChecked() );
     m_currentState.setInvestmentsOnly( m_tab3->m_checkInvestments->isChecked() );
+    m_currentState.setLoansOnly( m_tab3->m_checkLoans->isChecked() );
+
+    m_currentState.setDetailLevel(m_tab3->m_checkHideSplitDetails->isChecked() ?
+        MyMoneyReport::eDetailNone : MyMoneyReport::eDetailAll);
+  }
+
+  if ( m_tabChart )
+  {
+    MyMoneyReport::EChartType ct[5] = { MyMoneyReport::eChartLine, MyMoneyReport::eChartBar, MyMoneyReport::eChartStackedBar, MyMoneyReport::eChartPie, MyMoneyReport::eChartRing };
+    m_currentState.setChartType( ct[m_tabChart->m_comboType->currentItem()] );
+
+    m_currentState.setChartGridLines( m_tabChart->m_checkGridLines->isChecked() );
+    m_currentState.setChartDataLabels( m_tabChart->m_checkValues->isChecked() );
+    m_currentState.setChartByDefault( m_tabChart->m_checkShowChart->isChecked() );
   }
 
   // setup the date lock
-  unsigned range = m_dateRange->currentItem();
+  MyMoneyTransactionFilter::dateOptionE range = m_dateRange->currentItem();
   m_currentState.setDateFilter(range);
 
   done(true);
 }
 
+void KReportConfigurationFilterDlg::slotRowTypeChanged(int row)
+{
+  m_tab2->m_checkTotalColumn->setEnabled(row == 0);
+}
+
 void KReportConfigurationFilterDlg::slotReset(void)
 {
   //
@@ -213,29 +283,95 @@ void KReportConfigurationFilterDlg::slotReset(void)
 
   if ( m_tab2 )
   {
-    m_tab2->m_checkShowTop->setChecked( ! m_initialState.isShowingSubAccounts() );
-
-    if ( m_initialState.rowType() == MyMoneyReport::eExpenseIncome )
-      m_tab2->m_comboRows->setCurrentItem(0);
-    else
-      m_tab2->m_comboRows->setCurrentItem(1);
-
-    switch ( m_initialState.columnType() )
+    switch ( m_initialState.detailLevel() )
     {
-    case MyMoneyReport::eNoColumns:
-    case MyMoneyReport::eMonths:
-      m_tab2->m_comboColumns->setCurrentItem(0);
+    case MyMoneyReport::eDetailNone:
+    case MyMoneyReport::eDetailEnd:
+    case MyMoneyReport::eDetailAll:
+      m_tab2->m_comboDetail->setCurrentItem(0);
       break;
-    case MyMoneyReport::eBiMonths:
-      m_tab2->m_comboColumns->setCurrentItem(1);
+    case MyMoneyReport::eDetailTop:
+      m_tab2->m_comboDetail->setCurrentItem(1);
       break;
-    case MyMoneyReport::eQuarters:
-      m_tab2->m_comboColumns->setCurrentItem(2);
+    case MyMoneyReport::eDetailGroup:
+      m_tab2->m_comboDetail->setCurrentItem(2);
       break;
-    case MyMoneyReport::eYears:
-      m_tab2->m_comboColumns->setCurrentItem(3);
+    case MyMoneyReport::eDetailTotal:
+      m_tab2->m_comboDetail->setCurrentItem(3);
       break;
     }
+
+    switch(m_initialState.rowType()) {
+      case MyMoneyReport::eExpenseIncome:
+      case MyMoneyReport::eBudget:
+      case MyMoneyReport::eBudgetActual:
+        m_tab2->m_comboRows->setCurrentItem(0); // income / expense
+        break;
+      default:
+        m_tab2->m_comboRows->setCurrentItem(1); // asset / liability
+        break;
+    }
+    m_tab2->m_checkTotalColumn->setChecked(m_initialState.isShowingRowTotals());
+
+    slotRowTypeChanged(m_tab2->m_comboRows->currentItem());
+
+    if ( m_initialState.isColumnsAreDays() )
+    {
+      switch ( m_initialState.columnType() )
+      {
+      case MyMoneyReport::eNoColumns:
+      case MyMoneyReport::eDays:
+        m_tab2->m_comboColumns->setCurrentItem(0);
+        break;
+      case MyMoneyReport::eWeeks:
+        m_tab2->m_comboColumns->setCurrentItem(1);
+        break;
+      default:
+        break;
+      }
+    }
+    else
+    {
+      switch ( m_initialState.columnType() )
+      {
+      case MyMoneyReport::eNoColumns:
+      case MyMoneyReport::eMonths:
+        m_tab2->m_comboColumns->setCurrentItem(2);
+        break;
+      case MyMoneyReport::eBiMonths:
+        m_tab2->m_comboColumns->setCurrentItem(3);
+        break;
+      case MyMoneyReport::eQuarters:
+        m_tab2->m_comboColumns->setCurrentItem(4);
+        break;
+      case MyMoneyReport::eYears:
+        m_tab2->m_comboColumns->setCurrentItem(5);
+        break;
+      default:
+        break;
+      }
+    }
+
+    //load budgets combo
+    if(m_initialState.rowType() == MyMoneyReport::eBudget
+    || m_initialState.rowType() == MyMoneyReport::eBudgetActual) {
+      m_tab2->m_comboRows->setEnabled(false);
+      m_tab2->m_budgetFrame->setEnabled(!m_budgets.empty());
+      QValueVector<MyMoneyBudget>::const_iterator it_b;
+      int i = 0;
+      for(it_b = m_budgets.begin(); it_b != m_budgets.end(); ++it_b) {
+        m_tab2->m_comboBudget->insertItem((*it_b).name(), i);
+        //set the current selected item
+        if( (m_initialState.budget() == "Any" && (*it_b).budgetStart().year() == QDate::currentDate().year())
+             || m_initialState.budget() == (*it_b).id())
+          m_tab2->m_comboBudget->setCurrentItem(i);
+        i++;
+      }
+    }
+
+    m_tab2->m_checkScheduled->setChecked( m_initialState.isIncludingSchedules() );
+    m_tab2->m_checkTransfers->setChecked( m_initialState.isIncludingTransfers() );
+    m_tab2->m_checkUnused->setChecked( m_initialState.isIncludingUnusedAccounts() );
   }
   else if ( m_tab3 )
   {
@@ -263,12 +399,7 @@ void KReportConfigurationFilterDlg::slotReset(void)
     case MyMoneyReport::eWeek:
       m_tab3->m_comboOrganizeBy->setCurrentItem(6);
       break;
-    case MyMoneyReport::eAccountByTopAccount:
-    case MyMoneyReport::eEquityType:
-    case MyMoneyReport::eAccountType:
-    case MyMoneyReport::eInstitution:
-    case MyMoneyReport::eAssetLiability:
-    case MyMoneyReport::eExpenseIncome:
+    default:
       throw new MYMONEYEXCEPTION("KReportConfigurationFilterDlg::slotReset(): QueryTable report has invalid rowtype");
     }
 
@@ -282,9 +413,42 @@ void KReportConfigurationFilterDlg::slotReset(void)
     m_tab3->m_checkAction->setChecked(qc & MyMoneyReport::eQCaction);
     m_tab3->m_checkShares->setChecked(qc & MyMoneyReport::eQCshares);
     m_tab3->m_checkPrice->setChecked(qc & MyMoneyReport::eQCprice);
+    m_tab3->m_checkBalance->setChecked(qc & MyMoneyReport::eQCbalance);
 
     m_tab3->m_checkTax->setChecked( m_initialState.isTax() );
     m_tab3->m_checkInvestments->setChecked( m_initialState.isInvestmentsOnly() );
+    m_tab3->m_checkLoans->setChecked( m_initialState.isLoansOnly() );
+
+    m_tab3->m_checkHideSplitDetails->setChecked
+      (m_initialState.detailLevel() == MyMoneyReport::eDetailNone);
+  }
+
+  if ( m_tabChart )
+  {
+    switch( m_initialState.chartType() )
+    {
+      case MyMoneyReport::eChartNone:
+      case MyMoneyReport::eChartLine:
+        m_tabChart->m_comboType->setCurrentItem(0);
+        break;
+      case MyMoneyReport::eChartBar:
+        m_tabChart->m_comboType->setCurrentItem(1);
+        break;
+      case MyMoneyReport::eChartStackedBar:
+        m_tabChart->m_comboType->setCurrentItem(2);
+        break;
+      case MyMoneyReport::eChartPie:
+        m_tabChart->m_comboType->setCurrentItem(3);
+        break;
+      case MyMoneyReport::eChartRing:
+        m_tabChart->m_comboType->setCurrentItem(4);
+        break;
+      case MyMoneyReport::eChartEnd:
+        throw new MYMONEYEXCEPTION("KReportConfigurationFilterDlg::slotReset(): Report has invalid charttype");
+    }
+    m_tabChart->m_checkGridLines->setChecked(m_initialState.isChartGridLines());
+    m_tabChart->m_checkValues->setChecked(m_initialState.isChartDataLabels());
+    m_tabChart->m_checkShowChart->setChecked(m_initialState.isChartByDefault());
   }
 
   //
@@ -424,11 +588,11 @@ void KReportConfigurationFilterDlg::slotReset(void)
   QCStringList accounts;
   if ( m_initialState.accounts(accounts) )
   {
-    m_accountsView->selectAllAccounts(false);
-    m_accountsView->selectAccounts(accounts,true);
+    m_accountsView->selectAllItems(false);
+    m_accountsView->selectItems(accounts,true);
   }
   else
-    m_accountsView->selectAllAccounts(true);
+    m_accountsView->selectAllItems(true);
 
   //
   // Categories Filter
@@ -436,11 +600,11 @@ void KReportConfigurationFilterDlg::slotReset(void)
 
   if ( m_initialState.categories(accounts) )
   {
-    m_categoriesView->selectAllAccounts(false);
-    m_categoriesView->selectAccounts(accounts,true);
+    m_categoriesView->selectAllItems(false);
+    m_categoriesView->selectItems(accounts,true);
   }
   else
-    m_categoriesView->selectAllAccounts(true);
+    m_categoriesView->selectAllItems(true);
 
   //
   // Date Filter
@@ -453,25 +617,34 @@ void KReportConfigurationFilterDlg::slotReset(void)
   QDate dateFrom, dateTo;
   if ( m_initialState.dateFilter( dateFrom, dateTo ) )
   {
-    m_dateRange->setCurrentItem(userDefined);
+    m_dateRange->setCurrentItem(MyMoneyTransactionFilter::userDefined);
     m_fromDate->setDate(dateFrom);
     m_toDate->setDate(dateTo);
     slotDateChanged();
   }
   else
   {
-    m_dateRange->setCurrentItem(allDates);
-    slotDateRangeChanged(allDates);
+    m_dateRange->setCurrentItem(MyMoneyTransactionFilter::allDates);
+    slotDateRangeChanged(MyMoneyTransactionFilter::allDates);
   }
 
-  //QTimer::singleShot(0, this, SLOT(slotRightSize()));
-
   slotRightSize();
 }
 
-void KReportConfigurationFilterDlg::slotHelp(void)
+void KReportConfigurationFilterDlg::slotShowHelp(void)
 {
   kapp->invokeHelp("details.reports.config");
 }
 
+//TODO Fix the reports and engine to include transfers even if categories are filtered - bug #1523508
+void KReportConfigurationFilterDlg::slotUpdateCheckTransfers(void)
+{
+  if(!m_categoriesView->allItemsSelected()) {
+    m_tab2->m_checkTransfers->setChecked(false);
+    m_tab2->m_checkTransfers->setDisabled(true);
+  } else {
+    m_tab2->m_checkTransfers->setEnabled(true);
+  }
+}
+
 #include "kreportconfigurationfilterdlg.moc"
