@@ -39,7 +39,6 @@
 #include <kmymoney/mymoneyfile.h>
 #include <kmymoney/mymoneyfinancialcalculator.h>
 #include <kmymoney/kmymoneyglobalsettings.h>
-#include <kmymoney/kmymoneycombo.h>
 
 #include "kmymoneyutils.h"
 
@@ -53,66 +52,10 @@ KMyMoneyUtils::~KMyMoneyUtils()
 
 const QString KMyMoneyUtils::accountTypeToString(const MyMoneyAccount::accountTypeE accountType)
 {
-  QString returnString;
-
-  switch (accountType)
-  {
-    case MyMoneyAccount::Checkings:
-      returnString = i18n("Checking");
-      break;
-    case MyMoneyAccount::Savings:
-      returnString = i18n("Savings");
-      break;
-    case MyMoneyAccount::CreditCard:
-      returnString = i18n("Credit Card");
-      break;
-    case MyMoneyAccount::Cash:
-      returnString = i18n("Cash");
-      break;
-    case MyMoneyAccount::Loan:
-      returnString = i18n("Loan");
-      break;
-    case MyMoneyAccount::CertificateDep:
-      returnString = i18n("Certificate of Deposit");
-      break;
-    case MyMoneyAccount::Investment:
-      returnString = i18n("Investment");
-      break;
-    case MyMoneyAccount::MoneyMarket:
-      returnString = i18n("Money Market");
-      break;
-    case MyMoneyAccount::Asset:
-      returnString = i18n("Asset");
-      break;
-    case MyMoneyAccount::Liability:
-      returnString = i18n("Liability");
-      break;
-    case MyMoneyAccount::Currency:
-      returnString = i18n("Currency");
-      break;
-    case MyMoneyAccount::Income:
-      returnString = i18n("Income");
-      break;
-    case MyMoneyAccount::Expense:
-      returnString = i18n("Expense");
-      break;
-    case MyMoneyAccount::AssetLoan:
-      returnString = i18n("Investment Loan");
-      break;
-    case MyMoneyAccount::Stock:
-      returnString = i18n("Stock");
-      break;
-    case MyMoneyAccount::Equity:
-      returnString = i18n("Equity");
-      break;
-    default:
-      returnString = i18n("Unknown");
-  }
-
-  return returnString;
+  return MyMoneyAccount::accountTypeToString(accountType);
 }
 
-const MyMoneyAccount::accountTypeE KMyMoneyUtils::stringToAccountType(const QString& type)
+MyMoneyAccount::accountTypeE KMyMoneyUtils::stringToAccountType(const QString& type)
 {
   MyMoneyAccount::accountTypeE rc = MyMoneyAccount::UnknownAccountType;
   QString tmp = type.lower();
@@ -153,7 +96,7 @@ const MyMoneyAccount::accountTypeE KMyMoneyUtils::stringToAccountType(const QStr
   return rc;
 }
 
-const MyMoneySecurity::eSECURITYTYPE KMyMoneyUtils::stringToSecurity(const QString& txt)
+MyMoneySecurity::eSECURITYTYPE KMyMoneyUtils::stringToSecurity(const QString& txt)
 {
   MyMoneySecurity::eSECURITYTYPE rc = MyMoneySecurity::SECURITY_NONE;
   QString tmp = txt.lower();
@@ -172,33 +115,10 @@ const MyMoneySecurity::eSECURITYTYPE KMyMoneyUtils::stringToSecurity(const QStri
 
 const QString KMyMoneyUtils::securityTypeToString(const MyMoneySecurity::eSECURITYTYPE securityType)
 {
-  QString returnString;
-
-  switch (securityType)
-  {
-  case MyMoneySecurity::SECURITY_STOCK:
-    returnString = i18n("Stock");
-    break;
-  case MyMoneySecurity::SECURITY_MUTUALFUND:
-    returnString = i18n("Mutual Fund");
-    break;
-  case MyMoneySecurity::SECURITY_BOND:
-    returnString = i18n("Bond");
-    break;
-  case MyMoneySecurity::SECURITY_CURRENCY:
-    returnString = i18n("Currency");
-    break;
-  case MyMoneySecurity::SECURITY_NONE:
-    returnString = i18n("None");
-    break;
-  default:
-    returnString = i18n("Unknown");
-  }
-
-  return returnString;
+  return i18n(MyMoneySecurity::securityTypeToString(securityType));
 }
 
-const MyMoneySchedule::occurenceE KMyMoneyUtils::stringToOccurence(const QString& text)
+MyMoneySchedule::occurenceE KMyMoneyUtils::stringToOccurence(const QString& text)
 {
   MyMoneySchedule::occurenceE occurence = MyMoneySchedule::OCCUR_ANY;
   QString tmp = text.lower();
@@ -243,86 +163,22 @@ const MyMoneySchedule::occurenceE KMyMoneyUtils::stringToOccurence(const QString
 
 const QString KMyMoneyUtils::occurenceToString(const MyMoneySchedule::occurenceE occurence)
 {
-  KMyMoneyFrequencyCombo combo;
-  combo.setCurrentItem(occurence);
-  return combo.currentText();
+  return i18n(MyMoneySchedule::occurenceToString(occurence));
 }
 
 const QString KMyMoneyUtils::paymentMethodToString(MyMoneySchedule::paymentTypeE paymentType)
 {
-  QString text;
-
-  switch (paymentType)
-  {
-    case MyMoneySchedule::STYPE_DIRECTDEBIT:
-      text = i18n("Direct debit");
-      break;
-    case MyMoneySchedule::STYPE_DIRECTDEPOSIT:
-      text = i18n("Direct deposit");
-      break;
-    case MyMoneySchedule::STYPE_MANUALDEPOSIT:
-      text = i18n("Manual deposit");
-      break;
-    case MyMoneySchedule::STYPE_OTHER:
-      text = i18n("Other");
-      break;
-    case MyMoneySchedule::STYPE_WRITECHEQUE:
-      text = i18n("Write check");
-      break;
-    case MyMoneySchedule::STYPE_STANDINGORDER:
-      text = i18n("Standing order");
-      break;
-    case MyMoneySchedule::STYPE_BANKTRANSFER:
-      text = i18n("Bank transfer");
-      break;
-    case MyMoneySchedule::STYPE_ANY:
-      text = i18n("Any (Error)");
-      break;
-  }
-  return text;
+  return i18n(MyMoneySchedule::paymentMethodToString(paymentType));
 }
+
 const QString KMyMoneyUtils::weekendOptionToString(MyMoneySchedule::weekendOptionE weekendOption)
 {
-  QString text;
-
-  switch (weekendOption)
-  {
-    case MyMoneySchedule::MoveFriday:
-      text = i18n("Change the date to the previous Friday");
-      break;
-    case MyMoneySchedule::MoveMonday:
-      text = i18n("Change the date to the next Monday");
-      break;
-    case MyMoneySchedule::MoveNothing:
-      text = i18n("Do Nothing");
-      break;
-  }
-  return text;
+  return i18n(MyMoneySchedule::weekendOptionToString(weekendOption));
 }
 
 const QString KMyMoneyUtils::scheduleTypeToString(MyMoneySchedule::typeE type)
 {
-  QString text;
-
-  switch (type)
-  {
-    case MyMoneySchedule::TYPE_BILL:
-      text = i18n("Bill");
-      break;
-    case MyMoneySchedule::TYPE_DEPOSIT:
-      text = i18n("Deposit");
-      break;
-    case MyMoneySchedule::TYPE_TRANSFER:
-      text = i18n("Transfer");
-      break;
-    case MyMoneySchedule::TYPE_LOANPAYMENT:
-      text = i18n("Loan payment");
-      break;
-    case MyMoneySchedule::TYPE_ANY:
-    default:
-      text = i18n("Unknown");
-  }
-  return text;
+  return i18n(MyMoneySchedule::scheduleTypeToString(type));
 }
 
 KGuiItem KMyMoneyUtils::scheduleNewGuiItem(void)
@@ -396,7 +252,7 @@ const QString KMyMoneyUtils::homePageItemToString(const int idx)
   return rc;
 }
 
-const int KMyMoneyUtils::stringToHomePageItem(const QString& txt)
+int KMyMoneyUtils::stringToHomePageItem(const QString& txt)
 {
   int idx = 0;
   for(idx = 0; homePageItems[idx] != 0; ++idx) {
@@ -557,7 +413,7 @@ const MyMoneySplit KMyMoneyUtils::stockSplit(const MyMoneyTransaction& t)
   return MyMoneySplit();
 }
 
-const KMyMoneyUtils::transactionTypeE KMyMoneyUtils::transactionType(const MyMoneyTransaction& t)
+KMyMoneyUtils::transactionTypeE KMyMoneyUtils::transactionType(const MyMoneyTransaction& t)
 {
   if(!stockSplit(t).id().isEmpty())
     return InvestmentTransaction;
@@ -742,3 +598,22 @@ QString KMyMoneyUtils::reconcileStateToString(MyMoneySplit::reconcileFlagE flag,
   }
   return txt;
 }
+
+MyMoneyTransaction KMyMoneyUtils::scheduledTransaction(const MyMoneySchedule& schedule)
+{
+  MyMoneyTransaction t = schedule.transaction();
+
+  try {
+    if (schedule.type() == MyMoneySchedule::TYPE_LOANPAYMENT) {
+      calculateAutoLoan(schedule, t, QMap<QCString, MyMoneyMoney>());
+    }
+  } catch (MyMoneyException* e) {
+    qDebug("Unable to load schedule details for '%s' during transaction match: %s", schedule.name().data(), e->what().data());
+    delete e;
+  }
+
+  t.clearId();
+  t.setEntryDate(QDate());
+  return t;
+}
+
