@@ -20,6 +20,8 @@
 // QT Includes
 
 #include <qregexp.h>
+#include <kstandarddirs.h>
+#include <kiconloader.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -65,6 +67,21 @@ MyMoneyAccount::MyMoneyAccount(const QDomElement& node) :
   setParentAccountId(QCStringEmpty(node.attribute("parentaccount")));
   setLastModified(stringToDate(QStringEmpty(node.attribute("lastmodified"))));
   setLastReconciliationDate(stringToDate(QStringEmpty(node.attribute("lastreconciled"))));
+
+  if(!m_lastReconciliationDate.isValid()) {
+    // for some reason, I was unable to access our own kvp at this point through
+    // the value() method. It always returned empty strings. The workaround for
+    // this is to construct a local kvp the same way as we have done before and
+    // extract the value from it.
+    //
+    // Since we want to get rid of the lastStatementDate record anyway, this seems
+    // to be ok for now. (ipwizard - 2008-08-14)
+    QString txt = MyMoneyKeyValueContainer(node.elementsByTagName("KEYVALUEPAIRS").item(0).toElement()).value("lastStatementDate");
+    if(!txt.isEmpty()) {
+      setLastReconciliationDate(QDate::fromString(txt, Qt::ISODate));
+    }
+  }
+
   setInstitutionId(QCStringEmpty(node.attribute("institution")));
   setNumber(QStringEmpty(node.attribute("number")));
   setOpeningDate(stringToDate(QStringEmpty(node.attribute("opened"))));
@@ -143,6 +160,11 @@ void MyMoneyAccount::setOpeningDate(const QDate& date)
 
 void MyMoneyAccount::setLastReconciliationDate(const QDate& date)
 {
+  // FIXME: for a limited time (maybe until we delivered 1.0) we
+  // keep the last reconciliation date also in the KVP for backward
+  // compatability. After that, the setValue() statemetn should be removed
+  // and the XML ctor should remove the value completely from the KVP
+  setValue("lastStatementDate", date.toString(Qt::ISODate));
   m_lastReconciliationDate = date;
 }
 
@@ -176,7 +198,7 @@ void MyMoneyAccount::removeAccountId(const QCString& account)
     m_accountList.remove(it);
 }
 
-const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::accountTypeE type)
+MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::accountTypeE type)
 {
   switch(type) {
     case MyMoneyAccount::Checkings:
@@ -199,7 +221,7 @@ const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::
   }
 }
 
-const bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
+bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
 {
   return (MyMoneyKeyValueContainer::operator==(right) &&
       MyMoneyObject::operator==(right) &&
@@ -216,7 +238,7 @@ const bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
       (m_institution == right.m_institution) );
 }
 
-const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(void) const
+MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(void) const
 {
   return accountGroup(m_accountType);
 }
@@ -305,7 +327,7 @@ void MyMoneyAccountLoan::setInterestRate(const QDate& date, const MyMoneyMoney&
   setValue(key, value.toString());
 }
 
-const MyMoneyAccountLoan::interestDueE MyMoneyAccountLoan::interestCalculation(void) const
+MyMoneyAccountLoan::interestDueE MyMoneyAccountLoan::interestCalculation(void) const
 {
   QString payTime(value("interest-calculation"));
   if(payTime == "paymentDue")
@@ -337,7 +359,7 @@ void MyMoneyAccountLoan::setNextInterestChange(const QDate& date)
   setValue("interest-nextchange", date.toString(Qt::ISODate));
 }
 
-const int MyMoneyAccountLoan::interestChangeFrequency(int* unit) const
+int MyMoneyAccountLoan::interestChangeFrequency(int* unit) const
 {
   int rc = -1;
 
@@ -371,7 +393,7 @@ void MyMoneyAccountLoan::setSchedule(const QCString& sched)
   setValue("schedule", sched);
 }
 
-const bool MyMoneyAccountLoan::fixedInterestRate(void) const
+bool MyMoneyAccountLoan::fixedInterestRate(void) const
 {
   // make sure, that an empty kvp element returns true
   return !(value("fixed-interest") == "no");
@@ -396,7 +418,7 @@ void MyMoneyAccountLoan::setFinalPayment(const MyMoneyMoney& finalPayment)
   setValue("final-payment", finalPayment.toString());
 }
 
-const unsigned int MyMoneyAccountLoan::term(void) const
+unsigned int MyMoneyAccountLoan::term(void) const
 {
   return value("term").toUInt();
 }
@@ -498,6 +520,11 @@ void MyMoneyAccount::writeXML(QDomDocument& document, QDomElement& parent) const
     el.appendChild(onlinesettings);
   }
 
+  // FIXME drop the lastStatementDate record from the KVP when it is
+  // not stored there after setLastReconciliationDate() has been changed
+  // See comment there when this will happen
+  // deletePair("lastStatementDate");
+
 
   //Add in Key-Value Pairs for accounts.
   MyMoneyKeyValueContainer::writeXML(document, el);
@@ -586,3 +613,148 @@ void MyMoneyAccount::adjustBalance(const MyMoneySplit& s, bool reverse)
   }
 
 }
+
+QPixmap MyMoneyAccount::accountPixmap(bool reconcileFlag) const
+{
+  QString pixmap;
+
+  switch(accountType()) {
+    default:
+      if(accountGroup() == MyMoneyAccount::Asset)
+        pixmap = "account-types_asset";
+      else
+        pixmap = "account-types_liability";
+      break;
+
+    case MyMoneyAccount::Investment:
+      pixmap = "account-types_investments";
+      break;
+
+    case MyMoneyAccount::Checkings:
+      pixmap = "account-types_checking";
+      break;
+    case MyMoneyAccount::Savings:
+      pixmap = "account-types_savings";
+      break;
+
+    case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Loan:
+      pixmap = "account-types_loan";
+      break;
+
+    case MyMoneyAccount::CreditCard:
+      pixmap = "account-types_credit-card";
+      break;
+
+    case MyMoneyAccount::Asset:
+      pixmap = "account-types_asset";
+      break;
+
+    case MyMoneyAccount::Cash:
+      pixmap = "account-types_cash";
+      break;
+  }
+
+  QPixmap result = DesktopIcon(pixmap);
+  if(isClosed()) {
+    QPixmap overlay = DesktopIcon("account-types_closed");
+    bitBlt(&result, 0, 0, &overlay, 0, 0, overlay.width(), overlay.height(), Qt::CopyROP, false);
+  } else if(reconcileFlag) {
+    QPixmap overlay = DesktopIcon("account-types_reconcile");
+    bitBlt(&result, 0, 0, &overlay, 0, 0, overlay.width(), overlay.height(), Qt::CopyROP, false);
+  }
+  return result;
+}
+
+QPixmap MyMoneyAccount::accountGroupPixmap(bool reconcileFlag) const
+{
+  QString icon;
+  switch (accountGroup())
+  {
+    case MyMoneyAccount::Income:
+      icon = "account-types_income";
+      break;
+    case MyMoneyAccount::Expense:
+      icon = "account-types_expense";
+      break;
+    case MyMoneyAccount::Liability:
+      icon = "account-types_liability";
+      break;
+    case MyMoneyAccount::Asset:
+      icon = "account-types_asset";
+      break;
+    default:
+      icon = "account";
+      break;
+  }
+
+  QPixmap result = QPixmap(KGlobal::dirs()->findResource("appdata",QString( "icons/hicolor/22x22/actions/%1.png").arg(icon)));
+  if(isClosed()) {
+    QPixmap closed = QPixmap(KGlobal::dirs()->findResource("appdata",QString( "icons/hicolor/22x22/actions/account-types_closed.png")));
+    bitBlt(&result, 0, 0, &closed, 0, 0, closed.width(), closed.height(), Qt::CopyROP, false);
+  } else if(reconcileFlag) {
+    QPixmap closed = QPixmap(KGlobal::dirs()->findResource("appdata",QString( "icons/hicolor/22x22/actions/account-types_reconcile.png")));
+    bitBlt(&result, 0, 0, &closed, 0, 0, closed.width(), closed.height(), Qt::CopyROP, false);
+  }
+  return result;
+}
+
+QString MyMoneyAccount::accountTypeToString(const MyMoneyAccount::accountTypeE accountType)
+{
+  QString returnString;
+
+  switch (accountType) {
+    case MyMoneyAccount::Checkings:
+      returnString = i18n("Checking");
+      break;
+    case MyMoneyAccount::Savings:
+      returnString = i18n("Savings");
+      break;
+    case MyMoneyAccount::CreditCard:
+      returnString = i18n("Credit Card");
+      break;
+    case MyMoneyAccount::Cash:
+      returnString = i18n("Cash");
+      break;
+    case MyMoneyAccount::Loan:
+      returnString = i18n("Loan");
+      break;
+    case MyMoneyAccount::CertificateDep:
+      returnString = i18n("Certificate of Deposit");
+      break;
+    case MyMoneyAccount::Investment:
+      returnString = i18n("Investment");
+      break;
+    case MyMoneyAccount::MoneyMarket:
+      returnString = i18n("Money Market");
+      break;
+    case MyMoneyAccount::Asset:
+      returnString = i18n("Asset");
+      break;
+    case MyMoneyAccount::Liability:
+      returnString = i18n("Liability");
+      break;
+    case MyMoneyAccount::Currency:
+      returnString = i18n("Currency");
+      break;
+    case MyMoneyAccount::Income:
+      returnString = i18n("Income");
+      break;
+    case MyMoneyAccount::Expense:
+      returnString = i18n("Expense");
+      break;
+    case MyMoneyAccount::AssetLoan:
+      returnString = i18n("Investment Loan");
+      break;
+    case MyMoneyAccount::Stock:
+      returnString = i18n("Stock");
+      break;
+    case MyMoneyAccount::Equity:
+      returnString = i18n("Equity");
+      break;
+    default:
+      returnString = i18n("Unknown");
+  }
+
+  return returnString;
+}
