@@ -30,6 +30,7 @@
 #include <qvaluelist.h>
 #include <qstringlist.h>
 #include <qdom.h>
+#include <qpixmap.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -141,7 +142,7 @@ public:
   /**
     * This operator tests for equality of two MyMoneyAccount objects
     */
-  const bool operator == (const MyMoneyAccount &) const;
+  bool operator == (const MyMoneyAccount &) const;
 
   /**
     * This converts the account type into one of the four
@@ -175,9 +176,9 @@ public:
     * @param type actual account type
     * @return accountTypeE of major account type
     */
-  static const MyMoneyAccount::accountTypeE accountGroup(MyMoneyAccount::accountTypeE type);
+  static MyMoneyAccount::accountTypeE accountGroup(MyMoneyAccount::accountTypeE type);
 
-  const MyMoneyAccount::accountTypeE accountGroup(void) const;
+  MyMoneyAccount::accountTypeE accountGroup(void) const;
 
   /**
     * This method returns the id of the MyMoneyInstitution object this account
@@ -247,7 +248,7 @@ public:
     * This method returns the number of entries in the m_accountList
     * @return number of entries in the accountList
     */
-  const int accountCount(void) const { return m_accountList.count(); };
+  int accountCount(void) const { return m_accountList.count(); };
 
   /**
     * This method is used to add an account id as sub-ordinate account
@@ -516,6 +517,26 @@ public:
    */
   QString brokerageName(void) const;
 
+  /**
+   * @return a pixmap using IconDesktop for the account type
+   */
+  QPixmap accountPixmap(bool reconcileFlag = false) const;
+
+  /**
+   * @return a 22x22 pixmap for the account group type
+   */
+  QPixmap accountGroupPixmap(bool reconcileFlag = false) const;
+
+  /**
+   * This method is used to convert the internal representation of
+   * an account type into a human readable format
+   *
+   * @param accountType numerical representation of the account type.
+   *                    For possible values, see MyMoneyAccount::accountTypeE
+   * @return QString representing the human readable form
+   */
+  static QString accountTypeToString(const MyMoneyAccount::accountTypeE accountType);
+
 private:
   /**
     * This member variable identifies the type of account
@@ -632,19 +653,19 @@ public:
   void setLoanAmount(const MyMoneyMoney& amount);
   const MyMoneyMoney interestRate(const QDate& date) const;
   void setInterestRate(const QDate& date, const MyMoneyMoney& rate);
-  const interestDueE interestCalculation(void) const;
+  interestDueE interestCalculation(void) const;
   void setInterestCalculation(const interestDueE onReception);
   const QDate nextInterestChange(void) const;
   void setNextInterestChange(const QDate& date);
   const QCString schedule(void) const;
   void setSchedule(const QCString& sched);
-  const bool fixedInterestRate(void) const;
+  bool fixedInterestRate(void) const;
   void setFixedInterestRate(const bool fixed);
   const MyMoneyMoney finalPayment(void) const;
   void setFinalPayment(const MyMoneyMoney& finalPayment);
-  const unsigned int term(void) const;
+  unsigned int term(void) const;
   void setTerm(const unsigned int payments);
-  const int interestChangeFrequency(int* unit = 0) const;
+  int interestChangeFrequency(int* unit = 0) const;
   void setInterestChangeFrequency(const int amount, const int unit);
   const MyMoneyMoney periodicPayment(void) const;
   void setPeriodicPayment(const MyMoneyMoney& payment);
