@@ -20,6 +20,7 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #define private public
+#define protected public
 #include "mymoneyaccount.h"
 #undef private
 
@@ -30,13 +31,16 @@ class MyMoneyAccountTest : public CppUnit::TestFixture  {
 	CPPUNIT_TEST(testSetFunctions);
 	CPPUNIT_TEST(testCopyConstructor);
 	CPPUNIT_TEST(testAssignmentConstructor);
-/* removed with MyMoneyAccount::Transaction
-	CPPUNIT_TEST(testTransactionList);
-	CPPUNIT_TEST(testTransactionRetrieval);
-	CPPUNIT_TEST(testBalance);
-*/
 	CPPUNIT_TEST(testSubAccounts);
 	CPPUNIT_TEST(testEquality);
+	CPPUNIT_TEST(testWriteXML);
+	CPPUNIT_TEST(testReadXML);
+	CPPUNIT_TEST(testHasReferenceTo);
+	CPPUNIT_TEST(testAdjustBalance);
+	CPPUNIT_TEST(testSetClosed);
+	CPPUNIT_TEST(testIsIncomeExpense);
+	CPPUNIT_TEST(testIsAssetLiability);
+	CPPUNIT_TEST(testIsLoan);
 	CPPUNIT_TEST_SUITE_END();
 
 protected:
@@ -51,11 +55,16 @@ public:
 	void testSetFunctions();
 	void testCopyConstructor();
 	void testAssignmentConstructor();
-	void testTransactionList();
-	void testTransactionRetrieval();
-	void testBalance();
 	void testSubAccounts();
 	void testEquality();
+	void testWriteXML();
+	void testReadXML();
+	void testHasReferenceTo();
+	void testAdjustBalance();
+	void testSetClosed();
+	void testIsIncomeExpense();
+	void testIsAssetLiability();
+	void testIsLoan();
 };
 
 #endif
