@@ -87,6 +87,7 @@ MyMoneyFile::~MyMoneyFile()
 {
   _instance = 0;
   delete d;
+  delete m_storage;
 }
 
 MyMoneyFile::MyMoneyFile(IMyMoneyStorage *storage) :
@@ -112,6 +113,7 @@ void MyMoneyFile::attachStorage(IMyMoneyStorage* const storage)
   // and the whole cache
   d->m_cache.clear(storage);
   d->m_priceCache.clear();
+  preloadCache();
 
   // notify application about new data availability
   emit dataChanged();
@@ -152,10 +154,12 @@ void MyMoneyFile::commitTransaction(void)
 {
   checkTransaction(__PRETTY_FUNCTION__);
 
-  m_storage->commitTransaction();
+  bool changed = m_storage->commitTransaction();
   d->m_inTransaction = false;
   preloadCache();
-  emit dataChanged();
+  if(changed) {
+    emit dataChanged();
+  }
 }
 
 void MyMoneyFile::rollbackTransaction(void)
@@ -389,6 +393,9 @@ void MyMoneyFile::removeTransaction(const MyMoneyTransaction& transaction)
 
   // scan the splits again to update notification list
   for(it_s = tr.splits().begin(); it_s != tr.splits().end(); ++it_s) {
+    MyMoneyAccount acc = account((*it_s).accountId());
+    if(acc.isClosed())
+      throw new MYMONEYEXCEPTION(i18n("Cannot remove transaction that references a closed account."));
     addNotification((*it_s).accountId());
     addNotification((*it_s).payeeId());
   }
@@ -397,14 +404,14 @@ void MyMoneyFile::removeTransaction(const MyMoneyTransaction& transaction)
 }
 
 
-const bool MyMoneyFile::hasActiveSplits(const QCString& id) const
+bool MyMoneyFile::hasActiveSplits(const QCString& id) const
 {
   checkStorage();
 
   return m_storage->hasActiveSplits(id);
 }
 
-const bool MyMoneyFile::isStandardAccount(const QCString& id) const
+bool MyMoneyFile::isStandardAccount(const QCString& id) const
 {
   checkStorage();
 
@@ -460,6 +467,7 @@ void MyMoneyFile::removeAccount(const MyMoneyAccount& account)
   addNotification(acc.id(), false);
 
   m_storage->removeAccount(acc);
+  d->m_cache.clear(acc.id());
 }
 
 void MyMoneyFile::removeAccountList(const QCStringList& account_list, unsigned int level) {
@@ -665,7 +673,7 @@ void MyMoneyFile::createOpeningBalanceTransaction(const MyMoneyAccount& acc, con
   }
 }
 
-QCString MyMoneyFile::openingBalanceTransaction(const MyMoneyAccount& acc) const
+const QCString MyMoneyFile::openingBalanceTransaction(const MyMoneyAccount& acc) const
 {
   QCString result;
 
@@ -855,14 +863,14 @@ void MyMoneyFile::addTransaction(MyMoneyTransaction& transaction)
   }
 }
 
-const MyMoneyTransaction& MyMoneyFile::transaction(const QCString& id) const
+const MyMoneyTransaction MyMoneyFile::transaction(const QCString& id) const
 {
   checkStorage();
 
   return m_storage->transaction(id);
 }
 
-const MyMoneyTransaction& MyMoneyFile::transaction(const QCString& account, const int idx) const
+const MyMoneyTransaction MyMoneyFile::transaction(const QCString& account, const int idx) const
 {
   checkStorage();
 
@@ -890,7 +898,7 @@ const MyMoneyPayee& MyMoneyFile::payeeByName(const QString& name) const
 {
   checkStorage();
 
-  return m_storage->payeeByName(name);
+  return d->m_cache.payee(m_storage->payeeByName(name).id());
 }
 
 void MyMoneyFile::modifyPayee(const MyMoneyPayee& payee)
@@ -921,6 +929,16 @@ void MyMoneyFile::accountList(QValueList<MyMoneyAccount>& list, const QCStringLi
 {
   if(idlist.isEmpty()) {
     d->m_cache.account(list);
+
+#if 0
+    // TODO: I have no idea what this was good for, but it caused the networth report
+    //       to show double the numbers so I commented it out (ipwizard, 2008-05-24)
+    if (m_storage && (list.isEmpty() || list.size() != m_storage->accountCount())) {
+      m_storage->accountList(list);
+      d->m_cache.preloadAccount(list);
+    }
+#endif
+
     QValueList<MyMoneyAccount>::Iterator it;
     QValueList<MyMoneyAccount>::Iterator next;
     for(it = list.begin(); it != list.end(); ) {
@@ -961,7 +979,7 @@ const QValueList<MyMoneyInstitution> MyMoneyFile::institutionList(void) const
 }
 
 // general get functions
-const MyMoneyPayee& MyMoneyFile::user(void) const { checkStorage(); return m_storage->user(); }
+const MyMoneyPayee MyMoneyFile::user(void) const { checkStorage(); return m_storage->user(); }
 
 // general set functions
 void MyMoneyFile::setUser(const MyMoneyPayee& user)
@@ -989,7 +1007,7 @@ void MyMoneyFile::setDirty(void) const
   m_storage->setDirty();
 }
 
-const unsigned int MyMoneyFile::accountCount(void) const
+unsigned int MyMoneyFile::accountCount(void) const
 {
   checkStorage();
 
@@ -1008,38 +1026,38 @@ const MyMoneyAccount& MyMoneyFile::liability(void) const
 {
   checkStorage();
 
-  return m_storage->liability();
+  return d->m_cache.account (STD_ACC_LIABILITY);
 }
 
 const MyMoneyAccount& MyMoneyFile::asset(void) const
 {
   checkStorage();
 
-  return m_storage->asset();
+  return d->m_cache.account (STD_ACC_ASSET);
 }
 
 const MyMoneyAccount& MyMoneyFile::expense(void) const
 {
   checkStorage();
 
-  return m_storage->expense();
+  return d->m_cache.account (STD_ACC_EXPENSE);
 }
 
 const MyMoneyAccount& MyMoneyFile::income(void) const
 {
   checkStorage();
 
-  return m_storage->income();
+  return d->m_cache.account (STD_ACC_INCOME);
 }
 
 const MyMoneyAccount& MyMoneyFile::equity(void) const
 {
   checkStorage();
 
-  return m_storage->equity();
+  return d->m_cache.account (STD_ACC_EQUITY);
 }
 
-const unsigned int MyMoneyFile::transactionCount(const QCString& account) const
+unsigned int MyMoneyFile::transactionCount(const QCString& account) const
 {
   checkStorage();
 
@@ -1053,7 +1071,7 @@ const QMap<QCString, unsigned long> MyMoneyFile::transactionCountMap(void) const
   return m_storage->transactionCountMap();
 }
 
-const unsigned int MyMoneyFile::institutionCount(void) const
+unsigned int MyMoneyFile::institutionCount(void) const
 {
   checkStorage();
 
@@ -1124,7 +1142,7 @@ void MyMoneyFile::transactionList(QValueList<MyMoneyTransaction>& list, MyMoneyT
   m_storage->transactionList(list, filter);
 }
 
-QValueList<MyMoneyTransaction> MyMoneyFile::transactionList(MyMoneyTransactionFilter& filter) const
+const QValueList<MyMoneyTransaction> MyMoneyFile::transactionList(MyMoneyTransactionFilter& filter) const
 {
   QValueList<MyMoneyTransaction> list;
   transactionList(list, filter);
@@ -1302,9 +1320,7 @@ void MyMoneyFile::removeSchedule(const MyMoneySchedule& sched)
 
 const MyMoneySchedule MyMoneyFile::schedule(const QCString& id) const
 {
-  checkStorage();
-
-  return m_storage->schedule(id);
+  return d->m_cache.schedule(id);
 }
 
 const QValueList<MyMoneySchedule> MyMoneyFile::scheduleList(
@@ -1574,9 +1590,15 @@ const QStringList MyMoneyFile::consistencyCheck(void)
         const MyMoneyAccount& acc = this->account(s.accountId());
         if(t.commodity() == acc.currencyId()
         && s.shares().reduce() != s.value().reduce()) {
-          s.setValue(s.shares());
+          // use the value as master if the transaction is balanced
+          if(t.splitSum().isZero()) {
+            s.setShares(s.value());
+            rc << i18n("  * shares set to value in split of transaction '%1'.").arg(t.id());
+          } else {
+            s.setValue(s.shares());
+            rc << i18n("  * value set to shares in split of transaction '%1'.").arg(t.id());
+          }
           sChanged = true;
-          rc << i18n("  * value set to shares in split of transaction '%1'.").arg(t.id());
           ++problemCount;
         }
       } catch(MyMoneyException *e) {
@@ -1629,6 +1651,13 @@ const QStringList MyMoneyFile::consistencyCheck(void)
         ++problemCount;
       }
 
+      // make sure, we don't have a bankid stored with a split in a schedule
+      if(!(*it_s).bankID().isEmpty()) {
+        s.setBankID(QString());
+        sChanged = true;
+        rc << i18n("  * Removed bankid from split in scheduled transaction '%1'.").arg((*it_sch).name());
+        ++problemCount;
+      }
 
       // make sure, that shares and value have the same number if they
       // represent the same currency.
@@ -1636,9 +1665,15 @@ const QStringList MyMoneyFile::consistencyCheck(void)
         const MyMoneyAccount& acc = this->account(s.accountId());
         if(t.commodity() == acc.currencyId()
         && s.shares().reduce() != s.value().reduce()) {
-          s.setValue(s.shares());
-          sChanged = tChanged = true;
-          rc << i18n("  * value set to shares in split of schedule '%1'.").arg(sch.name());
+          // use the value as master if the transaction is balanced
+          if(t.splitSum().isZero()) {
+            s.setShares(s.value());
+            rc << i18n("  * shares set to value in split in schedule '%1'.").arg((*it_sch).name());
+          } else {
+            s.setValue(s.shares());
+            rc << i18n("  * value set to shares in split in schedule '%1'.").arg((*it_sch).name());
+          }
+          sChanged = true;
           ++problemCount;
         }
       } catch(MyMoneyException *e) {
@@ -1700,7 +1735,7 @@ const QStringList MyMoneyFile::consistencyCheck(void)
   return rc;
 }
 
-QCString MyMoneyFile::createCategory(const MyMoneyAccount& base, const QString& name)
+const QCString MyMoneyFile::createCategory(const MyMoneyAccount& base, const QString& name)
 {
   checkTransaction(__PRETTY_FUNCTION__);
 
@@ -1751,7 +1786,7 @@ QCString MyMoneyFile::createCategory(const MyMoneyAccount& base, const QString&
   return categoryToAccount(name);
 }
 
-QValueList<MyMoneySchedule> MyMoneyFile::scheduleListEx( int scheduleTypes,
+const QValueList<MyMoneySchedule> MyMoneyFile::scheduleListEx( int scheduleTypes,
                                               int scheduleOcurrences,
                                               int schedulePaymentTypes,
                                               QDate startDate,
@@ -1797,7 +1832,7 @@ void MyMoneyFile::removeSecurity(const MyMoneySecurity& security)
   m_storage->removeSecurity(security);
 }
 
-const MyMoneySecurity MyMoneyFile::security(const QCString& id) const
+const MyMoneySecurity& MyMoneyFile::security(const QCString& id) const
 {
   if(id.isEmpty())
     return baseCurrency();
@@ -1863,8 +1898,10 @@ const MyMoneySecurity& MyMoneyFile::currency(const QCString& id) const
   if(id.isEmpty())
     return baseCurrency();
 
-  checkStorage();
-  return m_storage->currency(id);
+  const MyMoneySecurity& curr = d->m_cache.security(id);
+  if(curr.id().isEmpty())
+    throw new MYMONEYEXCEPTION("Currency not found.");
+  return curr;
 }
 
 const QValueList<MyMoneySecurity> MyMoneyFile::currencyList(void) const
@@ -1959,7 +1996,7 @@ const MyMoneyPriceList MyMoneyFile::priceList(void) const
   return m_storage->priceList();
 }
 
-const bool MyMoneyFile::hasAccount(const QCString& id, const QString& name) const
+bool MyMoneyFile::hasAccount(const QCString& id, const QString& name) const
 {
   MyMoneyAccount acc = d->m_cache.account(id);
   QCStringList list = acc.accountList();
@@ -2009,7 +2046,7 @@ unsigned MyMoneyFile::countReports(void) const
   return m_storage->countReports();
 }
 
-MyMoneyReport MyMoneyFile::report( const QCString& id ) const
+const MyMoneyReport MyMoneyFile::report( const QCString& id ) const
 {
   checkStorage();
 
@@ -2043,7 +2080,7 @@ void MyMoneyFile::addBudget( MyMoneyBudget& budget )
   m_storage->addBudget( budget );
 }
 
-const MyMoneyBudget& MyMoneyFile::budgetByName(const QString& name) const
+const MyMoneyBudget MyMoneyFile::budgetByName(const QString& name) const
 {
   checkStorage();
 
@@ -2069,7 +2106,7 @@ unsigned MyMoneyFile::countBudgets(void) const
   return m_storage->countBudgets();
 }
 
-MyMoneyBudget MyMoneyFile::budget( const QCString& id ) const
+const MyMoneyBudget MyMoneyFile::budget( const QCString& id ) const
 {
   checkStorage();
 
@@ -2093,7 +2130,7 @@ bool MyMoneyFile::isReferenced(const MyMoneyObject& obj, const MyMoneyFileBitArr
   return m_storage->isReferenced(obj, skipChecks);
 }
 
-const bool MyMoneyFile::checkNoUsed(const QCString& accId, const QString& no) const
+bool MyMoneyFile::checkNoUsed(const QCString& accId, const QString& no) const
 {
   // by definition, an empty string or a non-numeric string is not used
   QRegExp exp(QString("(.*\\D)?(\\d+)(\\D.*)?"));
@@ -2120,7 +2157,7 @@ const bool MyMoneyFile::checkNoUsed(const QCString& accId, const QString& no) co
   return false;
 }
 
-QString MyMoneyFile::highestCheckNo(const QCString& accId) const
+const QString MyMoneyFile::highestCheckNo(const QCString& accId) const
 {
   unsigned64 lno = 0, cno;
   QString no;
@@ -2167,6 +2204,7 @@ void MyMoneyFile::preloadCache(void)
   d->m_cache.preloadPayee(m_storage->payeeList());
   d->m_cache.preloadInstitution(m_storage->institutionList());
   d->m_cache.preloadSecurity(m_storage->securityList() + m_storage->currencyList());
+  d->m_cache.preloadSchedule(m_storage->scheduleList());
 }
 
 bool MyMoneyFile::isTransfer(const MyMoneyTransaction& t) const
