@@ -117,10 +117,11 @@ class MyMoneyFilePrivate;
   * the currency selected by the user as base currency. If a currency
   * reference is emtpy, it will usually be interpreted as baseCurrency().
   *
-  * The methods liability(), asset(), expense() and income() are used to
-  * retrieve the four standard accounts. isStandardAccount() checks if a
-  * given accountId references one of the or not. setAccountName() is used
-  * to specify a name for the standard accounts from the GUI.
+  * The methods liability(), asset(), expense(), income() and equity() are
+  * used to retrieve the five standard accounts. isStandardAccount()
+  * checks if a given accountId references one of the or not.
+  * setAccountName() is used to specify a name for the standard accounts
+  * from the GUI.
   *
   * The MyMoneyFile object emits the dataChanged() signal when data
   * has been changed.
@@ -154,7 +155,7 @@ public:
     * This is the function to access the MyMoneyFile object.
     * It returns a pointer to the single instance of the object.
     */
-  static inline MyMoneyFile* const instance() { return &file; }
+  static inline MyMoneyFile* instance() { return &file; }
 
   /**
     * This is the destructor for any MyMoneyFile object
@@ -171,7 +172,7 @@ public:
   MyMoneyFile(IMyMoneyStorage *storage);
 
   // general get functions
-  const MyMoneyPayee& user(void) const;
+  const MyMoneyPayee user(void) const;
 
   // general set functions
   void setUser(const MyMoneyPayee& user);
@@ -223,7 +224,7 @@ public:
     * @return const pointer to the current attached storage object.
     *         If no object is attached, returns 0.
     */
-  IMyMoneyStorage* const storage(void) const { return m_storage; };
+  IMyMoneyStorage* storage(void) const { return m_storage; };
 
   /**
     * This method must be called before any single change or a series of changes
@@ -332,7 +333,7 @@ public:
     *            should be retrieved
     * @return QCString id for the transaction, or QCString() if no transaction exists
     */
-  QCString openingBalanceTransaction(const MyMoneyAccount& acc) const;
+  const QCString openingBalanceTransaction(const MyMoneyAccount& acc) const;
 
   /**
     * This method returns an indicator if the MyMoneyFile object has been
@@ -435,7 +436,7 @@ public:
     *
     * @return the number of modified splits
     */
-  const unsigned int moveSplits(const QCString& oldAccount, const QCString& newAccount);
+  unsigned int moveSplits(const QCString& oldAccount, const QCString& newAccount);
 
   /**
     * This method is used to determince, if the account with the
@@ -444,7 +445,7 @@ public:
     * @param id id of the account to be checked for
     * @return true if account is referenced, false otherwise
     */
-  const bool hasActiveSplits(const QCString& id) const;
+  bool hasActiveSplits(const QCString& id) const;
 
   /**
     * This method is used to check whether a given
@@ -455,7 +456,7 @@ public:
     * @param id account id
     * @return true if account-id is one of the standards, false otherwise
     */
-  const bool isStandardAccount(const QCString& id) const;
+  bool isStandardAccount(const QCString& id) const;
 
   /**
     * Returns @a true, if transaction @t is a transfer transaction.
@@ -552,7 +553,7 @@ public:
     * @param id id of transaction as QString.
     * @return reference to the requested transaction
     */
-  const MyMoneyTransaction& transaction(const QCString& id) const;
+  const MyMoneyTransaction transaction(const QCString& id) const;
 
   /**
     * This method is used to extract a transaction from the file global
@@ -562,7 +563,7 @@ public:
     * @param idx number of transaction in this account
     * @return reference to MyMoneyTransaction object
     */
-  const MyMoneyTransaction& transaction(const QCString& account, const int idx) const;
+  const MyMoneyTransaction transaction(const QCString& account, const int idx) const;
 
   /**
     * This method is used to pull a list of transactions from the file
@@ -577,7 +578,7 @@ public:
     *
     * @return set of transactions in form of a QValueList<MyMoneyTransaction>
     */
-  QValueList<MyMoneyTransaction> transactionList(MyMoneyTransactionFilter& filter) const;
+  const QValueList<MyMoneyTransaction> transactionList(MyMoneyTransactionFilter& filter) const;
 
   void transactionList(QValueList<MyMoneyTransaction>& list, MyMoneyTransactionFilter& filter) const;
 
@@ -628,7 +629,7 @@ public:
     *
     * @return number of transactions in journal/account
     */
-  const unsigned int transactionCount(const QCString& account = QCString()) const;
+  unsigned int transactionCount(const QCString& account = QCString()) const;
 
   /**
     * This method returns a QMap filled with the number of transactions
@@ -647,7 +648,7 @@ public:
     *
     * @return number of institutions known to file
     */
-  const unsigned int institutionCount(void) const;
+  unsigned int institutionCount(void) const;
 
   /**
     * This method returns the number of accounts currently known to file
@@ -655,7 +656,7 @@ public:
     *
     * @return number of accounts currently known inside a MyMoneyFile object
     */
-  const unsigned int accountCount(void) const;
+  unsigned int accountCount(void) const;
 
   /**
     * Returns the institution of a given ID
@@ -911,7 +912,7 @@ public:
     * according to the filter criteria passed as arguments.
     *
     * @param accountId only search for scheduled transactions that reference
-    *                  accound @p accountId. If accountId is the empty string,
+    *                  account @p accountId. If accountId is the empty string,
     *                  this filter is off. Default is @p QCString().
     * @param type      only schedules of type @p type are searched for.
     *                  See MyMoneySchedule::typeE for details.
@@ -973,9 +974,9 @@ public:
     * @exception An exception will be thrown, if @p base is not equal
     *            expense() or income().
     **/
-  QCString createCategory(const MyMoneyAccount& base, const QString& name);
+  const QCString createCategory(const MyMoneyAccount& base, const QString& name);
 
-  QValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
+  const QValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
                                               int scheduleOcurrences,
                                               int schedulePaymentTypes,
                                               QDate startDate,
@@ -1023,7 +1024,7 @@ public:
     * @param id QCString containing the id of the MyMoneySecurity object
     * @return MyMoneySecurity object
     */
-  const MyMoneySecurity security(const QCString& id) const;
+  const MyMoneySecurity& security(const QCString& id) const;
 
   /**
     * This method is used to retrieve a list of all MyMoneySecurity objects.
@@ -1158,7 +1159,7 @@ public:
     * @retval true account with name @p name found as subaccounts
     * @retval false no subaccount present with that name
     */
-  const bool hasAccount(const QCString& id, const QString& name) const;
+  bool hasAccount(const QCString& id, const QString& name) const;
 
   /**
     * This method is used to retrieve the list of all reports
@@ -1209,7 +1210,7 @@ public:
     * @param id QCString containing the id of the MyMoneyReport object
     * @return MyMoneyReport object
     */
-  MyMoneyReport report( const QCString& id ) const;
+  const MyMoneyReport report( const QCString& id ) const;
 
   /**
     * This method is used to remove an existing MyMoneyReport object
@@ -1253,7 +1254,7 @@ public:
     *
     * @return MyMoneyBudget refernce to object of budget
     */
-  const MyMoneyBudget& budgetByName(const QString& budget) const;
+  const MyMoneyBudget budgetByName(const QString& budget) const;
 
 
   /**
@@ -1283,7 +1284,7 @@ public:
     * @param id QCString containing the id of the MyMoneyBudget object
     * @return MyMoneyBudget object
     */
-  MyMoneyBudget budget( const QCString& id ) const;
+  const MyMoneyBudget budget( const QCString& id ) const;
 
   /**
     * This method is used to remove an existing MyMoneyBudget object
@@ -1319,7 +1320,7 @@ public:
     * @retval false @p no is not in use
     * @retval true @p no is already assigned
     */
-  const bool checkNoUsed(const QCString& accId, const QString& no) const;
+  bool checkNoUsed(const QCString& accId, const QString& no) const;
 
   /**
     * This method returns the highest assigned check no for
@@ -1328,7 +1329,7 @@ public:
     * @param accId id of account to be scanned
     * @return highest check no. used
     */
-  QString highestCheckNo(const QCString& accId) const;
+  const QString highestCheckNo(const QCString& accId) const;
 
   /**
     * Clear all internal caches (used internally for performance measurements)
