@@ -38,7 +38,10 @@
 #include "mymoneyforecast.h"
 #include "mymoneytransactionfilter.h"
 
-MyMoneyForecast::MyMoneyForecast()
+MyMoneyForecast::MyMoneyForecast() :
+    m_skipOpeningDate(true),
+    m_includeUnusedAccounts(false),
+    m_forecastDone(false)
 {
   setForecastCycles(KMyMoneyGlobalSettings::forecastCycles());
   setAccountsCycle(KMyMoneyGlobalSettings::forecastAccountCycle());
@@ -48,7 +51,8 @@ MyMoneyForecast::MyMoneyForecast()
   setBeginForecastDay(KMyMoneyGlobalSettings::beginForecastDay());
   setForecastMethod(KMyMoneyGlobalSettings::forecastMethod());
   setHistoryMethod(KMyMoneyGlobalSettings::historyMethod());
-  setSkipOpeningDate(true);
+  setIncludeFutureTransactions(KMyMoneyGlobalSettings::includeFutureTransactions());
+  setIncludeScheduledTransactions(KMyMoneyGlobalSettings::includeScheduledTransactions());
 }
 
 
@@ -86,16 +90,20 @@ void MyMoneyForecast::doForecast()
 
   switch(fMethod)
   {
-    case SCHEDULED:
+    case eScheduled:
       doFutureScheduledForecast();
+      calculateScheduledDailyBalances();
       break;
-    case HISTORIC:
+    case eHistoric:
       pastTransactions();
-      calculateDailyBalances();
+      calculateHistoricDailyBalances();
       break;
     default:
       break;
   }
+
+  //flag the forecast as done
+  m_forecastDone = true;
 }
 
 MyMoneyForecast::~MyMoneyForecast()
@@ -139,7 +147,8 @@ void MyMoneyForecast::pastTransactions()
   }
 
   //purge those accounts with no transactions on the period
-  purgeForecastAccountsList(m_accountListPast);
+  if(isIncludingUnusedAccounts() == false)
+    purgeForecastAccountsList(m_accountListPast);
 
   //calculate running sum
   QMap<QCString, QCString>::Iterator it_n;
@@ -345,7 +354,7 @@ MyMoneyMoney MyMoneyForecast::calculateAccountTrend(const MyMoneyAccount& acc, i
   return accTrend;
 }
 
-MyMoneyMoney MyMoneyForecast::accountMovingAverage(const MyMoneyAccount acc, const int trendDay, const int forecastTerms)
+MyMoneyMoney MyMoneyForecast::accountMovingAverage(const MyMoneyAccount &acc, const int trendDay, const int forecastTerms)
 {
   //Calculate a daily trend for the account based on the accounts of a given number of terms
   //With a term of 1 month and 3 terms, it calculates the trend taking the transactions occured at that day and the day before,
@@ -362,7 +371,7 @@ MyMoneyMoney MyMoneyForecast::accountMovingAverage(const MyMoneyAccount acc, con
   return balanceVariation / MyMoneyMoney(forecastTerms,1);
 }
 
-MyMoneyMoney MyMoneyForecast::accountWeightedMovingAverage(const MyMoneyAccount acc, const int trendDay, const int totalWeight)
+MyMoneyMoney MyMoneyForecast::accountWeightedMovingAverage(const MyMoneyAccount &acc, const int trendDay, const int totalWeight)
 {
   MyMoneyMoney balanceVariation;
 
@@ -376,7 +385,7 @@ MyMoneyMoney MyMoneyForecast::accountWeightedMovingAverage(const MyMoneyAccount
   return balanceVariation / MyMoneyMoney(totalWeight, 1);
 }
 
-void MyMoneyForecast::calculateDailyBalances()
+void MyMoneyForecast::calculateHistoricDailyBalances()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -387,24 +396,8 @@ void MyMoneyForecast::calculateDailyBalances()
   for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
     MyMoneyAccount acc = file->account(*it_n);
 
-    //Get current account balance
-    if ( acc.isInvest() ) { //investments require special treatment
-      //get the security id of that account
-      MyMoneySecurity undersecurity = file->security ( acc.currencyId() );
-      if ( ! undersecurity.isCurrency() ) //only do it if the security is not an actual currency
-      {
-        MyMoneyMoney rate = MyMoneyMoney ( 1, 1 ); //set the default value
-        //get te
-        MyMoneyPrice price = file->price ( undersecurity.id(), undersecurity.tradingCurrency(), QDate::currentDate() );
-        if ( price.isValid() )
-        {
-          rate = price.rate ( undersecurity.tradingCurrency() );
-        }
-        m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate()) * rate;
-      }
-    } else {
-      m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate());
-    }
+    //set the starting balance of the account
+    setStartingBalance(acc);
 
     for(QDate f_day = forecastStartDate(); f_day <= forecastEndDate(); ) {
       for(int t_day = 1; t_day <= accountsCycle(); ++t_day) {
@@ -424,7 +417,7 @@ MyMoneyMoney MyMoneyForecast::forecastBalance(const MyMoneyAccount& acc, QDate f
 {
 
   dailyBalances balance;
-  MyMoneyMoney MM_amount;
+  MyMoneyMoney MM_amount = MyMoneyMoney(0,1);
 
   //Check if acc is not a forecast account, return 0
   if ( !isForecastAccount ( acc ) )
@@ -455,8 +448,52 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
-  //QDate endDate = forecastEndDate();
+  if(isIncludingFutureTransactions())
+    addFutureTransactions();
+
+  if(isIncludingScheduledTransactions())
+    addScheduledTransactions();
+
+  //do not show accounts with no transactions
+  if(!isIncludingUnusedAccounts())
+    purgeForecastAccountsList(m_accountList);
+
+  //adjust value of investments to deep currency
+  QMap<QCString, QCString>::ConstIterator it_n;
+  for ( it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n ) {
+    MyMoneyAccount acc = file->account ( *it_n );
+
+    if ( acc.isInvest() ) {
+      //get the id of the security for that account
+      MyMoneySecurity undersecurity = file->security ( acc.currencyId() );
+
+      //only do it if the security is not an actual currency
+      if ( ! undersecurity.isCurrency() )
+      {
+        //set the default value
+        MyMoneyMoney rate = MyMoneyMoney ( 1, 1 );
+        MyMoneyPrice price;
+
+        for (QDate it_day = QDate::currentDate(); it_day <= forecastEndDate(); ) {
+          //get the price for the tradingCurrency that day
+          price = file->price ( undersecurity.id(), undersecurity.tradingCurrency(), it_day );
+          if ( price.isValid() )
+          {
+            rate = price.rate ( undersecurity.tradingCurrency() );
+          }
+          //value is the amount of shares multiplied by the rate of the deep currency
+          m_accountList[acc.id() ][it_day] = m_accountList[acc.id() ][it_day] * rate;
+          it_day = it_day.addDays(1);
+        }
+      }
+    }
+  }
+}
+
+void MyMoneyForecast::addFutureTransactions(void)
+{
   MyMoneyTransactionFilter filter;
+  MyMoneyFile* file = MyMoneyFile::instance();
 
   // collect and process all transactions that have already been entered but
   // are located in the future.
@@ -475,11 +512,11 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
         if(isForecastAccount(acc)) {
           dailyBalances balance;
           balance = m_accountList[acc.id()];
-          balance[(*it_t).postDate()] += (*it_s).shares();
-          // check if this is a new account for us
-          if(m_nameIdx[acc.id()] != acc.id()) {
-            m_nameIdx[acc.id()] = acc.id();
-            balance[QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate());
+          //if it is income, the balance is stored as negative number
+          if(acc.accountType() == MyMoneyAccount::Income) {
+            balance[(*it_t).postDate()] += ((*it_s).shares() * MyMoneyMoney(-1, 1));
+          } else {
+            balance[(*it_t).postDate()] += (*it_s).shares();
           }
           m_accountList[acc.id()] = balance;
         }
@@ -489,25 +526,31 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
 
 #if 0
   QFile trcFile("forecast.csv");
-  trcFile.open(IO_WriteOnly);
-  QTextStream s(&trcFile);
+    trcFile.open(IO_WriteOnly);
+    QTextStream s(&trcFile);
 
-  {
-    s << "Already present transactions\n";
-    QMap<QCString, dailyBalances>::Iterator it_a;
-    QMap<QCString, QCString>::ConstIterator it_n;
-    for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
+    {
+      s << "Already present transactions\n";
+      QMap<QCString, dailyBalances>::Iterator it_a;
+      QMap<QCString, QCString>::ConstIterator it_n;
+      for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
       MyMoneyAccount acc = file->account(*it_n);
       it_a = m_accountList.find(*it_n);
       s << "\"" << acc.name() << "\",";
       for(int i = 0; i < 90; ++i) {
-        s << "\"" << (*it_a)[i].formatMoney("") << "\",";
-      }
-      s << "\n";
+      s << "\"" << (*it_a)[i].formatMoney("") << "\",";
     }
+    s << "\n";
   }
+}
 #endif
 
+}
+
+void MyMoneyForecast::addScheduledTransactions (void)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
   // now process all the schedules that may have an impact
   QValueList<MyMoneySchedule> schedule;
 
@@ -551,11 +594,6 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
               for(it_s = t.splits().begin(); it_s != t.splits().end(); ++it_s ) {
                 MyMoneyAccount acc = file->account((*it_s).accountId());
                 if(isForecastAccount(acc)) {
-                  // check if this is a new account for us and if so, keep the
-                  // current balance in current date of the array
-                  if(m_accountList[acc.id()][QDate::currentDate()].isZero())
-                    m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate());
-
                   // collect all overdues on the first day
                   QDate forecastDate = nextDate;
                   if(QDate::currentDate() >= nextDate)
@@ -588,7 +626,11 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
                   if(QDate::currentDate() >= nextDate)
                     forecastDate = QDate::currentDate().addDays(1);
 
-                  balance[forecastDate] += (*it_s).value();
+                  if(acc.accountType() == MyMoneyAccount::Income) {
+                    balance[forecastDate] += ((*it_s).value() * MyMoneyMoney(-1, 1));
+                  } else {
+                    balance[forecastDate] += (*it_s).value();
+                  }
                   m_accountList[acc.id()] = balance;
                 }
               }
@@ -611,30 +653,34 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
   }
 
 #if 0
-  {
+{
   s << "\n\nAdded scheduled transactions\n";
   QMap<QCString, dailyBalances>::Iterator it_a;
   QMap<QCString, QCString>::ConstIterator it_n;
   for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
-    MyMoneyAccount acc = file->account(*it_n);
-    it_a = m_accountList.find(*it_n);
-    s << "\"" << acc.name() << "\",";
-    for(int i = 0; i < 90; ++i) {
-      s << "\"" << (*it_a)[i].formatMoney("") << "\",";
-    }
-    s << "\n";
-  }
+  MyMoneyAccount acc = file->account(*it_n);
+  it_a = m_accountList.find(*it_n);
+  s << "\"" << acc.name() << "\",";
+  for(int i = 0; i < 90; ++i) {
+    s << "\"" << (*it_a)[i].formatMoney("") << "\",";
   }
+  s << "\n";
+}
+}
 #endif
-  //do not show accounts with no transactions
-  purgeForecastAccountsList(m_accountList);
+}
+
+void MyMoneyForecast::calculateScheduledDailyBalances (void)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
 
   //Calculate account daily balances
   QMap<QCString, QCString>::ConstIterator it_n;
   for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
     MyMoneyAccount acc = file->account(*it_n);
 
-    m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate());//Get current account balance
+    //set the starting balance of the account
+    setStartingBalance(acc);
 
     for(QDate f_day = forecastStartDate(); f_day <= forecastEndDate(); ) {
       MyMoneyMoney balanceDayBefore = m_accountList[acc.id()][(f_day.addDays(-1))];//balance of the day before
@@ -643,32 +689,7 @@ void MyMoneyForecast::doFutureScheduledForecast(void)
     }
   }
 
-    //adjust value of investments to deep currency
-  for ( it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n ) {
-    MyMoneyAccount acc = file->account ( *it_n );
-
-    if ( acc.isInvest() ) {
-      //get the id of the security for that account
-      MyMoneySecurity undersecurity = file->security ( acc.currencyId() );
-      if ( ! undersecurity.isCurrency() ) //only do it if the security is not an actual currency
-      {
-        MyMoneyMoney rate = MyMoneyMoney ( 1, 1 ); //set the default value
-        MyMoneyPrice price;
-
-        for (QDate it_day = QDate::currentDate(); it_day <= forecastEndDate(); ) {
-          //get the price for the tradingCurrency that day
-          price = file->price ( undersecurity.id(), undersecurity.tradingCurrency(), it_day );
-          if ( price.isValid() )
-          {
-            rate = price.rate ( undersecurity.tradingCurrency() );
-          }
-          //value is the amount of shares multiplied by the rate of the deep currency
-          m_accountList[acc.id() ][it_day] = m_accountList[acc.id() ][it_day] * rate;
-          it_day = it_day.addDays(1);
-        }
-      }
-    }
-  }
+  
 }
 
 int MyMoneyForecast::daysToMinimumBalance(const MyMoneyAccount& acc)
@@ -747,7 +768,7 @@ MyMoneyMoney MyMoneyForecast::accountCycleVariation(const MyMoneyAccount& acc)
 {
   MyMoneyMoney cycleVariation;
 
-  if (forecastMethod() == HISTORIC) {
+  if (forecastMethod() == eHistoric) {
     for(int t_day = 1; t_day <= accountsCycle() ; ++t_day) {
       cycleVariation += m_accountTrendList[acc.id()][t_day];
     }
@@ -889,6 +910,9 @@ void MyMoneyForecast::createBudget ( MyMoneyBudget& budget, QDate historyStart,
     throw new MYMONEYEXCEPTION ( "Illegal parameters when trying to create budget" );
   }
 
+  //get forecast method
+  int fMethod = forecastMethod();
+
   //set start date to 1st of month and end dates to last day of month, since we deal with full months in budget
   historyStart = QDate ( historyStart.year(), historyStart.month(), 1 );
   historyEnd = QDate ( historyEnd.year(), historyEnd.month(), historyEnd.daysInMonth() );
@@ -913,17 +937,31 @@ void MyMoneyForecast::createBudget ( MyMoneyBudget& budget, QDate historyStart,
   //do not skip opening date
   setSkipOpeningDate ( false );
 
-  //clear and set accounts list we are going to use. Actually categories, in this case
+  //clear and set accounts list we are going to use. Categories, in this case
   m_nameIdx.clear();
   setBudgetAccountList();
 
-  pastTransactions(); //get all transactions for history period
+  //calculate budget according to forecast method
+  switch(fMethod)
+  {
+    case eScheduled:
+      doFutureScheduledForecast();
+      calculateScheduledMonthlyBalances();
+      break;
+    case eHistoric:
+      pastTransactions(); //get all transactions for history period
+      calculateAccountTrendList();
+      calculateHistoricMonthlyBalances(); //add all balances of each month and put at the 1st day of each month
+      break;
+    default:
+      break;
+  }
 
-  calculateAccountTrendList();
+  //flag the forecast as done
+  m_forecastDone = true;
 
-  calculateMonthlyBalances();
-
-  if ( returnBudget ) { //only fill the budget if it is going to be used
+  //only fill the budget if it is going to be used
+  if ( returnBudget ) { 
     //setup the budget itself
     MyMoneyFile* file = MyMoneyFile::instance();
     budget.setBudgetStart ( budgetStart );
@@ -945,9 +983,11 @@ void MyMoneyForecast::createBudget ( MyMoneyBudget& budget, QDate historyStart,
         period.setAmount ( forecastBalance ( acc, f_date ) );
         budgetAcc.addPeriod ( f_date, period );
 
-        f_date = f_date.addMonths ( 1 ); //next month
+        //next month
+        f_date = f_date.addMonths ( 1 ); 
       }
-      budget.setAccount ( budgetAcc, acc.id() ); //add budget account to budget
+      //add budget account to budget
+      budget.setAccount ( budgetAcc, acc.id() );
     }
   }
 }
@@ -990,7 +1030,7 @@ QValueList<MyMoneyAccount> MyMoneyForecast::budgetAccountList(void)
   return accList;
 }
 
-void MyMoneyForecast::calculateMonthlyBalances()
+void MyMoneyForecast::calculateHistoricMonthlyBalances()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -1012,3 +1052,49 @@ void MyMoneyForecast::calculateMonthlyBalances()
   }
 }
 
+void MyMoneyForecast::calculateScheduledMonthlyBalances()
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+//Calculate account monthly balances
+  QMap<QCString, QCString>::ConstIterator it_n;
+  for(it_n = m_nameIdx.begin(); it_n != m_nameIdx.end(); ++it_n) {
+    MyMoneyAccount acc = file->account(*it_n);
+
+    for( QDate f_date = forecastStartDate(); f_date <= forecastEndDate(); f_date = f_date.addDays(1) ) {
+      //get the trend for the day
+      MyMoneyMoney accountDailyBalance = m_accountList[acc.id()][f_date];
+
+      //do not add if it is the beginning of the month
+      //otherwise we end up with duplicated values as reported by Marko Käning
+      if(f_date != QDate(f_date.year(), f_date.month(), 1) )
+        m_accountList[acc.id()][QDate(f_date.year(), f_date.month(), 1)] += accountDailyBalance;
+    }
+  }
+}
+
+void MyMoneyForecast::setStartingBalance(const MyMoneyAccount &acc)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  //Get current account balance
+  if ( acc.isInvest() ) { //investments require special treatment
+      //get the security id of that account
+    MyMoneySecurity undersecurity = file->security ( acc.currencyId() );
+    if ( ! undersecurity.isCurrency() ) //only do it if the security is not an actual currency
+    {
+      MyMoneyMoney rate = MyMoneyMoney ( 1, 1 ); //set the default value
+        //get te
+      MyMoneyPrice price = file->price ( undersecurity.id(), undersecurity.tradingCurrency(), QDate::currentDate() );
+      if ( price.isValid() )
+      {
+        rate = price.rate ( undersecurity.tradingCurrency() );
+      }
+      m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate()) * rate;
+    }
+  } else {
+    m_accountList[acc.id()][QDate::currentDate()] = file->balance(acc.id(), QDate::currentDate());
+  }
+}
+  
+
