@@ -19,6 +19,11 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
+// ----------------------------------------------------------------------------
+// KDE Includes
+#include <kglobal.h>
+#include <kstandarddirs.h>
+
 // ----------------------------------------------------------------------------
 // Project Includes
 
@@ -171,3 +176,7 @@ bool MyMoneyInstitution::hasReferenceTo(const QCString& /* id */) const
   return rc;
 }
 
+QPixmap MyMoneyInstitution::pixmap() const {
+  return QPixmap(KGlobal::dirs()->findResource("appdata",QString( "icons/hicolor/22x22/actions/%1.png").arg("bank")));
+}
+
