@@ -183,6 +183,11 @@ const QString MyMoneyMoney::formatMoney(const MyMoneyAccount& acc, const MyMoney
   return formatMoney(sec.tradingSymbol(), denomToPrec(acc.fraction()), showThousandSeparator);
 }
 
+const QString MyMoneyMoney::formatMoney(const MyMoneySecurity& sec, bool showThousandSeparator) const
+{
+  return formatMoney(sec.tradingSymbol(), denomToPrec(sec.smallestAccountFraction()), showThousandSeparator);
+}
+
 const QString MyMoneyMoney::formatMoney(const QString& currency, const int prec, bool showThousandSeparator) const
 {
   QString res;
@@ -537,7 +542,7 @@ MyMoneyMoney MyMoneyMoney::operator / ( const MyMoneyMoney& _b ) const
   return quotient;
 }
 
-const signed64 MyMoneyMoney::getLcd(const MyMoneyMoney& b) const
+signed64 MyMoneyMoney::getLcd(const MyMoneyMoney& b) const
 {
   signed64 current_divisor = 2;
   signed64 max_square;
@@ -756,7 +761,7 @@ const MyMoneyMoney MyMoneyMoney::reduce(void) const
   return out;
 }
 
-const signed64 MyMoneyMoney::precToDenom(int prec)
+signed64 MyMoneyMoney::precToDenom(int prec)
 {
   signed64 denom = 1;
 
@@ -766,12 +771,12 @@ const signed64 MyMoneyMoney::precToDenom(int prec)
   return denom;
 }
 
-const double MyMoneyMoney::toDouble(void) const
+double MyMoneyMoney::toDouble(void) const
 {
   return static_cast<double>(m_num) / static_cast<double>(m_denom);
 }
 
-const int MyMoneyMoney::denomToPrec(signed64 fract)
+int MyMoneyMoney::denomToPrec(signed64 fract)
 {
   int rc = 0;
   while(fract > 1) {
