@@ -21,6 +21,8 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+#include <klocale.h>
+
 // ----------------------------------------------------------------------------
 // Project Includes
 
@@ -87,7 +89,7 @@ MyMoneySchedule::MyMoneySchedule(const QDomElement& node) :
   if(nodeList.count() == 0)
     throw new MYMONEYEXCEPTION("SCHEDULED_TX has no TRANSACTION node");
 
-  m_transaction = MyMoneyTransaction(nodeList.item(0).toElement(), false);
+  setTransaction(MyMoneyTransaction(nodeList.item(0).toElement(), false), true);
 
   // some old versions did not remove the entry date and post date fields
   // in the schedule. So if this is the case, we deal with a very old transaction
@@ -151,17 +153,50 @@ void MyMoneySchedule::setFixed(bool fixed)
 }
 
 void MyMoneySchedule::setTransaction(const MyMoneyTransaction& transaction)
+{
+  setTransaction(transaction, false);
+}
+
+void MyMoneySchedule::setTransaction(const MyMoneyTransaction& transaction, bool noDateCheck)
 {
   MyMoneyTransaction t = transaction;
-  // don't allow a transaction that has no due date
-  // if we get something like that, then we use the
-  // the current next due date. If that is also invalid
-  // we can't help it.
-  if(!t.postDate().isValid()) {
-    t.setPostDate(m_transaction.postDate());
+  if(!noDateCheck) {
+    // don't allow a transaction that has no due date
+    // if we get something like that, then we use the
+    // the current next due date. If that is also invalid
+    // we can't help it.
+    if(!t.postDate().isValid()) {
+      t.setPostDate(m_transaction.postDate());
+    }
+
+    if(!t.postDate().isValid())
+      return;
+  }
+
+  // make sure to clear out some unused information in scheduled transactions
+  // we need to do this for the case that the transaction passed as argument
+  // is a matched or imported transaction.
+  QValueList<MyMoneySplit> splits = t.splits();
+  if(splits.count() > 0) {
+    QValueList<MyMoneySplit>::const_iterator it_s;
+    for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+      MyMoneySplit s = *it_s;
+      // clear out the bankID
+      if(!(*it_s).bankID().isEmpty()) {
+        s.setBankID(QCString());
+        t.modifySplit(s);
+      }
+
+      // only clear payees from second split onwards
+      if(it_s == splits.begin())
+        continue;
+
+      if(!(*it_s).payeeId().isEmpty()) {
+        s.setPayeeId(QCString());
+        t.modifySplit(s);
+      }
+    }
   }
-  if(!t.postDate().isValid())
-    return;
 
   m_transaction = t;
   // make sure that the transaction does not have an id so that we can enter
@@ -232,7 +267,7 @@ void MyMoneySchedule::setLastPayment(const QDate& date)
 
   for (it=m_recordedPayments.begin(); it!=m_recordedPayments.end(); ++it)
   {
-    if (*it < date)
+    if (*it < date || !date.isValid())
       delList.append(*it);
   }
 
@@ -394,11 +429,11 @@ QDate MyMoneySchedule::nextPayment(const QDate& refDate) const
         break;
 
       case OCCUR_EVERYTHREEWEEKS:
-	do {
+        do {
           paymentDate = paymentDate.addDays(21);
-	}
-	while (paymentDate <= refDate);
-	break;
+        }
+        while (paymentDate <= refDate);
+        break;
 
         case OCCUR_EVERYTHIRTYDAYS:
         do
@@ -1004,3 +1039,121 @@ bool MyMoneySchedule::hasReferenceTo(const QCString& id) const
 {
   return m_transaction.hasReferenceTo(id);
 }
+
+QString MyMoneySchedule::occurenceToString(occurenceE occurence)
+{
+  QString occurenceString = I18N_NOOP("Any");
+
+  if(occurence == MyMoneySchedule::OCCUR_ONCE)
+    occurenceString = I18N_NOOP("Once");
+  else if(occurence == MyMoneySchedule::OCCUR_DAILY)
+    occurenceString = I18N_NOOP("Daily");
+  else if(occurence == MyMoneySchedule::OCCUR_WEEKLY)
+    occurenceString = I18N_NOOP("Weekly");
+  else if(occurence == MyMoneySchedule::OCCUR_FORTNIGHTLY)
+    occurenceString = I18N_NOOP("Fortnightly");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYOTHERWEEK)
+    occurenceString = I18N_NOOP("Every other week");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYTHREEWEEKS)
+    occurenceString = I18N_NOOP("Every three weeks");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYFOURWEEKS)
+    occurenceString = I18N_NOOP("Every four weeks");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS)
+    occurenceString = I18N_NOOP("Every thirty days");
+  else if(occurence == MyMoneySchedule::OCCUR_MONTHLY)
+    occurenceString = I18N_NOOP("Monthly");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS)
+    occurenceString = I18N_NOOP("Every eight weeks");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYOTHERMONTH)
+    occurenceString = I18N_NOOP("Every two months");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYTHREEMONTHS)
+    occurenceString = I18N_NOOP("Every three months");
+  else if(occurence == MyMoneySchedule::OCCUR_QUARTERLY)
+    occurenceString = I18N_NOOP("Quarterly");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYFOURMONTHS)
+    occurenceString = I18N_NOOP("Every four months");
+  else if(occurence == MyMoneySchedule::OCCUR_TWICEYEARLY)
+    occurenceString = I18N_NOOP("Twice yearly");
+  else if(occurence == MyMoneySchedule::OCCUR_YEARLY)
+    occurenceString = I18N_NOOP("Yearly");
+  else if(occurence == MyMoneySchedule::OCCUR_EVERYOTHERYEAR)
+    occurenceString = I18N_NOOP("Every other year");
+  return occurenceString;
+}
+
+QString MyMoneySchedule::scheduleTypeToString(MyMoneySchedule::typeE type)
+{
+  QString text;
+
+  switch (type) {
+    case MyMoneySchedule::TYPE_BILL:
+      text = I18N_NOOP("Bill");
+      break;
+    case MyMoneySchedule::TYPE_DEPOSIT:
+      text = I18N_NOOP("Deposit");
+      break;
+    case MyMoneySchedule::TYPE_TRANSFER:
+      text = I18N_NOOP("Transfer");
+      break;
+    case MyMoneySchedule::TYPE_LOANPAYMENT:
+      text = I18N_NOOP("Loan payment");
+      break;
+    case MyMoneySchedule::TYPE_ANY:
+    default:
+      text = I18N_NOOP("Unknown");
+  }
+  return text;
+}
+
+
+QString MyMoneySchedule::paymentMethodToString(MyMoneySchedule::paymentTypeE paymentType)
+{
+  QString text;
+
+  switch (paymentType) {
+    case MyMoneySchedule::STYPE_DIRECTDEBIT:
+      text = I18N_NOOP("Direct debit");
+      break;
+    case MyMoneySchedule::STYPE_DIRECTDEPOSIT:
+      text = I18N_NOOP("Direct deposit");
+      break;
+    case MyMoneySchedule::STYPE_MANUALDEPOSIT:
+      text = I18N_NOOP("Manual deposit");
+      break;
+    case MyMoneySchedule::STYPE_OTHER:
+      text = I18N_NOOP("Other");
+      break;
+    case MyMoneySchedule::STYPE_WRITECHEQUE:
+      text = I18N_NOOP("Write check");
+      break;
+    case MyMoneySchedule::STYPE_STANDINGORDER:
+      text = I18N_NOOP("Standing order");
+      break;
+    case MyMoneySchedule::STYPE_BANKTRANSFER:
+      text = I18N_NOOP("Bank transfer");
+      break;
+    case MyMoneySchedule::STYPE_ANY:
+      text = I18N_NOOP("Any (Error)");
+      break;
+  }
+  return text;
+}
+
+QString MyMoneySchedule::weekendOptionToString(MyMoneySchedule::weekendOptionE weekendOption)
+{
+  QString text;
+
+  switch (weekendOption) {
+    case MyMoneySchedule::MoveFriday:
+      text = I18N_NOOP("Change the date to the previous Friday");
+      break;
+    case MyMoneySchedule::MoveMonday:
+      text = I18N_NOOP("Change the date to the next Monday");
+      break;
+    case MyMoneySchedule::MoveNothing:
+      text = I18N_NOOP("Do Nothing");
+      break;
+  }
+  return text;
+}
+
