@@ -44,7 +44,6 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-class IMyMoneyStorage;
 #include <kmymoney/mymoneytransaction.h>
 #include <kmymoney/export.h>
 
@@ -92,7 +91,7 @@ public:
   // used by the GUI (for KMyMoney in kfindtransactiondlgdecl.ui)
   enum dateOptionE {
     allDates = 0,
-    untilToday,
+    asOfToday,
     currentMonth,
     currentYear,
     monthToDate,
@@ -283,13 +282,12 @@ public:
     * matches.
     *
     * @param transaction A transaction
-    * @param storage pointer to object of IMyMoneyStorage class
     *
     * @retval true The transaction matches the filter set
     * @retval false The transaction does not match at least one of
     *               the filters in the filter set
     */
-  const bool match(const MyMoneyTransaction& transaction, const IMyMoneyStorage* const storage);
+  bool match(const MyMoneyTransaction& transaction);
 
   /**
     * This method is used to check a specific split against the
@@ -298,13 +296,12 @@ public:
     * method, any split matches.
     *
     * @param sp pointer to the split to be checked
-    * @param storage pointer to object of IMyMoneyStorage class
     *
     * @retval true The split matches the filter set
     * @retval false The split does not match at least one of
     *               the filters in the filter set
     */
-  bool match(const MyMoneySplit * const sp, const IMyMoneyStorage* const storage) const;
+  bool match(const MyMoneySplit * const sp) const;
 
   /**
     * This method is used to switch the amount of splits reported
@@ -367,7 +364,7 @@ public:
     * @param cat id of category in question
     * @return true if category is in filter set, false otherwise
     */
-  const bool includesCategory( const QCString& cat ) const;
+  bool includesCategory( const QCString& cat ) const;
 
   /**
     * This method is used to return information about the
@@ -378,7 +375,7 @@ public:
     * @param acc id of account in question
     * @return true if account is in filter set, false otherwise
     */
-  const bool includesAccount( const QCString& acc ) const;
+  bool includesAccount( const QCString& acc ) const;
 
   /**
     * This method is used to return information about the
@@ -389,7 +386,7 @@ public:
     * @param pye id of payee in question
     * @return true if payee is in filter set, false otherwise
     */
-  const bool includesPayee( const QCString& pye ) const;
+  bool includesPayee( const QCString& pye ) const;
 
   /**
     * This method is used to return information about the
@@ -399,7 +396,7 @@ public:
     * @param to result value for the end of the date range
     * @return true if an amount filter is set
     */
-  const bool dateFilter( QDate& from, QDate& to ) const;
+  bool dateFilter( QDate& from, QDate& to ) const;
 
   /**
     * This method is used to return information about the
@@ -409,7 +406,7 @@ public:
     * @param to result value for the high end of the amount range
     * @return true if an amount filter is set
     */
-  const bool amountFilter( MyMoneyMoney& from, MyMoneyMoney& to ) const;
+  bool amountFilter( MyMoneyMoney& from, MyMoneyMoney& to ) const;
 
   /**
     * This method is used to return information about the
@@ -419,7 +416,7 @@ public:
     * @param to result value for the high end of the number range
     * @return true if a number filter is set
     */
-  const bool numberFilter( QString& from, QString& to ) const;
+  bool numberFilter( QString& from, QString& to ) const;
 
   /**
     * This method returns whether a payee filter has been set,
@@ -428,7 +425,7 @@ public:
     * @param list list to append payees into
     * @return return true if a payee filter has been set
     */
-  const bool payees(QCStringList& list) const;
+  bool payees(QCStringList& list) const;
 
   /**
     * This method returns whether an account filter has been set,
@@ -437,7 +434,7 @@ public:
     * @param list list to append accounts into
     * @return return true if an account filter has been set
     */
-  const bool accounts(QCStringList& list) const;
+  bool accounts(QCStringList& list) const;
 
   /**
     * This method returns whether a category filter has been set,
@@ -446,7 +443,7 @@ public:
     * @param list list to append categories into
     * @return return true if a category filter has been set
     */
-  const bool categories(QCStringList& list) const;
+  bool categories(QCStringList& list) const;
 
   /**
     * This method returns whether a type filter has been set,
@@ -455,9 +452,9 @@ public:
     * @param i int to replace with first type filter, untouched otherwise
     * @return return true if a type filter has been set
     */
-  const bool firstType(int& i) const;
+  bool firstType(int& i) const;
 
-  const bool types(QValueList<int>& list) const;
+  bool types(QValueList<int>& list) const;
 
   /**
     * This method returns whether a state filter has been set,
@@ -466,9 +463,9 @@ public:
     * @param i reference to int to replace with first state filter, untouched otherwise
     * @return return true if a state filter has been set
     */
-  const bool firstState(int& i) const;
+  bool firstState(int& i) const;
 
-  const bool states(QValueList<int>& list) const;
+  bool states(QValueList<int>& list) const;
   /**
     * This method returns whether a text filter has been set,
     * and if so, it returns the text filter.
@@ -476,7 +473,7 @@ public:
     * @param text regexp to replace with text filter, or blank if none set
     * @return return true if a text filter has been set
     */
-  const bool textFilter(QRegExp& text) const;
+  bool textFilter(QRegExp& text) const;
 
   /**
     * This method translates a plain-language date range into QDate
@@ -508,19 +505,18 @@ private:
     *
     * @return converted reconcile flag of the split passed as parameter
     */
-  const int splitState(const MyMoneySplit& split) const;
+  int splitState(const MyMoneySplit& split) const;
 
   /**
     * This is a conversion tool from MyMoneySplit::action
     * to MyMoneyTransactionFilter::typeE types
     *
-    * @param storage pointer to object of IMyMoneyStorage class
     * @param t reference to transaction
     * @param split reference to split in question
     *
     * @return converted action of the split passed as parameter
     */
-  const int splitType(const IMyMoneyStorage* const storage, const MyMoneyTransaction& t, const MyMoneySplit& split) const;
+  int splitType(const MyMoneyTransaction& t, const MyMoneySplit& split) const;
 
   /**
     * This method checks if a transaction is valid or not. A transaction
@@ -530,7 +526,7 @@ private:
     * @retval valid transaction is valid
     * @retval invalid transaction is invalid
     */
-  const validityOptionE validTransaction(const MyMoneyTransaction& transaction) const;
+  validityOptionE validTransaction(const MyMoneyTransaction& transaction) const;
 
 protected:
   FilterSet           m_filterSet;
