@@ -65,8 +65,8 @@ void timestamp(const char *);
 class MyMoneyUtils
 {
 public:
-  MyMoneyUtils() {};
-  ~MyMoneyUtils() {};
+  MyMoneyUtils() {}
+  ~MyMoneyUtils() {}
 
   //static function to add the correct file extension at the end of the file name
   static QString getFileExtension(QString strFileName);
@@ -110,7 +110,7 @@ class _CheckMemoryEntry {
 public:
   _CheckMemoryEntry();
   _CheckMemoryEntry(void *p, int line, size_t size, const char *file);
-  ~_CheckMemoryEntry() {};
+  ~_CheckMemoryEntry() {}
 
   void * pointer(void) const { return m_p; };
   const int line(void) const { return m_line; };
@@ -192,6 +192,6 @@ KMYMONEY_EXPORT QDate stringToDate(const QString& str);
 KMYMONEY_EXPORT QCString QCStringEmpty(const QString&);
 KMYMONEY_EXPORT QString QStringEmpty(const QString&);
 
-KMYMONEY_EXPORT const unsigned long extractId(const QCString& txt);
+KMYMONEY_EXPORT unsigned long extractId(const QCString& txt);
 
 #endif
