@@ -91,15 +91,22 @@ public:
     MaxRefCheckBits
   } ReferenceCheckBits;
 
+  // definitions for the ID's of the standard accounts
+#define STD_ACC_LIABILITY "AStd::Liability"
+#define STD_ACC_ASSET     "AStd::Asset"
+#define STD_ACC_EXPENSE   "AStd::Expense"
+#define STD_ACC_INCOME    "AStd::Income"
+#define STD_ACC_EQUITY    "AStd::Equity"
+
   IMyMoneyStorage();
   virtual ~IMyMoneyStorage();
 
   // general get functions
-  virtual const MyMoneyPayee& user(void) const = 0;
-  virtual const QDate& creationDate(void) const = 0;
-  virtual const QDate& lastModificationDate(void) const = 0;
-  virtual const unsigned int currentFixVersion(void) const = 0;
-  virtual const unsigned int fileFixVersion(void) const = 0;
+  virtual const MyMoneyPayee user(void) const = 0;
+  virtual const QDate creationDate(void) const = 0;
+  virtual const QDate lastModificationDate(void) const = 0;
+  virtual unsigned int currentFixVersion(void) const = 0;
+  virtual unsigned int fileFixVersion(void) const = 0;
 
   // general set functions
   virtual void setUser(const MyMoneyPayee& user) = 0;
@@ -115,7 +122,7 @@ public:
     * a pointer to the newly created copy. The caller of this method is the
     * new owner of the object and must destroy it.
     */
-  virtual IMyMoneyStorage* const duplicate(void) = 0;
+  virtual IMyMoneyStorage const * duplicate(void) = 0;
 
   /**
     * This method is used to create a new account
@@ -155,7 +162,7 @@ public:
     *
     * @return MyMoneyPayee object of payee
     */
-  virtual const MyMoneyPayee& payee(const QCString& id) const = 0;
+  virtual const MyMoneyPayee payee(const QCString& id) const = 0;
 
   /**
     * This method is used to retrieve the id to a corresponding
@@ -166,7 +173,7 @@ public:
     *
     * @return MyMoneyPayee object of payee
     */
-  virtual const MyMoneyPayee& payeeByName(const QString& payee) const = 0;
+  virtual const MyMoneyPayee payeeByName(const QString& payee) const = 0;
 
   /**
     * This method is used to modify an existing payee
@@ -203,7 +210,7 @@ public:
     * @return reference to MyMoneyAccount object. An exception is thrown
     *         if the id is unknown
     */
-  virtual const MyMoneyAccount& account(const QCString& id) const = 0;
+  virtual const MyMoneyAccount account(const QCString& id) const = 0;
 
   /**
     * This method is used to check whether a given
@@ -214,7 +221,7 @@ public:
     * @param id account id
     * @return true if account-id is one of the standards, false otherwise
     */
-  virtual const bool isStandardAccount(const QCString& id) const = 0;
+  virtual bool isStandardAccount(const QCString& id) const = 0;
 
   /**
     * This method is used to set the name for the specified standard account
@@ -262,7 +269,7 @@ public:
     * @param id id of the account to be checked for
     * @return true if account is referenced, false otherwise
     */
-  virtual const bool hasActiveSplits(const QCString& id) const = 0;
+  virtual bool hasActiveSplits(const QCString& id) const = 0;
 
   /**
     * This method is used to return the actual balance of an account
@@ -275,7 +282,7 @@ public:
     * @param date return balance for specific date
     * @return balance of the account as MyMoneyMoney object
     */
-  virtual const MyMoneyMoney balance(const QCString& id, const QDate& date)= 0;
+  virtual const MyMoneyMoney balance(const QCString& id, const QDate& date) const= 0;
 
   /**
     * This method is used to return the actual balance of an account
@@ -288,7 +295,7 @@ public:
     * @param date return balance for specific date
     * @return balance of the account as MyMoneyMoney object
     */
-  virtual const MyMoneyMoney totalBalance(const QCString& id, const QDate& date) = 0;
+  virtual const MyMoneyMoney totalBalance(const QCString& id, const QDate& date) const = 0;
 
   /**
     * Returns the institution of a given ID
@@ -297,7 +304,7 @@ public:
     * @return MyMoneyInstitution object filled with data. If the institution
     *         could not be found, an exception will be thrown
     */
-  virtual const MyMoneyInstitution& institution(const QCString& id) const = 0;
+  virtual const MyMoneyInstitution institution(const QCString& id) const = 0;
 
   /**
     * This method returns an indicator if the storage object has been
@@ -321,7 +328,7 @@ public:
     *
     * @return number of accounts currently known inside a MyMoneyFile object
     */
-  virtual const unsigned int accountCount(void) const = 0;
+  virtual unsigned int accountCount(void) const = 0;
 
   /**
     * This method returns a list of the institutions
@@ -393,7 +400,7 @@ public:
     *
     * @return number of transactions in journal/account
     */
-  virtual const unsigned int transactionCount(const QCString& account = QCString()) const = 0;
+  virtual unsigned int transactionCount(const QCString& account = QCString()) const = 0;
 
   /**
     * This method returns a QMap filled with the number of transactions
@@ -419,7 +426,7 @@ public:
     *
     * @return set of transactions in form of a QValueList<MyMoneyTransaction>
     */
-  virtual QValueList<MyMoneyTransaction> transactionList(MyMoneyTransactionFilter& filter) const = 0;
+  virtual const QValueList<MyMoneyTransaction> transactionList(MyMoneyTransactionFilter& filter) const = 0;
 
   virtual void transactionList(QValueList<MyMoneyTransaction>& list, MyMoneyTransactionFilter& filter) const = 0;
 
@@ -455,7 +462,7 @@ public:
     * @param id id of transaction as QString.
     * @return reference to the requested transaction
     */
-  virtual const MyMoneyTransaction& transaction(const QCString& id) const = 0;
+  virtual const MyMoneyTransaction transaction(const QCString& id) const = 0;
 
   /**
     * This method is used to extract a transaction from the file global
@@ -465,7 +472,7 @@ public:
     * @param idx number of transaction in this account
     * @return reference to MyMoneyTransaction object
     */
-  virtual const MyMoneyTransaction& transaction(const QCString& account, const int idx) const = 0;
+  virtual const MyMoneyTransaction transaction(const QCString& account, const int idx) const = 0;
 
   /**
     * This method returns the number of institutions currently known to file
@@ -473,7 +480,7 @@ public:
     *
     * @return number of institutions known to file
     */
-  virtual const unsigned int institutionCount(void) const = 0;
+  virtual unsigned int institutionCount(void) const = 0;
 
   /**
     * This method returns a list of accounts inside the storage object.
@@ -482,37 +489,37 @@ public:
     *
     * @note The standard accounts will not be returned
     */
-  virtual void accountList(QValueList<MyMoneyAccount>& list) = 0;
+  virtual void accountList(QValueList<MyMoneyAccount>& list) const = 0;
 
   /**
     * This method is used to return the standard liability account
     * @return MyMoneyAccount liability account(group)
     */
-  virtual const MyMoneyAccount& liability(void) const = 0;
+  virtual const MyMoneyAccount liability(void) const = 0;
 
   /**
     * This method is used to return the standard asset account
     * @return MyMoneyAccount asset account(group)
     */
-  virtual const MyMoneyAccount& asset(void) const = 0;
+  virtual const MyMoneyAccount asset(void) const = 0;
 
   /**
     * This method is used to return the standard expense account
     * @return MyMoneyAccount expense account(group)
     */
-  virtual const MyMoneyAccount& expense(void) const = 0;
+  virtual const MyMoneyAccount expense(void) const = 0;
 
   /**
     * This method is used to return the standard income account
     * @return MyMoneyAccount income account(group)
     */
-  virtual const MyMoneyAccount& income(void) const = 0;
+  virtual const MyMoneyAccount income(void) const = 0;
 
   /**
     * This method is used to return the standard equity account
     * @return MyMoneyAccount equity account(group)
     */
-  virtual const MyMoneyAccount& equity(void) const = 0;
+  virtual const MyMoneyAccount equity(void) const = 0;
 
   /**
     * This method is used to create a new security object.  The ID will be created
@@ -566,14 +573,14 @@ public:
 
   virtual void addPrice(const MyMoneyPrice& price) = 0;
   virtual void removePrice(const MyMoneyPrice& price) = 0;
-  virtual MyMoneyPrice price(const QCString& fromId, const QCString& toId, const QDate& date, const bool exactDate) const = 0;
+  virtual const MyMoneyPrice price(const QCString& fromId, const QCString& toId, const QDate& date, const bool exactDate) const = 0;
 
   /**
     * This method returns a list of all prices.
     *
     * @return MyMoneyPriceList of all MyMoneyPrice objects.
     */
-  virtual const MyMoneyPriceList& priceList(void) const = 0;
+  virtual const MyMoneyPriceList priceList(void) const = 0;
 
   /**
     * This method is used to add a scheduled transaction to the engine.
@@ -652,7 +659,7 @@ public:
                                      const QDate& endDate = QDate(),
                                      const bool overdue = false) const = 0;
 
-  virtual QValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
+  virtual const QValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
                                               int scheduleOcurrences,
                                               int schedulePaymentTypes,
                                               QDate startDate,
@@ -698,7 +705,7 @@ public:
     * @param id QCString containing the id of the MyMoneySecurity object
     * @return MyMoneyCurrency object
     */
-  virtual const MyMoneySecurity& currency(const QCString& id) const = 0;
+  virtual const MyMoneySecurity currency(const QCString& id) const = 0;
 
   /**
     * This method is used to retrieve the list of all currencies
@@ -759,7 +766,7 @@ public:
     * @param id QCString containing the id of the MyMoneyReport object
     * @return MyMoneyReport object
     */
-  virtual MyMoneyReport report( const QCString& id ) const = 0;
+  virtual const MyMoneyReport report( const QCString& id ) const = 0;
 
   /**
     * This method is used to remove an existing MyMoneyReport object
@@ -802,7 +809,7 @@ public:
     *
     * @return MyMoneyBudget object of budget
     */
-  virtual const MyMoneyBudget& budgetByName(const QString& budget) const = 0;
+  virtual const MyMoneyBudget budgetByName(const QString& budget) const = 0;
 
   /**
     * This method is used to modify an existing MyMoneyBudget
@@ -872,7 +879,7 @@ public:
     * These methods have to be provided to allow transaction safe data handling.
     */
   virtual void startTransaction(void) = 0;
-  virtual void commitTransaction(void) = 0;
+  virtual bool commitTransaction(void) = 0;
   virtual void rollbackTransaction(void) = 0;
 };
 
