@@ -38,7 +38,6 @@
 // Project Includes
 
 #include "mymoneystoragexml.h"
-#include "../../kmymoneyutils.h"
 #include "../mymoneyreport.h"
 #include "../mymoneybudget.h"
 #include "../mymoneyinstitution.h"
@@ -61,6 +60,11 @@ public:
   QMap<QCString, MyMoneySecurity> secList;
   QMap<QCString, MyMoneyReport> rList;
   QMap<QCString, MyMoneyBudget> bList;
+  QMap<MyMoneySecurityPair, MyMoneyPriceEntries> prList;
+
+  QCString           m_fromSecurity;
+  QCString           m_toSecurity;
+
 };
 
 
@@ -68,6 +72,7 @@ class MyMoneyXmlContentHandler : public QXmlContentHandler
 {
 public:
   MyMoneyXmlContentHandler(MyMoneyStorageXML* reader);
+  virtual ~MyMoneyXmlContentHandler() {}
   virtual void setDocumentLocator (QXmlLocator * locator) { m_loc = locator; }
   virtual bool startDocument (void);
   virtual bool endDocument (void);
@@ -95,7 +100,8 @@ private:
 MyMoneyXmlContentHandler::MyMoneyXmlContentHandler(MyMoneyStorageXML* reader) :
   m_reader(reader),
   m_loc(0),
-  m_level(0)
+  m_level(0),
+  m_elementCount(0)
 {
 }
 
@@ -135,7 +141,7 @@ bool MyMoneyXmlContentHandler::startElement (const QString& /* namespaceURI */,
     QString s = qName.lower();
     if(s == "transaction"
     || s == "account"
-    || s == "pricepair"
+    || s == "price"
     || s == "payee"
     || s == "currency"
     || s == "security"
@@ -181,6 +187,14 @@ bool MyMoneyXmlContentHandler::startElement (const QString& /* namespaceURI */,
         m_reader->signalProgress(0, count, i18n("Loading reports..."));
         m_elementCount = 0;
       }
+    } else if(s == "prices") {
+      qDebug("reading prices");
+      m_elementCount = 0;
+    } else if(s == "pricepair") {
+      if(atts.count()) {
+        m_reader->d->m_fromSecurity = QCString(atts.value(QString("from")));
+        m_reader->d->m_toSecurity = QCString(atts.value(QString("to")));
+      }
     }
 
   } else {
@@ -206,40 +220,50 @@ bool MyMoneyXmlContentHandler::endElement(const QString& /* namespaceURI */, con
       try {
         if(s == "transaction") {
           MyMoneyTransaction t(m_baseNode);
-          m_reader->d->tList[t.uniqueSortKey()] = t;
+          if(!t.id().isEmpty())
+            m_reader->d->tList[t.uniqueSortKey()] = t;
         } else if(s == "account") {
           MyMoneyAccount a(m_baseNode);
-          m_reader->d->aList[a.id()] = a;
-        } else if(s == "pricepair") {
-          m_reader->readPricePair(m_baseNode);
+          if(!a.id().isEmpty())
+            m_reader->d->aList[a.id()] = a;
         } else if(s == "payee") {
           MyMoneyPayee p(m_baseNode);
-          m_reader->d->pList[p.id()] = p;
+          if(!p.id().isEmpty())
+            m_reader->d->pList[p.id()] = p;
         } else if(s == "currency") {
           MyMoneySecurity s(m_baseNode);
-          m_reader->d->secList[s.id()] = s;
+          if(!s.id().isEmpty())
+            m_reader->d->secList[s.id()] = s;
         } else if(s == "security") {
           MyMoneySecurity s(m_baseNode);
-          m_reader->d->secList[s.id()] = s;
+          if(!s.id().isEmpty())
+            m_reader->d->secList[s.id()] = s;
         } else if(s == "keyvaluepairs") {
           MyMoneyKeyValueContainer kvp(m_baseNode);
           m_reader->m_storage->setPairs(kvp.pairs());
         } else if(s == "institution") {
           MyMoneyInstitution i(m_baseNode);
-          m_reader->d->iList[i.id()] = i;
+          if(!i.id().isEmpty())
+            m_reader->d->iList[i.id()] = i;
         } else if(s == "report") {
           MyMoneyReport r(m_baseNode);
-          m_reader->d->rList[r.id()] = r;
+          if(!r.id().isEmpty())
+            m_reader->d->rList[r.id()] = r;
         } else if(s == "budget") {
           MyMoneyBudget b(m_baseNode);
-          m_reader->d->bList[b.id()] = b;
+          if(!b.id().isEmpty())
+            m_reader->d->bList[b.id()] = b;
         } else if(s == "fileinfo") {
           rc = m_reader->readFileInformation(m_baseNode);
         } else if(s == "user") {
           rc = m_reader->readUserInformation(m_baseNode);
         } else if(s == "scheduled_tx") {
           MyMoneySchedule s(m_baseNode);
-          m_reader->d->sList[s.id()] = s;
+          if(!s.id().isEmpty())
+            m_reader->d->sList[s.id()] = s;
+        } else if(s == "price") {
+          MyMoneyPrice p(m_reader->d->m_fromSecurity, m_reader->d->m_toSecurity, m_baseNode);
+          m_reader->d->prList[MyMoneySecurityPair(m_reader->d->m_fromSecurity, m_reader->d->m_toSecurity)][p.date()] = p;
         } else {
           m_errMsg = i18n("Unknown XML tag %1 found in line %2").arg(qName).arg(m_loc->lineNumber());
           kdDebug(2) << m_errMsg << endl;
@@ -300,6 +324,11 @@ bool MyMoneyXmlContentHandler::endElement(const QString& /* namespaceURI */, con
       m_reader->m_storage->loadBudgets(m_reader->d->bList);
       m_reader->d->bList.clear();
       m_reader->signalProgress(-1, -1);
+    } else if(s == "prices") {
+      // last price read, now dump them into the engine
+      m_reader->m_storage->loadPrices(m_reader->d->prList);
+      m_reader->d->bList.clear();
+      m_reader->signalProgress(-1, -1);
     }
   }
   return rc;
@@ -777,43 +806,6 @@ QDomElement MyMoneyStorageXML::writeKeyValuePairs(const QMap<QCString, QString>
   return QDomElement();
 }
 
-void MyMoneyStorageXML::readPricePair(const QDomElement& pricePair)
-{
-  QCString from = QCString(pricePair.attribute("from"));
-  QCString to = QCString(pricePair.attribute("to"));
-  QDomNode child = pricePair.firstChild();
-
-  while(!child.isNull())
-  {
-    if(child.isElement())
-    {
-      QDomElement childElement = child.toElement();
-      if("PRICE" == childElement.tagName())
-      {
-        MyMoneyPrice p = readPrice(from, to, childElement);
-
-        //tell the storage objects we have a new price.
-        m_storage->addPrice(p);
-      }
-    }
-    child = child.nextSibling();
-  }
-}
-
-const MyMoneyPrice MyMoneyStorageXML::readPrice(const QCString& from, const QCString& to, const QDomElement& price)
-{
-  QDate date;
-  MyMoneyMoney rate;
-  QString source;
-
-  date = QDate::fromString(price.attribute("date"), Qt::ISODate);
-  rate = MyMoneyMoney(price.attribute("price"));
-  source = price.attribute("source");
-
-  //create actual object to return to add into the engine's list of objects.
-  return MyMoneyPrice(from, to, date, rate, source);
-}
-
 void MyMoneyStorageXML::writePrices(QDomElement& prices)
 {
   const MyMoneyPriceList list = m_storage->priceList();
