@@ -15,36 +15,68 @@
  *                                                                         *
  ***************************************************************************/
 
-// ----------------------------------------------------------------------------
-// KDE Includes
-
-#include <kgenericfactory.h>
-#include <kdebug.h>
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
 #include <qfile.h>
 #include <qtextstream.h>
 
+// ----------------------------------------------------------------------------
+// KDE Includes
+
+#include <kgenericfactory.h>
+#include <kdebug.h>
+#include <kfile.h>
+#include <kurl.h>
+#include <kaction.h>
+#include <kmessagebox.h>
+
 // ----------------------------------------------------------------------------
 // Project Includes
 
 #include "ofximporterplugin.h"
+#include "konlinebankingstatus.h"
+#include "konlinebankingsetupwizard.h"
+#include "kofxdirectconnectdlg.h"
 
 K_EXPORT_COMPONENT_FACTORY( kmm_ofximport,
                             KGenericFactory<OfxImporterPlugin>( "kmm_ofximport" ) )
 
-OfxImporterPlugin::OfxImporterPlugin(QObject *parent, const char *name, const QStringList&)
- : KMyMoneyPlugin::ImporterPlugin( parent, name ),
+OfxImporterPlugin::OfxImporterPlugin(QObject *parent, const char *name, const QStringList&) :
+ KMyMoneyPlugin::Plugin( parent, name ),
+ KMyMoneyPlugin::ImporterPlugin(),
  m_valid( false )
 {
+  setInstance(KGenericFactory<OfxImporterPlugin>::instance());
+  setXMLFile("kmm_ofximport.rc");
+  createActions();
 }
 
 OfxImporterPlugin::~OfxImporterPlugin()
 {
 }
 
+void OfxImporterPlugin::createActions(void)
+{
+  new KAction(i18n("OFX ..."), "", 0, this, SLOT(slotImportFile()), actionCollection(), "file_import_ofx");
+}
+
+void OfxImporterPlugin::slotImportFile(void)
+{
+  KURL url = importInterface()->selectFile(i18n("OFX import file selection"),
+                                             "",
+                                             "*.ofx *.qfx *.ofc|OFX files (*.ofx, *.qfx, *.ofc)\n*.*|All files (*.*)",
+                                             static_cast<KFile::Mode>(KFile::File | KFile::ExistingOnly));
+  if(url.isValid()) {
+    if ( isMyFormat(url.path()) ) {
+      slotImportFile(url.path());
+    } else {
+      KMessageBox::error( 0, i18n("Unable to import %1 using the OFX importer plugin.  This file is not the correct format.").arg(url.prettyURL(0, KURL::StripFileProtocol)), i18n("Incorrect format"));
+    }
+
+  }
+}
+
 QString OfxImporterPlugin::formatName(void) const
 {
   return "OFX";
@@ -55,6 +87,7 @@ QString OfxImporterPlugin::formatFilenameFilter(void) const
   return "*.ofx *.qfx *.ofc";
 }
 
+
 bool OfxImporterPlugin::isMyFormat( const QString& filename ) const
 {
   // filename is an Ofx file if it contains the tag "<OFX>" somewhere.
@@ -79,10 +112,13 @@ bool OfxImporterPlugin::isMyFormat( const QString& filename ) const
   return result;
 }
 
-bool OfxImporterPlugin::import( const QString& filename, QValueList<MyMoneyStatement>& result )
+bool OfxImporterPlugin::import( const QString& filename )
 {
-  m_fatalerror = "Unable to parse file";
+  m_fatalerror = i18n("Unable to parse file");
   m_valid = false;
+  m_errors.clear();
+  m_warnings.clear();
+  m_infos.clear();
 
   m_statementlist.clear();
   m_securitylist.clear();
@@ -102,15 +138,17 @@ bool OfxImporterPlugin::import( const QString& filename, QValueList<MyMoneyState
 
   if ( m_valid )
   {
-    result += m_statementlist;
     m_fatalerror = QString();
+    m_valid = storeStatements(m_statementlist);
   }
   return m_valid;
 }
 
 QString OfxImporterPlugin::lastError(void) const
 {
-  return m_fatalerror;
+  if(m_errors.count() == 0)
+    return m_fatalerror;
+  return m_errors.join("<p>");
 }
 
 /* __________________________________________________________________________
@@ -383,6 +421,10 @@ int OfxImporterPlugin::ofxAccountCallback(struct OfxAccountData data, void * pv)
     s.m_strAccountName = data.account_name;
     s.m_strAccountNumber = data.account_id;
   }
+  if(data.bank_id_valid == true)
+  {
+    s.m_strRoutingNumber = data.bank_id;
+  }
   if(data.currency_valid==true)
   {
     s.m_strCurrency = data.currency;
@@ -483,5 +525,123 @@ int OfxImporterPlugin::ofxStatusCallback(struct OfxStatusData data, void * pv)
   return 0;
 }
 
+bool OfxImporterPlugin::importStatement(const MyMoneyStatement& s)
+{
+  qDebug("OfxImporterPlugin::importStatement start");
+  return statementInterface()->import(s);
+}
+
+const MyMoneyAccount& OfxImporterPlugin::account(const QString& key, const QString& value) const
+{
+  Q_UNUSED(key);
+  Q_UNUSED(value);
+
+  static MyMoneyAccount null;
+
+  return null;
+}
+
+void OfxImporterPlugin::protocols(QStringList& protocolList) const
+{
+  protocolList.clear();
+  protocolList << "OFX";
+}
+
+QWidget* OfxImporterPlugin::accountConfigTab(const MyMoneyAccount& acc, QString& name)
+{
+  name = i18n("Online settings");
+  m_statusDlg = new KOnlineBankingStatus(acc, 0, 0);
+  return m_statusDlg;
+}
+
+MyMoneyKeyValueContainer OfxImporterPlugin::onlineBankingSettings(const MyMoneyKeyValueContainer& current)
+{
+  MyMoneyKeyValueContainer kvp(current);
+  // keep the provider name in sync with the one found in kmm_ofximport.desktop
+  kvp["provider"] = "KMyMoney OFX";
+  if(m_statusDlg) {
+    kvp.deletePair("appId");
+    if(!m_statusDlg->appId().isEmpty())
+      kvp.setValue("appId", m_statusDlg->appId());
+  }
+  return kvp;
+}
+
+bool OfxImporterPlugin::mapAccount(const MyMoneyAccount& acc, MyMoneyKeyValueContainer& settings)
+{
+  Q_UNUSED(acc);
+
+  bool rc = false;
+  KOnlineBankingSetupWizard wiz(0, "onlinebankingsetup");
+  if(wiz.isInit()) {
+    if(wiz.exec() == QDialog::Accepted) {
+      rc = wiz.chosenSettings( settings );
+    }
+  }
+
+  return rc;
+}
+
+bool OfxImporterPlugin::updateAccount(const MyMoneyAccount& acc)
+{
+  try {
+    if(!acc.id().isEmpty()) {
+      KOfxDirectConnectDlg dlg(acc);
+
+      connect(&dlg, SIGNAL(statementReady(const QString&)),
+              this, SLOT(slotImportFile(const QString&)));
+
+      dlg.init();
+      dlg.exec();
+    }
+  } catch (MyMoneyException *e) {
+    KMessageBox::information(0 ,i18n("Error connecting to bank: %1").arg(e->what()));
+    delete e;
+  }
+
+  return false;
+}
+
+void OfxImporterPlugin::slotImportFile(const QString& url)
+{
+  
+  if(!import(url)) {
+    KMessageBox::error( 0, QString("<qt>%1</qt>").arg(i18n("Unable to import %1 using the OFX importer plugin.  The plugin returned the following error:<p>%2").arg(url, lastError())), i18n("Importing error"));
+  }
+}
+
+bool OfxImporterPlugin::storeStatements(QValueList<MyMoneyStatement>& statements)
+{
+  bool hasstatements = (statements.count() > 0);
+  bool ok = true;
+  bool abort = false;
+
+  // FIXME Deal with warnings/errors coming back from plugins
+  /*if ( ofx.errors().count() )
+  {
+    if ( KMessageBox::warningContinueCancelList(this,i18n("The following errors were returned from your bank"),ofx.errors(),i18n("OFX Errors")) == KMessageBox::Cancel )
+      abort = true;
+  }
+
+  if ( ofx.warnings().count() )
+  {
+    if ( KMessageBox::warningContinueCancelList(this,i18n("The following warnings were returned from your bank"),ofx.warnings(),i18n("OFX Warnings"),KStdGuiItem::cont(),"ofxwarnings") == KMessageBox::Cancel )
+      abort = true;
+  }*/
+
+  qDebug("OfxImporterPlugin::storeStatements() with %d statements called", static_cast<int>(statements.count()));
+  QValueList<MyMoneyStatement>::const_iterator it_s = statements.begin();
+  while ( it_s != statements.end() && !abort ) {
+    ok = ok && importStatement((*it_s));
+    ++it_s;
+  }
+
+  if ( hasstatements && !ok ) {
+    KMessageBox::error( 0, i18n("Importing process terminated unexpectedly."), i18n("Failed to import all statements."));
+  }
+
+  return ( !hasstatements || ok );
+}
+
 #include "ofximporterplugin.moc"
 // vim:cin:si:ai:et:ts=2:sw=2:
