@@ -3,8 +3,16 @@
                          -------------------
     begin                : Fri Jul 23 2004
     copyright            : (C) 2004-2005 by Ace Jones
+                           (C) 2007 Sascha Pfau
     email                :  acejones@users.sourceforge.net
+                            MrPeacock@gmail.com
  ***************************************************************************/
+ 
+/****************************************************************************
+  Contains code from the func_xirr and related methods of financial.cpp 
+  - KOffice 1.6 by Sascha Pfau.  Sascha agreed to relicense those methods under
+  GPLv2 or later.
+*****************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -30,7 +38,7 @@
 // Project Includes
 
 #include "../mymoney/mymoneyreport.h"
-#include "reporttable.h"
+#include "listtable.h"
 
 namespace reports {
 
@@ -49,61 +57,16 @@ class ReportAccount;
   * @short
 **/
 
-class QueryTable : public ReportTable
+class QueryTable : public ListTable
 {
-public:
-  QueryTable(const MyMoneyReport&);
-  QString renderHTML( void ) const;
-  QString renderCSV( void ) const;
-  void drawChart( KReportChartView& ) const {}
-  void dump( const QString& file, const QString& context=QString() ) const;
-  void init(void);
-
-public:
-  /**
-    * Contains a single row in the table.
-    *
-    * Each column is a key/value pair, both strings.  This class is just
-    * a QMap with the added ability to specify which columns you'd like to
-    * use as a sort key when you qHeapSort a list of these TableRows
-    */
-  class TableRow: public QMap<QString,QString>
-  {
   public:
-    bool operator<( const TableRow& ) const;
-    bool operator<=( const TableRow& ) const;
-    bool operator>( const TableRow& ) const;
-    bool operator==( const TableRow& ) const;
+    QueryTable(const MyMoneyReport&);
+    void init(void);
 
-    static void setSortCriteria( const QString& _criteria ) { m_sortCriteria = QStringList::split(",",_criteria); }
-  private:
-    static QStringList m_sortCriteria;
-  };
-
-protected:
-  void render( QString&, QString& ) const;
-  void constructAccountTable(void);
-  void constructTransactionTable(void);
-  void constructPerformanceRow( const ReportAccount& account, TableRow& result, const MyMoneyMoney& ) const;
-
-private:
-  QValueList<TableRow> m_transactions;
-  const MyMoneyReport& m_config;
-  QString m_group;
-  /**
-    * Comma-separated list of columns to place BEFORE the subtotal column
-    */
-  QString m_columns;
-  /**
-    * Name of the subtotal column
-    */
-  QString m_subtotal;
-  /**
-    * Comma-separated list of columns to place AFTER the subtotal column
-    */
-  QString m_postcolumns;
-  QString m_summarize;
-  QString m_propagate;
+  protected:
+    void constructAccountTable(void);
+    void constructTransactionTable(void);
+    void constructPerformanceRow( const ReportAccount& account, TableRow& result ) const;
 
 };
 
@@ -124,6 +87,7 @@ public:
   MyMoneyMoney NPV( double _rate ) const;
 
   static void setToday( const QDate& _today ) { m_sToday = _today; }
+  const QDate& today( void ) const { return m_sToday; }
 
 private:
   QDate m_date;
@@ -134,14 +98,42 @@ private:
 
 class CashFlowList: public QValueList<CashFlowListItem>
 {
-public:
-  CashFlowList(void) {}
-  MyMoneyMoney NPV(double rate) const;
-  double IRR(void) const;
-  MyMoneyMoney total(void) const;
-  void dumpDebug(void) const;
-protected:
-  const CashFlowListItem& mostRecent(void) const;
+  public:
+    CashFlowList(void) {}
+    MyMoneyMoney NPV(double rate) const;
+    double IRR(void) const;
+    MyMoneyMoney total(void) const;
+    void dumpDebug(void) const;
+
+    /**
+     * Function: XIRR
+     *
+     * Compute the internal rate of return for a non-periodic series of cash flows.
+     *
+     * XIRR ( Values; Dates; [ Guess = 0.1 ] )
+     **/
+    double calculateXIRR ( void ) const;
+
+  protected:
+    const CashFlowListItem& mostRecent(void) const;
+
+  private:
+        /**
+   * helper: xirrResult
+   *
+   * args[0] = values
+   * args[1] = dates
+         **/
+    double xirrResult ( double& rate ) const;
+
+        /**
+     *
+     * helper: xirrResultDerive
+     *
+     * args[0] = values
+     * args[1] = dates
+         **/
+    double xirrResultDerive ( double& rate ) const;
 };
 
 }
