@@ -107,7 +107,7 @@ KBudgetView::KBudgetView(QWidget *parent, const char *name ) :
   KGuiItem newButtenItem( QString(""),
                              QIconSet(il->loadIcon("file_new", KIcon::Small, KIcon::SizeSmall)),
                              i18n("Creates a new budget"),
-                             i18n("Use this to create a new emtpy budget."));
+                             i18n("Use this to create a new empty budget."));
   m_newButton->setGuiItem(newButtenItem);
   QToolTip::add(m_newButton, newButtenItem.toolTip());
 
@@ -147,10 +147,10 @@ KBudgetView::KBudgetView(QWidget *parent, const char *name ) :
   connect(m_cbBudgetSubaccounts, SIGNAL(clicked()), this, SLOT(cb_includesSubaccounts_clicked()));
 
   connect(m_accountTree, SIGNAL(selectionChanged(QListViewItem*)), this, SLOT(slotSelectAccount(QListViewItem*)));
+  connect(m_accountTree, SIGNAL(valueChanged()), this, SLOT(slotRefreshHideUnusedButton()));
 
   // connect the buttons to the actions. Make sure the enabled state
   // of the actions is reflected by the buttons
-  connect(m_newButton, SIGNAL(clicked()), kmymoney2->action("budget_new"), SLOT(activate()));
   connect(kmymoney2->action("budget_new"), SIGNAL(enabled(bool)), m_newButton, SLOT(setEnabled(bool)));
   connect(m_renameButton, SIGNAL(clicked()), kmymoney2->action("budget_rename"), SLOT(activate()));
   connect(kmymoney2->action("budget_rename"), SIGNAL(enabled(bool)), m_renameButton, SLOT(setEnabled(bool)));
@@ -159,37 +159,22 @@ KBudgetView::KBudgetView(QWidget *parent, const char *name ) :
 
   connect(m_budgetValue, SIGNAL(valuesChanged()), this, SLOT(slotBudgetedAmountChanged()));
 
+  connect(m_newButton, SIGNAL(clicked()), this, SLOT(slotNewBudget()));
   connect(m_updateButton, SIGNAL(pressed()), this, SLOT(slotUpdateBudget()));
-
   connect(m_resetButton, SIGNAL(pressed()), this, SLOT(slotResetBudget()));
 
-  connect(m_hideUnusedButton, SIGNAL(toggled(bool)), this, SLOT(slotSelectBudget()));
+  connect(m_hideUnusedButton, SIGNAL(toggled(bool)), this, SLOT(slotHideUnused(bool)));
 
   // setup initial state
   m_newButton->setEnabled(kmymoney2->action("budget_new")->isEnabled());
   m_renameButton->setEnabled(kmymoney2->action("budget_rename")->isEnabled());
   m_deleteButton->setEnabled(kmymoney2->action("budget_delete")->isEnabled());
 
-  // make sure to use the previous settings. If no settings are found
-  // we use equal distribution of all fields as an initial setting
-  // For some reason, if the view is never selected with this code, it
-  // stores a value of 32 for the columns. We have to detect that as well.
-  m_accountTree->setColumnWidth(0, 0);
-  m_accountTree->restoreLayout(KGlobal::config(), "Budget Account View Settings");
-  if(m_accountTree->columnWidth(0) < 60) {
-    m_accountTree->setResizeMode(QListView::AllColumns);
-  }
-
-  // FIXME hide unused columns. Apparently, this does not really
-  // hide them, so for now we just leave it in
-  // m_accountTree->hideColumn(KMyMoneyAccountTree::TaxReportColumn);
-
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotRefreshView()));
 }
 
 KBudgetView::~KBudgetView()
 {
-  m_accountTree->saveLayout(KGlobal::config(), "Budget Account View Settings");
 }
 
 void KBudgetView::show()
@@ -201,6 +186,12 @@ void KBudgetView::show()
   }
 }
 
+void KBudgetView::polish()
+{
+  KBudgetViewDecl::polish();
+  m_accountTree->restoreLayout("Budget Account View Settings");
+}
+
 void KBudgetView::slotRearrange(void)
 {
   resizeEvent(0);
@@ -222,7 +213,7 @@ void KBudgetView::slotReloadView(void)
 void KBudgetView::loadBudgets(void)
 {
   QCString id;
-
+  
   ::timetrace("Start KBudgetView::loadBudgets");
 
   // remember which item is currently selected
@@ -322,7 +313,7 @@ void KBudgetView::slotRefreshView(void)
 void KBudgetView::loadAccounts(void)
 {
   QMap<QCString, bool> isOpen;
-
+  
   ::timetrace("start load budget account view");
 
   // if no budgets are selected, don't load the accounts
@@ -337,13 +328,13 @@ void KBudgetView::loadAccounts(void)
   }
 
   // remember the id of the current selected item
-  KMyMoneyAccountTreeBudgetItem *item = m_accountTree->selectedItem();
+  KMyMoneyAccountTreeBaseItem *item = m_accountTree->selectedItem();
   QCString selectedItemId = (item) ? item->id() : QCString();
 
   // keep a map of all 'expanded' accounts
   QListViewItemIterator it_lvi(m_accountTree);
   while(it_lvi.current()) {
-    item = dynamic_cast<KMyMoneyAccountTreeBudgetItem*>(it_lvi.current());
+    item = dynamic_cast<KMyMoneyAccountTreeBaseItem*>(it_lvi.current());
     if(item && item->isOpen()) {
       isOpen[item->id()] = true;
     }
@@ -368,11 +359,7 @@ void KBudgetView::loadAccounts(void)
   m_transactionCountMap = file->transactionCountMap();
 
   m_accountTree->setBaseCurrency(file->baseCurrency());
-
-  // make sure we show all items for an empty budget
-  if(m_budget.getaccounts().isEmpty())
-    m_hideUnusedButton->setChecked(false);
-
+  
   bool haveUnusedBudgets = false;
 
   // create the items
@@ -401,7 +388,7 @@ void KBudgetView::loadAccounts(void)
   // expanded and re-select the one that was probably selected before
   it_lvi = QListViewItemIterator(m_accountTree);
   while(it_lvi.current()) {
-    item = dynamic_cast<KMyMoneyAccountTreeBudgetItem*>(it_lvi.current());
+    item = dynamic_cast<KMyMoneyAccountTreeBaseItem*>(it_lvi.current());
     if(item) {
       if(item->id() == selectedItemId)
         m_accountTree->setSelected(item, true);
@@ -484,7 +471,7 @@ bool KBudgetView::loadSubAccounts(KMyMoneyAccountTreeBudgetItem* parent, QCStrin
     // the display of those,
     if(acc.accountGroup() == MyMoneyAccount::Income
     || acc.accountGroup() == MyMoneyAccount::Expense) {
-      if(m_hideUnusedButton->isChecked() && thisUnused) {
+      if(m_hideUnusedButton->isEnabled() && m_hideUnusedButton->isChecked() && thisUnused) {
         unused = true;
         delete item;
       }
@@ -493,26 +480,35 @@ bool KBudgetView::loadSubAccounts(KMyMoneyAccountTreeBudgetItem* parent, QCStrin
   return unused;
 }
 
-void KBudgetView::slotSelectBudget(void)
+void KBudgetView::askSave(void)
 {
-  // check if the content of a currently selected payee was modified
+  // check if the content of a currently selected budget was modified
   // and ask to store the data
   if (m_updateButton->isEnabled()) {
     if (KMessageBox::questionYesNo(this, QString("<qt>%1</qt>").arg(
-      i18n("Do you want to save the changes for <b>%1</b>").arg(m_budget.name())),
-      i18n("Save changes")) == KMessageBox::Yes) {
-        m_inSelection = true;
-        slotUpdateBudget();
-        m_inSelection = false;
-    }
+        i18n("Do you want to save the changes for <b>%1</b>").arg(m_budget.name())),
+             i18n("Save changes")) == KMessageBox::Yes) {
+               m_inSelection = true;
+               slotUpdateBudget();
+               m_inSelection = false;
+             }
   }
+}
 
+void KBudgetView::slotRefreshHideUnusedButton(void)
+{
+  m_hideUnusedButton->setDisabled(m_budget.getaccounts().isEmpty());
+}
+
+void KBudgetView::slotSelectBudget(void)
+{
+  askSave();
   KBudgetListItem* item;
   if (m_budget.id().isEmpty()) {
     item = dynamic_cast<KBudgetListItem*>(m_budgetList->firstChild());
     if(item) {
       m_budgetList->blockSignals(true);
-      m_budgetList->setSelected(item, true);
+      m_budgetList->setSelected(item, true); // WRTODO das auch beim NewBudget machen
       m_budgetList->blockSignals(false);
     }
   }
@@ -528,6 +524,7 @@ void KBudgetView::slotSelectBudget(void)
     m_accountTree->setEnabled(true);
   }
 
+  slotRefreshHideUnusedButton();
   loadAccounts();
 
   QValueList<MyMoneyBudget> budgetList;
@@ -536,6 +533,15 @@ void KBudgetView::slotSelectBudget(void)
   emit selectObjects(budgetList);
 }
 
+void KBudgetView::slotHideUnused(bool toggled)
+{
+  // make sure we show all items for an empty budget
+  bool prevState=!toggled;
+  slotRefreshHideUnusedButton();
+  if (prevState!=m_hideUnusedButton->isChecked())
+    loadAccounts();
+}
+
 const MyMoneyBudget& KBudgetView::selectedBudget(void) const
 {
   static MyMoneyBudget nullBudget;
@@ -594,9 +600,9 @@ void KBudgetView::slotRenameBudget(QListViewItem* p , int /*col*/, const QString
   if (pBudget->budget().name() != new_name) {
     MyMoneyFileTransaction ft;
     try {
-      // check if we already have a payee with the new name
+      // check if we already have a budget with the new name
       try {
-        // this function call will throw an exception, if the payee
+        // this function call will throw an exception, if the budget
         // hasn't been found.
         MyMoneyFile::instance()->budgetByName(new_name);
         // the name already exists, ask the user whether he's sure to keep the name
@@ -714,6 +720,12 @@ void KBudgetView::cb_includesSubaccounts_clicked()
   }
 }
 
+void KBudgetView::slotNewBudget(void)
+{
+  askSave();
+  kmymoney2->action("budget_new")->activate();
+}
+
 void KBudgetView::slotResetBudget(void)
 {
   try {
@@ -732,6 +744,7 @@ void KBudgetView::slotUpdateBudget(void)
   try {
     MyMoneyFile::instance()->modifyBudget(m_budget);
     ft.commit();
+    slotRefreshHideUnusedButton();
   } catch(MyMoneyException *e) {
     KMessageBox::detailedSorry(0, i18n("Unable to modify budget"),
                                (e->what() + " " + i18n("thrown in") + " " + e->file()+ ":%1").arg(e->line()));
