@@ -21,6 +21,7 @@
 #include <qspinbox.h>
 #include <qlabel.h>
 #include <qbuttongroup.h>
+#include <qtextedit.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -40,9 +41,8 @@
 #include "../kmymoneyutils.h"
 #include "../mymoney/mymoneyforecast.h"
 #include "../widgets/kmymoneyforecastlistviewitem.h"
-#include "../reports/reportaccount.h"
+#include "../widgets/kmymoneyaccounttreeforecast.h"
 
-using namespace reports;
 
 KForecastView::KForecastView(QWidget *parent, const char *name) :
   KForecastViewDecl(parent,name)
@@ -58,34 +58,15 @@ KForecastView::KForecastView(QWidget *parent, const char *name) :
 
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadForecast()));
 
-  connect(m_forecastButton, SIGNAL(clicked()), this, SLOT(slotLoadForecast()));
+  connect(m_forecastButton, SIGNAL(clicked()), this, SLOT(slotManualForecast()));
 
   m_forecastList->setAllColumnsShowFocus(true);
   m_summaryList->setAllColumnsShowFocus(true);
-  m_adviceList->setAllColumnsShowFocus(true);
+  //m_adviceList->setAllColumnsShowFocus(true);
   m_advancedList->setAllColumnsShowFocus(true);
 
-  //fill the settings controls
-  m_forecastDays->setValue(KMyMoneyGlobalSettings::forecastDays());
-  m_accountsCycle->setValue(KMyMoneyGlobalSettings::forecastAccountCycle());
-  m_beginDay->setValue(KMyMoneyGlobalSettings::beginForecastDay());
-  m_forecastCycles->setValue(KMyMoneyGlobalSettings::forecastCycles());
-  m_historyMethod->setButton(KMyMoneyGlobalSettings::historyMethod());
-  switch(KMyMoneyGlobalSettings::forecastMethod()) {
-    case 0:
-      m_forecastMethod->setText(i18n("Scheduled"));
-      m_forecastCycles->setDisabled(true);
-      m_historyMethod->setDisabled(true);
-      break;
-    case 1:
-      m_forecastMethod->setText(i18n("History"));
-      m_forecastCycles->setEnabled(true);
-      m_historyMethod->setEnabled(true);
-      break;
-    default:
-      m_forecastMethod->setText(i18n("Unknown"));
-      break;
-  }
+  loadForecastSettings();
+
 }
 
 KForecastView::~KForecastView()
@@ -141,18 +122,56 @@ void KForecastView::slotLoadForecast(void)
   m_needReload[ListView] = true;
   m_needReload[AdvancedView] = true;
   m_needReload[BudgetView] = true;
+
+  //refresh settings
+  loadForecastSettings();
+
   if(isVisible())
     slotTabChanged(m_tab->currentPage());
 }
 
+void KForecastView::slotManualForecast(void)
+{
+  m_needReload[SummaryView] = true;
+  m_needReload[ListView] = true;
+  m_needReload[AdvancedView] = true;
+  m_needReload[BudgetView] = true;
+
+  if(isVisible())
+    slotTabChanged(m_tab->currentPage());
+}
+
+void KForecastView::loadForecastSettings(void)
+{
+  //fill the settings controls
+  m_forecastDays->setValue(KMyMoneyGlobalSettings::forecastDays());
+  m_accountsCycle->setValue(KMyMoneyGlobalSettings::forecastAccountCycle());
+  m_beginDay->setValue(KMyMoneyGlobalSettings::beginForecastDay());
+  m_forecastCycles->setValue(KMyMoneyGlobalSettings::forecastCycles());
+  m_historyMethod->setButton(KMyMoneyGlobalSettings::historyMethod());
+  switch(KMyMoneyGlobalSettings::forecastMethod()) {
+    case 0:
+      m_forecastMethod->setText(i18n("Scheduled"));
+      m_forecastCycles->setDisabled(true);
+      m_historyMethod->setDisabled(true);
+      break;
+    case 1:
+      m_forecastMethod->setText(i18n("History"));
+      m_forecastCycles->setEnabled(true);
+      m_historyMethod->setEnabled(true);
+      break;
+    default:
+      m_forecastMethod->setText(i18n("Unknown"));
+      break;
+  }
+}
+
 void KForecastView::loadListView(void)
 {
+  MyMoneyForecast forecast;
   MyMoneyFile* file = MyMoneyFile::instance();
 
-  QValueList<MyMoneyAccount> accList;
-  MyMoneySecurity baseCurrency = file->baseCurrency();
-
-  MyMoneyForecast forecast;
+  m_forecastList->setBaseCurrency(file->baseCurrency());
 
   //get the settings from current page
   forecast.setForecastDays(m_forecastDays->value());
@@ -162,123 +181,34 @@ void KForecastView::loadListView(void)
   forecast.setHistoryMethod(m_historyMethod->selectedId());
   forecast.doForecast();
 
-  //Get all accounts of the right type to calculate forecast
-  m_nameIdx.clear();
-  accList = forecast.accountList();
-  QValueList<MyMoneyAccount>::const_iterator accList_t = accList.begin();
-  for(; accList_t != accList.end(); ++accList_t ) {
-    MyMoneyAccount acc = *accList_t;
-    if(m_nameIdx[acc.id()] != acc.id()) { //Check if the account is there
-        m_nameIdx[acc.id()] = acc.id();
-    }
-  }
-
   //clear the list, including columns
-  m_forecastList->clear();
-  for(;m_forecastList->columns() > 0;) {
-    m_forecastList->removeColumn(0);
-  }
+  m_forecastList->clearColumns();
 
-  //add first column of both lists
-  int accountColumn = m_forecastList->addColumn(i18n("Account"), -1);
+  //add columns
+  m_forecastList->showAccount();
+  m_forecastList->showDetailed(forecast);
 
-  //add cycle interval columns
-  m_forecastList->addColumn(i18n("Current"), -1);
-  for(int i = 1; i <= forecast.forecastDays(); ++i) {
-    QDate forecastDate = QDate::currentDate().addDays(i);
-    QString columnName =  KGlobal::locale()->formatDate(forecastDate, true);
-    m_forecastList->addColumn(columnName, -1);
-  }
+  //add default rows
+  addTotalRow(m_forecastList, forecast);
+  addAssetLiabilityRows(forecast);
 
-  //add variation columns
-  m_forecastList->addColumn(i18n("Total variation"), -1);
-
-  //align columns
-  for(int i = 1; i < m_forecastList->columns(); ++i) {
-    m_forecastList->setColumnAlignment(i, Qt::AlignRight);
-  }
-
-  m_forecastList->setSorting(-1);
-
-  KMyMoneyForecastListViewItem *forecastItem = 0;
-  QMap<QDate, MyMoneyMoney> cycleBalance;
-
-  QMap<QCString, QCString>::ConstIterator it_nc;
-  for(it_nc = m_nameIdx.begin(); it_nc != m_nameIdx.end(); ++it_nc) {
-
-    MyMoneyAccount acc = file->account(*it_nc);
-    MyMoneySecurity currency;
-    if(acc.isInvest()) {
-      MyMoneySecurity underSecurity = file->security(acc.currencyId());
-      currency = file->security(underSecurity.tradingCurrency());
-    } else {
-        currency = file->security(acc.currencyId());
-    }
-    QString amount;
-    QString vAmount;
-    MyMoneyMoney vAmountMM;
-
-    forecastItem = new KMyMoneyForecastListViewItem(m_forecastList, forecastItem, false);
-    forecastItem->setText(accountColumn, acc.name());
-    int it_c = 1; // iterator for the columns of the listview
-
-    for(QDate forecastDate = QDate::currentDate(); forecastDate <= forecast.forecastEndDate(); ++it_c, forecastDate = forecastDate.addDays(1)) {
-      MyMoneyMoney amountMM = forecast.forecastBalance(acc, forecastDate);
-
-      //calculate the balance in base currency for the total row
-      if(acc.currencyId() != file->baseCurrency().id()) {
-        ReportAccount repAcc = ReportAccount(acc.id());
-        MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(forecastDate);
-        MyMoneyMoney baseAmountMM = amountMM * curPrice;
-        cycleBalance[forecastDate] += baseAmountMM;
-        //convert to lowest fraction after using a different currency
-        cycleBalance[forecastDate] = cycleBalance[forecastDate].convert(file->baseCurrency().smallestAccountFraction());
-      } else {
-        cycleBalance[forecastDate] += amountMM;
-      }
-      amount = amountMM.formatMoney(acc, currency);
-      forecastItem->setText((accountColumn+it_c), amount, amountMM.isNegative()); //sets the text and negative color
-    }
-
-    //calculate and add variation per cycle
-    vAmountMM = forecast.accountTotalVariation(acc);
-    vAmount = vAmountMM.formatMoney(acc, currency);
-    forecastItem->setText((accountColumn+it_c), vAmount, vAmountMM.isNegative());
-
-  }
-  //add total row
-  forecastItem = new KMyMoneyForecastListViewItem(m_forecastList, forecastItem, false);
-  forecastItem->setText(accountColumn, i18n("Total"));
-
-  int prec = MyMoneyMoney::denomToPrec(file->baseCurrency().smallestAccountFraction());
-  int column = 1;
-  for(QDate forecastDate = QDate::currentDate(); forecastDate <= forecast.forecastEndDate(); forecastDate = forecastDate.addDays(1), ++column) {
-    MyMoneyMoney amountMM = cycleBalance[forecastDate];
-    QString amount = amountMM.formatMoney(file->baseCurrency().tradingSymbol(), prec);
-    forecastItem->setText( column, amount, amountMM.isNegative());
-  }
-  //calculate total variation
-  QString totalVarAmount;
-  MyMoneyMoney totalVarAmountMM = cycleBalance[forecast.forecastEndDate()]-cycleBalance[QDate::currentDate()];
-  totalVarAmount = totalVarAmountMM.formatMoney(file->baseCurrency().tradingSymbol(), prec);
-  forecastItem->setText( column, totalVarAmount);
+  //load asset and liability forecast accounts
+  loadAccounts(forecast, file->asset(), m_assetItem, KMyMoneyAccountTreeForecastItem::eDetailed);
+  loadAccounts(forecast, file->liability(), m_liabilityItem, KMyMoneyAccountTreeForecastItem::eDetailed);
 
   m_forecastList->show();
 }
 
 void KForecastView::loadSummaryView(void)
 {
-  MyMoneyFile* file = MyMoneyFile::instance();
+  MyMoneyForecast forecast;
   QValueList<MyMoneyAccount> accList;
-  QMap<QDate, MyMoneyMoney> cycleBalance;
   int dropMinimum;
   int dropZero;
-  bool negative = false;
-  int daysToBeginDay;
 
-  MyMoneySecurity baseCurrency = file->baseCurrency();
+  MyMoneyFile* file = MyMoneyFile::instance();
 
-  MyMoneyForecast forecast;
+  m_summaryList->setBaseCurrency(file->baseCurrency());
 
   //get the settings from current page
   forecast.setForecastDays(m_forecastDays->value());
@@ -288,6 +218,21 @@ void KForecastView::loadSummaryView(void)
   forecast.setHistoryMethod(m_historyMethod->selectedId());
   forecast.doForecast();
 
+  //clear the list, including columns
+  m_summaryList->clearColumns();
+
+  //add columns
+  m_summaryList->showAccount();
+  m_summaryList->showSummary(forecast);
+
+  //add default rows
+  addTotalRow(m_summaryList, forecast);
+  addAssetLiabilityRows(forecast);
+
+  loadAccounts(forecast, file->asset(), m_assetItem, KMyMoneyAccountTreeForecastItem::eSummary);
+  loadAccounts(forecast, file->liability(), m_liabilityItem, KMyMoneyAccountTreeForecastItem::eSummary);
+
+  //Add comments to the advice list
   //Get all accounts of the right type to calculate forecast
   m_nameIdx.clear();
   accList = forecast.accountList();
@@ -299,139 +244,7 @@ void KForecastView::loadSummaryView(void)
     }
   }
 
-  //clear the list, including columns
-  m_summaryList->clear();
-  for(;m_summaryList->columns() > 0;) {
-    m_summaryList->removeColumn(0);
-  }
-
-  //clear the list, including columns
-  m_adviceList->clear();
-  for(;m_adviceList->columns() > 0;) {
-    m_adviceList->removeColumn(0);
-  }
-
-  //add first column of both lists
-  int accountColumn = m_summaryList->addColumn(i18n("Account"), -1);
-  m_adviceList->addColumn("", -1);
-
-  //add cycle interval columns
-  m_summaryList->addColumn(i18n("Current"), -1);
-
-  //if beginning of forecast is today, set the begin day to next cycle to avoid repeating the first cycle
-  if(QDate::currentDate() < forecast.beginForecastDate()) {
-    daysToBeginDay = QDate::currentDate().daysTo(forecast.beginForecastDate());
-  } else {
-    daysToBeginDay = forecast.accountsCycle();
-  }
-  for(int i = 0; ((i*forecast.accountsCycle())+daysToBeginDay) <= forecast.forecastDays(); ++i) {
-    int intervalDays = ((i*forecast.accountsCycle())+daysToBeginDay);
-    QString columnName =  i18n("%1 days").arg(intervalDays, 0, 10);
-    m_summaryList->addColumn(columnName, -1);
-  }
-
-  //add variation columns
-  m_summaryList->addColumn(i18n("Total variation"), -1);
-
-  //align columns
-  for(int i = 1; i < m_summaryList->columns(); ++i) {
-    m_summaryList->setColumnAlignment(i, Qt::AlignRight);
-  }
-
-  m_summaryList->setSorting(-1);
-  m_adviceList->setSorting(-1);
-
-  KMyMoneyForecastListViewItem *summaryItem = 0;
-  KMyMoneyForecastListViewItem *adviceItem = 0;
-
   QMap<QCString, QCString>::ConstIterator it_nc;
-  for(it_nc = m_nameIdx.begin(); it_nc != m_nameIdx.end(); ++it_nc) {
-    const MyMoneyAccount& acc = file->account(*it_nc);
-    MyMoneySecurity currency;
-    QString amount;
-    QString vAmount;
-    MyMoneyMoney vAmountMM;
-    ReportAccount repAcc;
-    if(acc.currencyId() != file->baseCurrency().id())
-      repAcc = ReportAccount(acc.id());
-
-    //change currency to deep currency if account is an investment
-    if(acc.isInvest()) {
-      MyMoneySecurity underSecurity = file->security(acc.currencyId());
-      currency = file->security(underSecurity.tradingCurrency());
-    } else {
-      currency = file->security(acc.currencyId());
-    }
-
-    summaryItem = new KMyMoneyForecastListViewItem(m_summaryList, summaryItem, false);
-    summaryItem->setText(accountColumn, acc.name());
-    int it_c = 1; // iterator for the columns of the listview
-
-    //add current balance column
-    QDate summaryDate = QDate::currentDate();
-
-    MyMoneyMoney amountMM;
-    amountMM = forecast.forecastBalance(acc, summaryDate);
-
-    //calculate the balance in base currency for the total row
-    if(acc.currencyId() != file->baseCurrency().id()) {
-      MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(summaryDate);
-      MyMoneyMoney baseAmountMM = amountMM * curPrice;
-      cycleBalance[summaryDate] += baseAmountMM;
-    } else {
-      cycleBalance[summaryDate] += amountMM;
-    }
-    amount = amountMM.formatMoney(acc, currency);
-    summaryItem->setText((accountColumn+it_c), amount);
-    it_c++;
-
-    //iterate through all other columns
-    for(QDate summaryDate = QDate::currentDate().addDays(daysToBeginDay); summaryDate <= forecast.forecastEndDate();summaryDate = summaryDate.addDays(forecast.accountsCycle()), ++it_c) {
-      amountMM = forecast.forecastBalance(acc, summaryDate);
-
-      //calculate the balance in base currency for the total row
-      if(acc.currencyId() != file->baseCurrency().id()) {
-        MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(summaryDate);
-        MyMoneyMoney baseAmountMM = amountMM * curPrice;
-        cycleBalance[summaryDate] += baseAmountMM;
-        //convert to the lowest fraction, otherwise we get crazy results
-        cycleBalance[summaryDate] = cycleBalance[summaryDate].convert(file->baseCurrency().smallestAccountFraction());
-      } else {
-        cycleBalance[summaryDate] += amountMM;
-      }
-      amount = amountMM.formatMoney(acc, currency);
-      summaryItem->setText(it_c, amount);
-    }
-    //calculate and add variation per cycle
-    vAmountMM = forecast.accountTotalVariation(acc);
-    summaryItem->setNegative(vAmountMM.isNegative());
-    vAmount = vAmountMM.formatMoney(acc, currency);
-    summaryItem->setText((accountColumn+it_c), vAmount);
-
-  }
-  //add total row
-  summaryItem = new KMyMoneyForecastListViewItem(m_summaryList, summaryItem, false);
-  summaryItem->setText(accountColumn, i18n("Total"));
-
-  //add current total
-  int prec = MyMoneyMoney::denomToPrec(file->baseCurrency().smallestAccountFraction());
-  summaryItem->setText(1, cycleBalance[QDate::currentDate()].formatMoney(file->baseCurrency().tradingSymbol(), prec));
-
-  //add interval totals
-  int column = 2;
-  for(QDate summaryDate = QDate::currentDate().addDays(daysToBeginDay); summaryDate <= forecast.forecastEndDate();summaryDate = summaryDate.addDays(forecast.accountsCycle()), ++column) {
-    MyMoneyMoney amountMM = cycleBalance[summaryDate];
-    QString amount = amountMM.formatMoney(file->baseCurrency().tradingSymbol(), prec);
-    summaryItem->setText( column, amount);
-  }
-  //calculate total variation
-  QString totalVarAmount;
-  MyMoneyMoney totalVarAmountMM = cycleBalance[QDate::currentDate().addDays(forecast.forecastDays())]-cycleBalance[QDate::currentDate()];
-  summaryItem->setNegative(totalVarAmountMM.isNegative());
-  totalVarAmount = totalVarAmountMM.formatMoney(file->baseCurrency().tradingSymbol(), prec);
-  summaryItem->setText( column, totalVarAmount);
-
-  //Add comments to the advice list
   for(it_nc = m_nameIdx.begin(); it_nc != m_nameIdx.end(); ++it_nc) {
 
     const MyMoneyAccount& acc = file->account(*it_nc);
@@ -455,7 +268,6 @@ void KForecastView::loadSummaryView(void)
     //Check if the account is going to be below zero in the future
     dropZero = forecast.daysToZeroBalance(acc);
 
-
     // spit out possible warnings
     QString msg;
 
@@ -470,17 +282,18 @@ void KForecastView::loadSummaryView(void)
         case -1:
           break;
         case 0:
-          msg = i18n("The balance of %1 is below the minimum balance %2 today.").arg(acc.name()).arg(minBalance.formatMoney(acc, currency));
-          negative = true;
+          msg = QString("<font color=\"%1\">").arg(KMyMoneyGlobalSettings::listNegativeValueColor().name());
+          msg += i18n("The balance of %2 is below the minimum balance %3 today.").arg(acc.name()).arg(minBalance.formatMoney(acc, currency));
+          msg += QString("</font>");
           break;
         default:
-          msg = i18n("The balance of %1 will drop below the minimum balance %2 in %3 days.").arg(acc.name()).arg(minBalance.formatMoney(acc, currency)).arg(dropMinimum-1);
-          negative = true;
+          msg = QString("<font color=\"%1\">").arg(KMyMoneyGlobalSettings::listNegativeValueColor().name());
+          msg += i18n("The balance of %1 will drop below the minimum balance %2 in %3 days.").arg(acc.name()).arg(minBalance.formatMoney(acc, currency)).arg(dropMinimum-1);
+          msg += QString("</font>");
       }
 
       if(!msg.isEmpty()) {
-        adviceItem = new KMyMoneyForecastListViewItem(m_adviceList, adviceItem, negative);
-        adviceItem->setText(0, msg);
+        m_adviceText->append(msg);
       }
     }
 
@@ -491,48 +304,47 @@ void KForecastView::loadSummaryView(void)
         break;
       case 0:
         if(acc.accountGroup() == MyMoneyAccount::Asset) {
-          msg = i18n("The balance of %1 is below %2 today.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency));
-          negative = true;
+          msg = QString("<font color=\"%1\">").arg(KMyMoneyGlobalSettings::listNegativeValueColor().name());
+          msg += i18n("The balance of %1 is below %2 today.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency));
+          msg += QString("</font>");
           break;
         }
         if(acc.accountGroup() == MyMoneyAccount::Liability) {
           msg = i18n("The balance of %1 is above %2 today.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency));
-          negative = false;
           break;
         }
         break;
       default:
         if(acc.accountGroup() == MyMoneyAccount::Asset) {
-          msg = i18n("The balance of %1 will drop below %2 in %3 days.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency)).arg(dropZero);
-          negative = true;
+          msg = QString("<font color=\"%1\">").arg(KMyMoneyGlobalSettings::listNegativeValueColor().name());
+          msg += i18n("The balance of %1 will drop below %2 in %3 days.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency)).arg(dropZero);
+          msg += QString("</font>");
           break;
         }
         if(acc.accountGroup() == MyMoneyAccount::Liability) {
           msg = i18n("The balance of %1 will raise above %2 in %3 days.").arg(acc.name()).arg(MyMoneyMoney().formatMoney(acc, currency)).arg(dropZero);
-          negative = false;
           break;
         }
     }
     if(!msg.isEmpty()) {
-      adviceItem = new KMyMoneyForecastListViewItem(m_adviceList, adviceItem, negative);
-      adviceItem->setText(0, msg);
+      m_adviceText->append(msg);
     }
 
     //advice about trends
     msg = QString();
     MyMoneyMoney accCycleVariation = forecast.accountCycleVariation(acc);
     if (accCycleVariation < MyMoneyMoney(0, 1)) {
-      msg = i18n("The account %1 is decreasing %2 per cycle.").arg(acc.name()).arg(accCycleVariation.formatMoney(acc, currency));
-      negative = true;
+      msg = QString("<font color=\"%1\">").arg(KMyMoneyGlobalSettings::listNegativeValueColor().name());
+      msg += i18n("The account %1 is decreasing %2 per cycle.").arg(acc.name()).arg(accCycleVariation.formatMoney(acc, currency));
+      msg += QString("</font>");
     }
 
     if(!msg.isEmpty()) {
-      adviceItem = new KMyMoneyForecastListViewItem(m_adviceList, adviceItem, negative);
-      adviceItem->setText(0, msg);
+      m_adviceText->append(msg);
     }
   }
   m_summaryList->show();
-  m_adviceList->show();
+  m_adviceText->show();
 }
 
 void KForecastView::loadAdvancedView(void)
@@ -658,10 +470,10 @@ void KForecastView::loadAdvancedView(void)
 void KForecastView::loadBudgetView(void)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
-  MyMoneySecurity baseCurrency = file->baseCurrency();
   MyMoneyForecast forecast;
-  QDate f_date;
-  QValueList<MyMoneyAccount> accList;
+//  QValueList<MyMoneyAccount> accList;
+
+  m_budgetList->setBaseCurrency(file->baseCurrency());
 
   //get the settings from current page and calculate this year based on last year
   QDate historyEndDate = QDate(QDate::currentDate().year()-1, 12, 31);
@@ -673,108 +485,147 @@ void KForecastView::loadBudgetView(void)
   MyMoneyBudget budget;
   forecast.createBudget(budget, historyStartDate, historyEndDate, forecastStartDate, forecastEndDate, false);
 
-  //Get all accounts of the right type to calculate forecast
-  m_nameIdx.clear();
-  accList = forecast.accountList();
-  QValueList<MyMoneyAccount>::const_iterator accList_t = accList.begin();
-  for(; accList_t != accList.end(); ++accList_t ) {
-    MyMoneyAccount acc = *accList_t;
-    if(m_nameIdx[acc.id()] != acc.id()) { //Check if the account is there
-      m_nameIdx[acc.id()] = acc.id();
-    }
-  }
-
   //clear the list, including columns
-  m_budgetList->clear();
-  for(;m_budgetList->columns() > 0;) {
-    m_budgetList->removeColumn(0);
-  }
+  m_budgetList->clearColumns();
 
-  //add first column of both lists
-  int accountColumn = m_budgetList->addColumn(i18n("Account"), -1);
+  //add columns
+  m_budgetList->showAccount();
+  m_budgetList->showBudget(forecast);
 
-  //add cycle interval columns
-  f_date = forecastStartDate;
-  for(int i = 1; f_date <= forecastEndDate; ++i, f_date = f_date.addMonths(1)) {
-    QString columnName =  QDate::longMonthName(i);
-    m_budgetList->addColumn(columnName, -1);
-  }
-  //add total column
-  m_budgetList->addColumn(i18n("Total"), -1);
+  //add default rows
+  addTotalRow(m_budgetList, forecast);
+  addIncomeExpenseRows(forecast);
 
-
-  //align columns
-  for(int i = 1; i < m_budgetList->columns(); ++i) {
-    m_budgetList->setColumnAlignment(i, Qt::AlignRight);
-  }
-
-  m_budgetList->setSorting(-1);
-
-  KMyMoneyForecastListViewItem *budgetItem = 0;
-  QMap<int, MyMoneyMoney> cycleBalance;
-
-  QMap<QCString, QCString>::ConstIterator it_nc;
-  for(it_nc = m_nameIdx.begin(); it_nc != m_nameIdx.end(); ++it_nc) {
-    MyMoneyAccount acc = file->account(*it_nc);
-    MyMoneySecurity currency;
-    QString amount;
-    QString vAmount;
-    MyMoneyMoney vAmountMM;
-    MyMoneyMoney tAmountMM;
-    int it_c = 1; // iterator for the columns of the listview
-    f_date = forecastStartDate;
-
-    if(acc.isInvest()) {
-      MyMoneySecurity underSecurity = file->security(acc.currencyId());
-      currency = file->security(underSecurity.tradingCurrency());
-    } else {
-      currency = file->security(acc.currencyId());
-    }
-
-    budgetItem = new KMyMoneyForecastListViewItem(m_budgetList, budgetItem, false);
-    budgetItem->setText(accountColumn, acc.name());
-
-    //iterate columns
-    for(int i = 1; f_date <= forecastEndDate; ++i, f_date = f_date.addMonths(1), ++it_c) {
-      MyMoneyMoney amountMM;
-      amountMM = forecast.forecastBalance(acc,QDate(QDate::currentDate().year(), i, 1));
-      if(acc.accountType() == MyMoneyAccount::Expense)
-        amountMM = -amountMM;
-
-      //calculate the balance in base currency for the total row
-      if(acc.currencyId() != file->baseCurrency().id()) {
-        ReportAccount repAcc = ReportAccount(acc.id());
-        MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(QDate::currentDate());
-        MyMoneyMoney baseAmountMM = amountMM * curPrice;
-        cycleBalance[i] += baseAmountMM;
-
-      } else {
-        cycleBalance[i] += amountMM;
-      }
-
-      tAmountMM += amountMM;
-      amount = amountMM.formatMoney(acc, currency);
-      budgetItem->setText(it_c, amount, amountMM.isNegative()); //sets the text and negative color
-    }
-    amount = tAmountMM.formatMoney(acc, currency);
-    budgetItem->setText(it_c, amount, tAmountMM.isNegative()); //sets the text and negative color
-  }
-  //add total row
-  budgetItem = new KMyMoneyForecastListViewItem(m_budgetList, budgetItem, false);
-  budgetItem->setText(accountColumn, i18n("Total"));
-  int i;
-  MyMoneyMoney totalBudgetAmount;
-  int prec = MyMoneyMoney::denomToPrec(file->baseCurrency().smallestAccountFraction());
-  f_date = forecastStartDate;
-  for(i = 1; f_date <= forecastEndDate; ++i, f_date = f_date.addMonths(1)) {
-    MyMoneyMoney amountMM = cycleBalance[i];
-    totalBudgetAmount += amountMM;
-    QString amount = amountMM.formatMoney(file->baseCurrency().tradingSymbol(), prec);
-    budgetItem->setText((i), amount, amountMM.isNegative());
-  }
-  budgetItem->setText((i), totalBudgetAmount.formatMoney(file->baseCurrency().tradingSymbol(), prec), totalBudgetAmount.isNegative());
+  //load income and expense budget accounts
+  loadAccounts(forecast, file->income(), m_incomeItem, KMyMoneyAccountTreeForecastItem::eBudget);
+  loadAccounts(forecast, file->expense(), m_expenseItem, KMyMoneyAccountTreeForecastItem::eBudget);
 
   m_budgetList->show();
 }
 
+QValueList<MyMoneyPrice> KForecastView::getAccountPrices(const MyMoneyAccount& acc)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+  QValueList<MyMoneyPrice> prices;
+  MyMoneySecurity security = file->baseCurrency();
+    try {
+      if(acc.isInvest()) {
+        security = file->security(acc.currencyId());
+        prices += file->price(acc.currencyId(), security.tradingCurrency());
+        if(security.tradingCurrency() != file->baseCurrency().id()) {
+          MyMoneySecurity sec = file->security(security.tradingCurrency());
+          prices += file->price(sec.id(), file->baseCurrency().id());
+        }
+      } else if(acc.currencyId() != file->baseCurrency().id()) {
+        if(acc.currencyId() != file->baseCurrency().id()) {
+          security = file->security(acc.currencyId());
+          prices += file->price(acc.currencyId(), file->baseCurrency().id());
+        }
+      }
+
+    } catch(MyMoneyException *e) {
+      kdDebug(2) << __PRETTY_FUNCTION__ << " caught exception while adding " << acc.name() << "[" << acc.id() << "]: " << e->what();
+      delete e;
+    }
+  return prices;
+}
+
+void KForecastView::addAssetLiabilityRows(const MyMoneyForecast& forecast)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  QValueList<MyMoneyPrice> basePrices;
+  m_assetItem = new KMyMoneyAccountTreeForecastItem( m_totalItem, file->asset(), forecast, basePrices, file->baseCurrency() );
+  m_assetItem->setOpen(true);
+  m_liabilityItem = new KMyMoneyAccountTreeForecastItem( m_totalItem, file->liability(), forecast, basePrices, file->baseCurrency());
+  m_liabilityItem->setOpen(true);
+}
+
+void KForecastView::addIncomeExpenseRows(const MyMoneyForecast& forecast)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  QValueList<MyMoneyPrice> basePrices;
+  m_incomeItem = new KMyMoneyAccountTreeForecastItem( m_totalItem, file->income(), forecast, basePrices, file->baseCurrency() );
+  m_incomeItem->setOpen(true);
+  m_expenseItem = new KMyMoneyAccountTreeForecastItem( m_totalItem, file->expense(), forecast, basePrices, file->baseCurrency());
+  m_expenseItem->setOpen(true);
+}
+
+void KForecastView::addTotalRow(KMyMoneyAccountTreeForecast* forecastList, const MyMoneyForecast& forecast)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  m_totalItem = new KMyMoneyAccountTreeForecastItem( forecastList, file->asset(), forecast, file->baseCurrency(), i18n("Total") );
+  m_totalItem->setOpen(true);
+}
+
+bool KForecastView::includeAccount(MyMoneyForecast& forecast, const MyMoneyAccount& acc)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+
+  if( forecast.isForecastAccount(acc) )
+    return true;
+
+  QCStringList accounts = acc.accountList();
+
+  if(accounts.size() > 0) {
+    QCStringList::ConstIterator it_acc;
+    for(it_acc = accounts.begin(); it_acc != accounts.end(); ++it_acc) {
+      MyMoneyAccount account = file->account(*it_acc);
+      if( includeAccount(forecast, account) )
+        return true;
+    }
+  }
+  return false;
+}
+
+void KForecastView::loadAccounts(MyMoneyForecast& forecast, const MyMoneyAccount& account, KMyMoneyAccountTreeForecastItem* parentItem, int forecastType )
+{
+  QMap<QCString, QCString> nameIdx;
+  QCStringList accList;
+  MyMoneyFile* file = MyMoneyFile::instance();
+  KMyMoneyAccountTreeForecastItem *forecastItem = 0;
+
+  //Get all accounts of the right type to calculate forecast
+  accList = account.accountList();
+
+  if(accList.size() == 0)
+    return;
+
+  QCStringList::ConstIterator accList_t;
+  for(accList_t = accList.begin(); accList_t != accList.end(); ++accList_t ) {
+    MyMoneyAccount subAccount = file->account(*accList_t);
+    //only add the account if it is a forecast account or the parent of a forecast account
+    if(includeAccount(forecast, subAccount)) {
+      nameIdx[subAccount.id()] = subAccount.id();
+    }
+  }
+
+  QMap<QCString, QCString>::ConstIterator it_nc;
+  for(it_nc = nameIdx.begin(); it_nc != nameIdx.end(); ++it_nc) {
+
+    const MyMoneyAccount subAccount = file->account(*it_nc);
+    MyMoneySecurity currency;
+    if(subAccount.isInvest()) {
+      MyMoneySecurity underSecurity = file->security(subAccount.currencyId());
+      currency = file->security(underSecurity.tradingCurrency());
+    } else {
+      currency = file->security(subAccount.currencyId());
+    }
+
+    QString amount;
+    QString vAmount;
+    MyMoneyMoney vAmountMM;
+
+    //get prices
+    QValueList<MyMoneyPrice> prices = getAccountPrices(subAccount);
+
+    forecastItem = new KMyMoneyAccountTreeForecastItem( parentItem, subAccount, forecast, prices, currency, static_cast<KMyMoneyAccountTreeForecastItem::EForecastViewType>(forecastType) );
+    forecastItem->setOpen(true);
+
+    loadAccounts(forecast, subAccount, forecastItem, forecastType);
+  }
+}
+
 #include "kforecastview.moc"
