@@ -57,6 +57,8 @@
 #include "../dialogs/ksortoptiondlg.h"
 #include "../kmymoney2.h"
 
+#include "../widgets/scheduledtransaction.h"
+
 class KGlobalLedgerViewPrivate
 {
 public:
@@ -66,10 +68,12 @@ public:
   KMyMoneyRegister::RegisterSearchLineWidget* m_registerSearchLine;
   QPoint               m_startPoint;
   QCString             m_reconciliationAccount;
+  QDate                m_reconciliationDate;
   MyMoneyMoney         m_endingBalance;
   int                  m_precision;
   bool                 m_inLoading;
   bool                 m_recursion;
+  bool                 m_showDetails;
   KMyMoneyRegister::Action m_action;
   QTimer               m_viewPosTimer;
 };
@@ -135,7 +139,8 @@ KGlobalLedgerViewPrivate::KGlobalLedgerViewPrivate() :
   m_mousePressFilter(0),
   m_registerSearchLine(0),
   m_inLoading(false),
-  m_recursion(false)
+  m_recursion(false),
+  m_showDetails(false)
 {
 }
 
@@ -220,6 +225,8 @@ KGlobalLedgerView::KGlobalLedgerView(QWidget *parent, const char *name )
   kmymoney2->action("transaction_edit")->plug(m_buttonbar);
   kmymoney2->action("transaction_enter")->plug(m_buttonbar);
   kmymoney2->action("transaction_cancel")->plug(m_buttonbar);
+  kmymoney2->action("transaction_accept")->plug(m_buttonbar);
+  kmymoney2->action("transaction_match")->plug(m_buttonbar);
 
   // create the transaction form frame
   m_formFrame = new QFrame(this);
@@ -235,7 +242,7 @@ KGlobalLedgerView::KGlobalLedgerView(QWidget *parent, const char *name )
   connect(m_register, SIGNAL(focusChanged(KMyMoneyRegister::Transaction*)), m_form, SLOT(slotSetTransaction(KMyMoneyRegister::Transaction*)));
   connect(m_register, SIGNAL(focusChanged()), kmymoney2, SLOT(slotUpdateActions()));
   connect(m_accountComboBox, SIGNAL(accountSelected(const QCString&)), this, SLOT(slotSelectAccount(const QCString&)));
-  connect(m_register, SIGNAL(selectionChanged(const QValueList<KMyMoneyRegister::SelectedTransaction>&)), this, SIGNAL(transactionsSelected(const QValueList<KMyMoneyRegister::SelectedTransaction>&)));
+  connect(m_register, SIGNAL(selectionChanged(const KMyMoneyRegister::SelectedTransactions&)), this, SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)));
   connect(m_register, SIGNAL(editTransaction()), this, SIGNAL(startEdit()));
   connect(m_register, SIGNAL(emptyItemSelected()), this, SLOT(slotNewTransaction()));
   connect(m_register, SIGNAL(aboutToSelectItem(KMyMoneyRegister::RegisterItem*, bool&)), this, SLOT(slotAboutToSelectItem(KMyMoneyRegister::RegisterItem*, bool&)));
@@ -314,13 +321,12 @@ void KGlobalLedgerView::loadView(void)
   // no account selected
   emit accountSelected(MyMoneyAccount());
   // no transaction selected
-  QValueList<KMyMoneyRegister::SelectedTransaction> list;
+  KMyMoneyRegister::SelectedTransactions list;
   emit transactionsSelected(list);
-  // no match transaction selected
-  m_matchTransaction = MyMoneyTransaction();
 
   QMap<QCString, bool> isSelected;
   QCString focusItemId;
+  QCString anchorItemId;
 
   if(!d->m_inLoading)
     d->m_startPoint = QPoint(-1, -1);
@@ -336,14 +342,12 @@ void KGlobalLedgerView::loadView(void)
     // remember the item that has the focus
     if(m_register->focusItem())
       focusItemId = m_register->focusItem()->id();
-
-    // remember if a transaction has a match mark
-    KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(item);
-    if(t && t->hasMatchMark())
-      m_matchTransaction = t->transaction();
+    // and the one that has the selection anchor
+    if(m_register->anchorItem())
+      anchorItemId = m_register->anchorItem()->id();
 
     // remember the upper left corner of the viewport
-    if(!d->m_inLoading)
+    if(!d->m_inLoading && d->m_showDetails == KMyMoneyGlobalSettings::showRegisterDetailed())
       d->m_startPoint = QPoint(m_register->contentsX(), m_register->contentsY());
   } else {
     if(d->m_viewPosTimer.isActive())
@@ -376,6 +380,7 @@ void KGlobalLedgerView::loadView(void)
 
   // ... and recreate it
   KMyMoneyRegister::RegisterItem* focusItem = 0;
+  KMyMoneyRegister::RegisterItem* anchorItem = 0;
   QMap<QCString, MyMoneyMoney> actBalance, clearedBalance, futureBalance;
   QMap<QCString, MyMoneyMoney>::iterator it_b;
   try {
@@ -383,6 +388,7 @@ void KGlobalLedgerView::loadView(void)
     // and update the sort order
     QString sortOrder;
     QCString key;
+    QDate reconciliationDate = d->m_reconciliationDate;
 
     MyMoneyTransactionFilter filter(m_account.id());
     // if it's an investment account, we also take care of
@@ -429,6 +435,43 @@ void KGlobalLedgerView::loadView(void)
       kmymoney2->slotStatusProgressBar(++i, 0);
     }
 
+    // create dummy entries for the scheduled transactions if sorted by postdate
+    int period = KMyMoneyGlobalSettings::schedulePreview();
+    if(m_register->primarySortKey() == KMyMoneyRegister::PostDateSort && !isReconciliationAccount() && period > 0) {
+      QDate endDate = QDate::currentDate().addDays(period);
+      QValueList<MyMoneySchedule> scheduleList = MyMoneyFile::instance()->scheduleList(m_account.id());
+      while(scheduleList.count() > 0){
+        MyMoneySchedule& s = scheduleList.first();
+        for(;;) {
+          if(s.isFinished() || s.nextDueDate() > endDate) {
+            break;;
+          }
+
+          MyMoneyTransaction t(s.id(), KMyMoneyUtils::scheduledTransaction(s));
+          t.setPostDate(s.nextDueDate());
+          // if the transaction is scheduled and overdue, it can't
+          // certainly be posted in the past. So we take todays date
+          // as the alternative
+          if(s.isOverdue())
+            t.setPostDate(QDate::currentDate());
+          const QValueList<MyMoneySplit>& splits = t.splits();
+          QValueList<MyMoneySplit>::const_iterator it_s;
+          for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+            if((*it_s).accountId() == m_account.id()) {
+              new KMyMoneyRegister::StdTransactionScheduled(m_register, t, *it_s, uniqueMap[t.id()]);
+            }
+          }
+          // if this is a one time schedule, we can bail out here as we're done
+          if(s.occurence() == MyMoneySchedule::OCCUR_ONCE)
+            break;
+
+          // for all others, we check if the next payment date is still 'in range'
+          s.setNextDueDate(s.nextPayment(s.nextDueDate()));
+        }
+        scheduleList.pop_front();
+      }
+    }
+
     // add the group markers
     m_register->addGroupMarkers();
 
@@ -438,21 +481,53 @@ void KGlobalLedgerView::loadView(void)
     // remove trailing and adjacent markers
     m_register->removeUnwantedGroupMarkers();
 
+    // add special markers for reconciliation now so that they do not get
+    // removed by m_register->removeUnwantedGroupMarkers(). Needs resorting
+    // of items but that's ok.
+
+    KMyMoneyRegister::StatementGroupMarker* statement = 0;
+    KMyMoneyRegister::StatementGroupMarker* dStatement = 0;
+    KMyMoneyRegister::StatementGroupMarker* pStatement = 0;
+
+    if(isReconciliationAccount()) {
+      switch(m_register->primarySortKey()) {
+        case KMyMoneyRegister::PostDateSort:
+          statement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Details"));
+          m_register->sortItems();
+          break;
+        case KMyMoneyRegister::TypeSort:
+          dStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Deposit Details"));
+          pStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Payment, reconciliationDate, i18n("Statement Payment Details"));
+          m_register->sortItems();
+          break;
+        default:
+          break;
+      }
+    }
+
     // determine balances (actual, cleared). We do this by getting the actual
     // balance of all entered transactions from the engine and walk the list
     // of transactions backward. Also re-select a transaction if it was
     // selected before and setup the focus item.
 
     MyMoneyMoney factor(1,1);
-    if(m_account.accountGroup() == MyMoneyAccount::Liability)
+    if(m_account.accountGroup() == MyMoneyAccount::Liability
+    || m_account.accountGroup() == MyMoneyAccount::Equity)
       factor = -factor;
 
+    QMap<QCString, int> deposits;
+    QMap<QCString, int> payments;
+    QMap<QCString, MyMoneyMoney> depositAmount;
+    QMap<QCString, MyMoneyMoney> paymentAmount;
     for(it_b = actBalance.begin(); it_b != actBalance.end(); ++it_b) {
       MyMoneyMoney balance = MyMoneyFile::instance()->balance(it_b.key());
       balance = balance * factor;
       clearedBalance[it_b.key()] =
       futureBalance[it_b.key()] =
       (*it_b) = balance;
+      deposits[it_b.key()] = payments[it_b.key()] = 0;
+      depositAmount[it_b.key()] = MyMoneyMoney();
+      paymentAmount[it_b.key()] = MyMoneyMoney();
     }
 
     tracer.printf("total balance of %s = %s", m_account.name().data(), actBalance[m_account.id()].formatMoney("", 2).data());
@@ -460,37 +535,77 @@ void KGlobalLedgerView::loadView(void)
     tracer.printf("cleared balance of %s = %s", m_account.name().data(), clearedBalance[m_account.id()].formatMoney("", 2).data());
 
     KMyMoneyRegister::RegisterItem* p = m_register->lastItem();
-    focusItem = p;
+    focusItem = 0;
+
+    // take care of possibly trailing scheduled transactions (bump up the future balance)
+    while(p) {
+      if(p->isSelectable()) {
+        KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
+        if(t && t->isScheduled()) {
+          MyMoneyMoney balance = futureBalance[t->split().accountId()];
+          const MyMoneySplit& split = t->split();
+          // if this split is a stock split, we can't just add the amount of shares
+          if(t->transaction().isStockSplit()) {
+            balance = balance * split.shares();
+          } else {
+            balance += split.shares() * factor;
+          }
+          futureBalance[split.accountId()] = balance;
+        } else if(t && !focusItem)
+          focusItem = p;
+      }
+      p = p->prevItem();
+    }
+
+    p = m_register->lastItem();
     while(p) {
       KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
       if(t) {
         if(isSelected.contains(t->id()))
           t->setSelected(true);
 
-        if(t->transaction().id() == m_matchTransaction.id())
-          t->setMatchMark(true);
-
         if(t->id() == focusItemId)
           focusItem = t;
+        if(t->id() == anchorItemId)
+          anchorItem = t;
 
         MyMoneyMoney balance = futureBalance[t->split().accountId()];
         t->setBalance(balance.formatMoney("", d->m_precision));
         const MyMoneySplit& split = t->split();
+
         // if this split is a stock split, we can't just add the amount of shares
         if(t->transaction().isStockSplit()) {
           balance /= split.shares();
         } else {
           balance -= split.shares() * factor;
         }
-        if(split.reconcileFlag() == MyMoneySplit::NotReconciled) {
-          tracer.printf("Reducing cleared balance by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
-          clearedBalance[t->split().accountId()] -= split.shares() * factor;
+
+        if(!t->isScheduled()) {
+          if(split.reconcileFlag() == MyMoneySplit::NotReconciled) {
+            tracer.printf("Reducing cleared balance by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
+            clearedBalance[split.accountId()] -= split.shares() * factor;
+          }
+          if(isReconciliationAccount() && t->transaction().postDate() > reconciliationDate && split.reconcileFlag() == MyMoneySplit::Cleared) {
+            tracer.printf("Reducing cleared balance by %s because we are in reconciliation, %s/%s(%s)'s date is after or on reconciliation date (%s) and is cleared", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data(), reconciliationDate.toString(Qt::ISODate).data());
+
+            clearedBalance[split.accountId()] -= split.shares() * factor;
+          }
+          if(isReconciliationAccount() && t->transaction().postDate() <= reconciliationDate && split.reconcileFlag() == MyMoneySplit::Cleared) {
+            if(split.shares().isNegative()) {
+              payments[split.accountId()]++;
+              paymentAmount[split.accountId()] += split.shares();
+            } else {
+              deposits[split.accountId()]++;
+              depositAmount[split.accountId()] += split.shares();
+            }
+          }
+
+          if(t->transaction().postDate() > QDate::currentDate()) {
+            tracer.printf("Reducing actual balance by %s because %s/%s(%s) is in the future", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
+            actBalance[split.accountId()] -= split.shares() * factor;
+          }
         }
-        if(t->transaction().postDate() > QDate::currentDate()) {
-          tracer.printf("Reducing actual balance by %s because %s/%s(%s) is in the future", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
-          actBalance[t->split().accountId()] -= split.shares() * factor;
-        }
-        futureBalance[t->split().accountId()] = balance;
+        futureBalance[split.accountId()] = balance;
       }
       p = p->prevItem();
     }
@@ -499,19 +614,44 @@ void KGlobalLedgerView::loadView(void)
     tracer.printf("future balance of %s = %s", m_account.name().data(), futureBalance[m_account.id()].formatMoney("", 2).data());
     tracer.printf("cleared balance of %s = %s", m_account.name().data(), clearedBalance[m_account.id()].formatMoney("", 2).data());
 
+    // update statement information
+    if(statement) {
+      statement->setText(i18n("%1 deposits (%3), %2 payments (%4)").
+          arg(deposits[m_account.id()]).
+          arg(payments[m_account.id()]).
+          arg(depositAmount[m_account.id()].abs().formatMoney(m_account.fraction())).
+          arg(paymentAmount[m_account.id()].abs().formatMoney(m_account.fraction())) );
+    }
+    if(pStatement) {
+      pStatement->setText(i18n("%1 payments (%2)").arg(payments[m_account.id()]).
+          arg(paymentAmount[m_account.id()].abs().formatMoney(m_account.fraction())) );
+    }
+    if(dStatement) {
+      dStatement->setText(i18n("%1 deposits (%2)").arg(deposits[m_account.id()]).
+          arg(depositAmount[m_account.id()].abs().formatMoney(m_account.fraction())) );
+    }
+
     // add a last empty entry for new transactions
     // leave some information about the current account
     MyMoneySplit split;
     split.setReconcileFlag(MyMoneySplit::NotReconciled);
+    // make sure to use the value specified in the option during reconciliation
+    if(isReconciliationAccount())
+      split.setReconcileFlag(static_cast<MyMoneySplit::reconcileFlagE>(KMyMoneyGlobalSettings::defaultReconciliationState()));
     KMyMoneyRegister::Register::transactionFactory(m_register, MyMoneyTransaction(), split, 0);
 
     m_register->updateRegister(true);
 
     if(focusItem) {
-      m_register->selectItem(focusItem, true);
+      // in case we have some selected items we just set the focus item
+      // in other cases, we make the focusitem also the selected item
+      if(isSelected.count() > 1) {
+        m_register->setFocusItem(focusItem);
+        m_register->setAnchorItem(anchorItem);
+      } else
+        m_register->selectItem(focusItem, true);
     } else {
-      // make sure to skip the empty entry at the end if anything else exists
-      // otherwise point to that emtpy line
+      // just use the empty line at the end if nothing else exists in the ledger
       p = m_register->lastItem();
       m_register->setFocusItem(p);
       m_register->selectItem(p);
@@ -540,34 +680,10 @@ void KGlobalLedgerView::loadView(void)
     d->m_inLoading = true;
   }
 
+  d->m_showDetails = KMyMoneyGlobalSettings::showRegisterDetailed();
+
   // and tell everyone what's selected
   emit accountSelected(m_account);
-  emit matchTransactionSelected(m_matchTransaction);
-}
-
-void KGlobalLedgerView::slotStartMatchTransaction(const MyMoneyTransaction& tr)
-{
-  KMyMoneyRegister::RegisterItem* p = m_register->firstItem();
-
-  emit matchTransactionSelected(MyMoneyTransaction());
-
-  while(p) {
-    KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
-    if(t) {
-      bool matches = (t->transaction().id() == tr.id()) && (!tr.id().isEmpty());
-      t->setMatchMark(matches);
-      if(matches) {
-        m_matchTransaction = t->transaction();
-        emit matchTransactionSelected(m_matchTransaction);
-      }
-    }
-    p = p->nextItem();
-  }
-}
-
-void KGlobalLedgerView::slotCancelMatchTransaction(void)
-{
-  slotStartMatchTransaction(MyMoneyTransaction());
 }
 
 void KGlobalLedgerView::updateSummaryLine(const QMap<QCString, MyMoneyMoney>& actBalance, const QMap<QCString, MyMoneyMoney>& clearedBalance)
@@ -586,14 +702,6 @@ void KGlobalLedgerView::updateSummaryLine(const QMap<QCString, MyMoneyMoney>& ac
   } else {
     // update summary line in normal mode
     QDate reconcileDate = m_account.lastReconciliationDate();
-    // For some historic reason, the last reconciliation statement is
-    // stored in the KVP area of the account under the key 'lastStatementDate'.
-    // As long as we don't change that, we continue to read it from there
-    // if the lastReconciliationDate() method returns an invalid date.
-    if(!reconcileDate.isValid()) {
-      if(!m_account.value("lastStatementDate").isEmpty())
-        reconcileDate = QDate::fromString(m_account.value("lastStatementDate"), Qt::ISODate);
-    }
 
     if(reconcileDate.isValid()) {
       m_leftSummaryLabel->setText(i18n("Last reconciled: %1").arg(KGlobal::locale()->formatDate(reconcileDate, true)));
@@ -612,16 +720,22 @@ void KGlobalLedgerView::updateSummaryLine(const QMap<QCString, MyMoneyMoney>& ac
       bool approx = false;
       for(it_b = actBalance.begin(); it_b != actBalance.end(); ++it_b) {
         MyMoneyAccount stock = file->account(it_b.key());
-        MyMoneySecurity sec = file->security(stock.currencyId());
-        MyMoneyMoney rate;
+        QCString currencyId = stock.currencyId();
+        MyMoneySecurity sec = file->security(currencyId);
         MyMoneyPrice priceInfo;
-        priceInfo = file->price(sec.id(), sec.tradingCurrency());
-        approx |= !priceInfo.isValid();
-        rate = priceInfo.rate(sec.tradingCurrency());
-        if(sec.tradingCurrency() != base.id()) {
+        MyMoneyMoney rate(1,1);
+
+        if(stock.isInvest()) {
+          currencyId = sec.tradingCurrency();
+          priceInfo = file->price(sec.id(), currencyId);
+          approx |= !priceInfo.isValid();
+          rate = priceInfo.rate(sec.tradingCurrency());
+        }
+
+        if(currencyId != base.id()) {
           priceInfo = file->price(sec.tradingCurrency(), base.id());
           approx |= !priceInfo.isValid();
-          rate = rate * priceInfo.rate(base.id());
+          rate = (rate * priceInfo.rate(base.id())).convert(MyMoneyMoney::precToDenom(KMyMoneyGlobalSettings::pricePrecision()));
         }
         balance += ((*it_b) * rate).convert(base.smallestAccountFraction());
       }
@@ -723,7 +837,7 @@ void KGlobalLedgerView::slotSelectAllTransactions(void)
   while(p) {
     KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
     if(t) {
-      if(t->isVisible() && t->isSelectable() && !t->id().isEmpty()) {
+      if(t->isVisible() && t->isSelectable() && !t->isScheduled() && !t->id().isEmpty()) {
         t->setSelected(true);
       }
     }
@@ -732,12 +846,11 @@ void KGlobalLedgerView::slotSelectAllTransactions(void)
   m_register->repaintItems();
 
   // inform everyone else about the selected items
-  QValueList<KMyMoneyRegister::SelectedTransaction> list;
-  m_register->selectedTransactions(list);
+  KMyMoneyRegister::SelectedTransactions list(m_register);
   emit transactionsSelected(list);
 }
 
-void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const MyMoneyMoney& endingBalance)
+void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance)
 {
   if(d->m_reconciliationAccount != acc.id()) {
     // make sure the account is selected
@@ -745,6 +858,7 @@ void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const
       slotSelectAccount(acc.id());
 
     d->m_reconciliationAccount = acc.id();
+    d->m_reconciliationDate = reconciliationDate;
     d->m_endingBalance = endingBalance;
     if(acc.accountGroup() == MyMoneyAccount::Liability)
       d->m_endingBalance = -endingBalance;
@@ -806,6 +920,8 @@ bool KGlobalLedgerView::slotSelectAccount(const QCString& id, const QCString& tr
         rc = false;
       }
     } else {
+      // we need to refresh m_account.m_accountList, a child could have been deleted
+      m_account = MyMoneyFile::instance()->account(id);
       emit accountSelected(m_account);
     }
     selectTransaction(transactionId);
@@ -845,8 +961,7 @@ bool KGlobalLedgerView::selectEmptyTransaction(void)
   bool rc = false;
 
   if(!m_inEditMode) {
-    QValueList<KMyMoneyRegister::SelectedTransaction> list;
-    m_register->selectedTransactions(list);
+    KMyMoneyRegister::SelectedTransactions list(m_register);
     if(list.count() > 0 && !list[0].transaction().id().isEmpty()) {
       m_register->clearSelection();
     }
@@ -857,7 +972,7 @@ bool KGlobalLedgerView::selectEmptyTransaction(void)
   return rc;
 }
 
-TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegister::SelectedTransaction>& list)
+TransactionEditor* KGlobalLedgerView::startEdit(const KMyMoneyRegister::SelectedTransactions& list)
 {
   // we use the warnlevel to keep track, if we have to warn the
   // user that some or all splits have been reconciled or if the
@@ -869,20 +984,8 @@ TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegiste
   //     already
   // 2 - user will be informed, that this transaction cannot be changed anymore
 
-  int warnLevel = 0;
-
-  QValueList<KMyMoneyRegister::SelectedTransaction>::const_iterator it_t;
-  for(it_t = list.begin(); warnLevel < 2 && it_t != list.end(); ++it_t) {
-    const QValueList<MyMoneySplit>& splits = (*it_t).transaction().splits();
-    QValueList<MyMoneySplit>::const_iterator it_s;
-    for(it_s = splits.begin(); warnLevel < 2 && it_s != splits.end(); ++it_s) {
-      if((*it_s).reconcileFlag() == MyMoneySplit::Frozen)
-        warnLevel = 2;
-      if((*it_s).reconcileFlag() == MyMoneySplit::Reconciled && warnLevel < 1)
-        warnLevel = 1;
-
-    }
-  }
+  int warnLevel = list.warnLevel();
+  Q_ASSERT(warnLevel<2);  // otherwise the edit action should not be enabled
 
   switch(warnLevel) {
     case 0:
@@ -896,7 +999,6 @@ TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegiste
         ),
         i18n("Transaction already reconciled"), KStdGuiItem::cont(),
         "EditReconciledTransaction") == KMessageBox::Cancel) {
-
         warnLevel = 2;
       }
       break;
@@ -907,28 +1009,36 @@ TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegiste
                  "Editing the transactions is therefore prohibited."),
             i18n("Transaction already frozen"));
       break;
+
+    case 3:
+      KMessageBox::sorry(0,
+            i18n("At least one split of the selected transaction references an account that has been closed. "
+                 "Editing the transactions is therefore prohibited."),
+            i18n("Account closed"));
+      break;
   }
 
-  if(warnLevel == 2)
+  if(warnLevel > 1)
     return 0;
 
 
   TransactionEditor* editor = 0;
   KMyMoneyRegister::Transaction* item = dynamic_cast<KMyMoneyRegister::Transaction*>(m_register->focusItem());
-  // in case the current focus item is not selected, we move the focus to the first selected transaction
-  if(!item->isSelected()) {
-    KMyMoneyRegister::RegisterItem* p;
-    for(p = m_register->firstItem(); p; p = p->nextItem()) {
-      KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
-      if(t && t->isSelected()) {
-        m_register->setFocusItem(t);
-        item = t;
-        break;
-      }
-    }
-  }
 
   if(item) {
+    // in case the current focus item is not selected, we move the focus to the first selected transaction
+    if(!item->isSelected()) {
+      KMyMoneyRegister::RegisterItem* p;
+      for(p = m_register->firstItem(); p; p = p->nextItem()) {
+        KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
+        if(t && t->isSelected()) {
+          m_register->setFocusItem(t);
+          item = t;
+          break;
+        }
+      }
+    }
+
     // decide, if we edit in the register or in the form
     TransactionEditorContainer* parent;
     if(m_formFrame->isVisible())
@@ -963,7 +1073,7 @@ TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegiste
       connect(editor, SIGNAL(escapePressed()), kmymoney2->action("transaction_cancel"), SLOT(activate()));
 
       connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), editor, SLOT(slotReloadEditWidgets()));
-      connect(editor, SIGNAL(finishEdit(const QValueList<KMyMoneyRegister::SelectedTransaction >&)), this, SLOT(slotLeaveEditMode(const QValueList<KMyMoneyRegister::SelectedTransaction >&)));
+      connect(editor, SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
 
       connect(editor, SIGNAL(objectCreation(bool)), d->m_mousePressFilter, SLOT(setFilterDeactive(bool)));
       connect(editor, SIGNAL(createPayee(const QString&, QCString&)), kmymoney2, SLOT(slotPayeeNew(const QString&, QCString&)));
@@ -1004,7 +1114,7 @@ TransactionEditor* KGlobalLedgerView::startEdit(const QValueList<KMyMoneyRegiste
   return editor;
 }
 
-void KGlobalLedgerView::slotLeaveEditMode(const QValueList<KMyMoneyRegister::SelectedTransaction>& list)
+void KGlobalLedgerView::slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions& list)
 {
   m_inEditMode = false;
   qApp->removeEventFilter(d->m_mousePressFilter);
@@ -1091,10 +1201,8 @@ void KGlobalLedgerView::show(void)
 
   } else {
     emit accountSelected(m_account);
-    QValueList<KMyMoneyRegister::SelectedTransaction> list;
-    m_register->selectedTransactions(list);
+    KMyMoneyRegister::SelectedTransactions list(m_register);
     emit transactionsSelected(list);
-    emit matchTransactionSelected(m_matchTransaction);
   }
 
   // don't forget base class implementation
@@ -1194,27 +1302,45 @@ void KGlobalLedgerView::slotKeepPostDate(const QDate& date)
 bool KGlobalLedgerView::canCreateTransactions(QString& tooltip) const
 {
   bool rc = true;
+  if(m_account.id().isEmpty()) {
+    tooltip = i18n("Cannot create transactions when no account is selected.");
+    rc = false;
+  }
   if(m_account.accountGroup() == MyMoneyAccount::Income
   || m_account.accountGroup() == MyMoneyAccount::Expense) {
     tooltip = i18n("Cannot create transactions in the context of a category.");
     rc = false;
   }
+  if(m_account.isClosed()) {
+    tooltip = i18n("Cannot create transactions in a closed account.");
+    rc = false;
+  }
   return rc;
 }
 
-bool KGlobalLedgerView::canModifyTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const
+bool KGlobalLedgerView::canProcessTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
 {
   if(m_register->focusItem() == 0)
     return false;
 
   if(!m_register->focusItem()->isSelected()) {
-    tooltip = i18n("Cannot modify transaction with focus if it is not selected.");
+    tooltip = i18n("Cannot process transaction with focus if it is not selected.");
     return false;
   }
   return list.count() > 0;
 }
 
-bool KGlobalLedgerView::canEditTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const
+bool KGlobalLedgerView::canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
+{
+  return canProcessTransactions(list,tooltip) && list.canModify();
+}
+
+bool KGlobalLedgerView::canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
+{
+  return canProcessTransactions(list,tooltip) && list.canDuplicate();
+}
+
+bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
 {
   // check if we can edit the list of transactions. We can edit, if
   //
@@ -1224,8 +1350,14 @@ bool KGlobalLedgerView::canEditTransactions(const QValueList<KMyMoneyRegister::S
   //   d) the transaction having the current focus is selected
 
   // check for d)
-  if(!canModifyTransactions(list, tooltip))
+  if(!canProcessTransactions(list, tooltip))
     return false;
+  // check for c)
+  if (list.warnLevel() == 2) {
+    tooltip = i18n("Cannot edit transactions with frozen splits.");
+    return false;
+  }
+
 
   bool rc = true;
   int investmentTransactions = 0;
@@ -1237,7 +1369,7 @@ bool KGlobalLedgerView::canEditTransactions(const QValueList<KMyMoneyRegister::S
     rc = false;
   }
 
-  QValueList<KMyMoneyRegister::SelectedTransaction>::const_iterator it_t;
+  KMyMoneyRegister::SelectedTransactions::const_iterator it_t;
   for(it_t = list.begin(); rc && it_t != list.end(); ++it_t) {
     if((*it_t).transaction().id().isEmpty()) {
       tooltip = QString();
@@ -1265,17 +1397,6 @@ bool KGlobalLedgerView::canEditTransactions(const QValueList<KMyMoneyRegister::S
         break;
       }
     }
-
-    // check for c)
-    const QValueList<MyMoneySplit>& splits = (*it_t).transaction().splits();
-    QValueList<MyMoneySplit>::const_iterator it_s;
-    for(it_s = splits.begin(); rc && it_s != splits.end(); ++it_s) {
-      if((*it_s).reconcileFlag() == MyMoneySplit::Frozen) {
-        tooltip = i18n("Cannot edit transactions with frozen splits.");
-        rc = false;
-      }
-    }
-
   }
 
   // now check that we have the correct account type for investment transactions
