@@ -70,7 +70,6 @@
 #include <string>
 #endif
 
-#include "../dialogs/knewaccountdlg.h"
 #include "../dialogs/kendingbalancedlg.h"
 #include "../dialogs/kchooseimportexportdlg.h"
 #include "../dialogs/kcsvprogressdlg.h"
@@ -78,13 +77,12 @@
 #include "../dialogs/kexportdlg.h"
 #include "../dialogs/knewloanwizard.h"
 #include "../dialogs/kcurrencyeditdlg.h"
-#include "../dialogs/kofxdirectconnectdlg.h"
 #include "../dialogs/kfindtransactiondlg.h"
 #include "../dialogs/knewbankdlg.h"
 #include "../dialogs/knewfiledlg.h"
 
 #include "../mymoney/storage/mymoneyseqaccessmgr.h"
-//#include "../mymoney/storage/mymoneydatabasemgr.h"
+#include "../mymoney/storage/mymoneydatabasemgr.h"
 #include "../mymoney/storage/imymoneystorageformat.h"
 #include "../mymoney/storage/mymoneystoragebin.h"
 #include "../mymoney/mymoneyexception.h"
@@ -151,7 +149,7 @@ KMyMoneyView::KMyMoneyView(QWidget *parent, const char *name)
   connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, SLOT(slotInstitutionEdit(const MyMoneyObject&)));
   connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, SLOT(slotAccountOpen(const MyMoneyObject&)));
   connect(m_institutionsView, SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&)), kmymoney2, SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyInstitution&)));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const MyMoneyMoney&)), m_institutionsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const MyMoneyMoney&)));
+  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_institutionsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
 
   // Page 2
   m_accountsViewFrame = addVBoxPage( i18n("Accounts"), i18n("Accounts"),
@@ -164,7 +162,7 @@ KMyMoneyView::KMyMoneyView(QWidget *parent, const char *name)
   connect(m_accountsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, SLOT(slotAccountOpen(const MyMoneyObject&)));
   connect(m_accountsView, SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
   connect(this, SIGNAL(kmmFilePlugin(unsigned int)), m_accountsView, SLOT(slotUpdateIconPos(unsigned int)));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const MyMoneyMoney&)), m_accountsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const MyMoneyMoney&)));
+  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_accountsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
 
   // Page 3
   m_scheduleViewFrame = addVBoxPage( i18n("Schedule"), i18n("Bills & Reminders"),
@@ -203,17 +201,13 @@ KMyMoneyView::KMyMoneyView(QWidget *parent, const char *name)
   m_ledgerView = new KGlobalLedgerView(m_ledgerViewFrame, "GlobalLedgerView");
   connect(m_ledgerView, SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, SLOT(slotSelectAccount(const MyMoneyObject&)));
   connect(m_ledgerView, SIGNAL(openContextMenu()), kmymoney2, SLOT(slotShowTransactionContextMenu()));
-  connect(m_ledgerView, SIGNAL(transactionsSelected(const QValueList<KMyMoneyRegister::SelectedTransaction>&)), kmymoney2, SLOT(slotSelectTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>&)));
+  connect(m_ledgerView, SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)), kmymoney2, SLOT(slotSelectTransactions(const KMyMoneyRegister::SelectedTransactions&)));
   connect(m_ledgerView, SIGNAL(newTransaction()), kmymoney2, SLOT(slotTransactionsNew()));
   connect(m_ledgerView, SIGNAL(cancelOrEndEdit(bool&)), kmymoney2, SLOT(slotTransactionsCancelOrEnter(bool&)));
   connect(m_ledgerView, SIGNAL(startEdit()), kmymoney2, SLOT(slotTransactionsEdit()));
   connect(m_ledgerView, SIGNAL(endEdit()), kmymoney2, SLOT(slotTransactionsEnter()));
   connect(m_ledgerView, SIGNAL(toggleReconciliationFlag()), kmymoney2, SLOT(slotToggleReconciliationFlag()));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const MyMoneyMoney&)), m_ledgerView, SLOT(slotSetReconcileAccount(const MyMoneyAccount&, const MyMoneyMoney&)));
-  connect(m_ledgerView, SIGNAL(matchTransactionSelected(const MyMoneyTransaction&)), kmymoney2, SLOT(slotSelectMatchTransaction(const MyMoneyTransaction&)));
-
-  connect(kmymoney2, SIGNAL(startMatchTransaction(const MyMoneyTransaction&)), m_ledgerView, SLOT(slotStartMatchTransaction(const MyMoneyTransaction&)));
-  connect(kmymoney2, SIGNAL(cancelMatchTransaction()), m_ledgerView, SLOT(slotCancelMatchTransaction()));
+  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_ledgerView, SLOT(slotSetReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
   connect(kmymoney2, SIGNAL(selectAllTransactions()), m_ledgerView, SLOT(slotSelectAllTransactions()));
 
   // Page 7
@@ -311,7 +305,7 @@ bool KMyMoneyView::canPrint(void)
   return rc;
 }
 
-bool KMyMoneyView::canCreateTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& /* list */, QString& tooltip) const
+bool KMyMoneyView::canCreateTransactions(const KMyMoneyRegister::SelectedTransactions& /* list */, QString& tooltip) const
 {
   // we can only create transactions in the ledger view so
   // we check that this is the active page
@@ -324,7 +318,7 @@ bool KMyMoneyView::canCreateTransactions(const QValueList<KMyMoneyRegister::Sele
   return rc;
 }
 
-bool KMyMoneyView::canModifyTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const
+bool KMyMoneyView::canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
 {
   // we can only modify transactions in the ledger view so
   // we check that this is the active page
@@ -339,7 +333,22 @@ bool KMyMoneyView::canModifyTransactions(const QValueList<KMyMoneyRegister::Sele
   return rc;
 }
 
-bool KMyMoneyView::canEditTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const
+bool KMyMoneyView::canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
+{
+  // we can only duplicate transactions in the ledger view so
+  // we check that this is the active page
+
+  bool rc = (activePageIndex() == pageIndex(m_ledgerViewFrame));
+
+  if(rc) {
+    rc = m_ledgerView->canDuplicateTransactions(list, tooltip);
+  } else {
+    tooltip = i18n("Duplicating transactions can only be performed in the ledger view");
+  }
+  return rc;
+}
+
+bool KMyMoneyView::canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const
 {
   bool rc;
   // we can only edit transactions in the ledger view so
@@ -355,7 +364,7 @@ bool KMyMoneyView::canEditTransactions(const QValueList<KMyMoneyRegister::Select
 bool KMyMoneyView::createNewTransaction(void)
 {
   bool rc = false;
-  QValueList<KMyMoneyRegister::SelectedTransaction> list;
+  KMyMoneyRegister::SelectedTransactions list;
   QString txt;
   if(canCreateTransactions(list, txt)) {
     rc = m_ledgerView->selectEmptyTransaction();
@@ -363,7 +372,7 @@ bool KMyMoneyView::createNewTransaction(void)
   return rc;
 }
 
-TransactionEditor* KMyMoneyView::startEdit(const QValueList<KMyMoneyRegister::SelectedTransaction>& list)
+TransactionEditor* KMyMoneyView::startEdit(const KMyMoneyRegister::SelectedTransactions& list)
 {
   TransactionEditor* editor = 0;
   QString txt;
@@ -378,8 +387,8 @@ void KMyMoneyView::newStorage(storageTypeE t)
   removeStorage();
   MyMoneyFile* file = MyMoneyFile::instance();
   if (t == Memory) file->attachStorage(new MyMoneySeqAccessMgr);
-  else //file->attachStorage(new MyMoneyDatabaseMgr);
-    qFatal ("Mode not implemented");
+  else file->attachStorage(new MyMoneyDatabaseMgr);
+    //qFatal ("Mode not implemented");
 }
 
 void KMyMoneyView::removeStorage(void)
@@ -435,6 +444,7 @@ void KMyMoneyView::slotLedgerSelected(const QCString& _accId, const QCString& tr
     case MyMoneyAccount::Income:
     case MyMoneyAccount::Expense:
     case MyMoneyAccount::Investment:
+    case MyMoneyAccount::Equity:
       showPage(pageIndex(m_ledgerViewFrame));
       m_ledgerView->slotSelectAccount(accId, transaction);
       break;
@@ -461,8 +471,6 @@ void KMyMoneyView::slotScheduleSelected(const QCString& scheduleId)
 {
   MyMoneySchedule sched = MyMoneyFile::instance()->schedule(scheduleId);
   kmymoney2->slotSelectSchedule(sched);
-  showPage(pageIndex(m_scheduleViewFrame));
-  m_scheduledView->slotSelectSchedule(scheduleId);
 }
 
 void KMyMoneyView::slotShowReport(const QCString& reportid)
@@ -488,7 +496,7 @@ void KMyMoneyView::closeFile(void)
     m_reportsView->slotCloseAll();
 
   emit kmmFilePlugin (preClose);
-  if (isSyncDatabase() && m_fileOpen)
+  if (isSyncDatabase())
     MyMoneyFile::instance()->storage()->close(); // to log off a database user
   newStorage();
   slotShowHomePage();
@@ -509,7 +517,7 @@ bool KMyMoneyView::readFile(const KURL& url)
 {
   QString filename;
 
-  newStorage();
+//  newStorage();
   m_fileOpen = false;
   bool isEncrypted = false;
 
@@ -525,6 +533,8 @@ bool KMyMoneyView::readFile(const KURL& url)
   }
 
   if (url.protocol() == "sql") { // handle reading of database
+    //newStorage(Database);
+    MyMoneyFile::instance()->detachStorage();
     if (url.queryItem("mode") == "single") {
       m_fileType = KmmDbSingleUser;
       return (openDatabase(url)); // open database in single user mode
@@ -542,6 +552,8 @@ bool KMyMoneyView::readFile(const KURL& url)
     }
   }
 
+  newStorage();
+
   if(url.isLocalFile()) {
     filename = url.path();
 
@@ -656,7 +668,7 @@ bool KMyMoneyView::readFile(const KURL& url)
                   ungetString(qfile, hdr.data(), 70);
                 QRegExp kmyexp("<!DOCTYPE KMYMONEY-FILE>");
                 QRegExp gncexp("<gnc-v(\\d+)");
-                QCString txt(hdr);
+                QCString txt(hdr, 70);
                 if(kmyexp.search(txt) != -1) {
                   ::timetrace("is XML format");
                   pReader = new MyMoneyStorageXML;
@@ -717,7 +729,7 @@ bool KMyMoneyView::readFile(const KURL& url)
   // make sure we setup the encryption key correctly
   MyMoneyFileTransaction ft;
   if(isEncrypted && MyMoneyFile::instance()->value("kmm-encryption-key").isEmpty()) {
-    MyMoneyFile::instance()->setValue("kmm-encryption-key", KMyMoneyGlobalSettings::gpgRecipient());
+    MyMoneyFile::instance()->setValue("kmm-encryption-key", KMyMoneyGlobalSettings::gpgRecipientList().join(","));
   }
 
   // make sure we setup the name of the base accounts in translated form
@@ -761,6 +773,11 @@ bool KMyMoneyView::openDatabase (const KURL& url) {
   }
   // open the database in single-user mode
   IMyMoneySerialize* pStorage = dynamic_cast<IMyMoneySerialize*> (MyMoneyFile::instance()->storage());
+  MyMoneyDatabaseMgr* pDBMgr = 0;
+  if (! pStorage) {
+    pDBMgr = new MyMoneyDatabaseMgr;
+    pStorage = dynamic_cast<IMyMoneySerialize*> (pDBMgr);
+  }
   MyMoneyStorageSql* reader = pStorage->connectToDatabase (url);
   KURL dbURL (url);
   bool retry = true;
@@ -771,9 +788,17 @@ bool KMyMoneyView::openDatabase (const KURL& url) {
       break;
     case 1: // permanent error
       KMessageBox::detailedError (this, i18n("Can't open database %1\n").arg(dbURL.prettyURL()), reader->lastError());
+      if (pDBMgr) {
+        removeStorage();
+        delete pDBMgr;
+      }
       return false;
     case -1: // retryable error
       if (KMessageBox::warningYesNo (this, reader->lastError(), PACKAGE) == KMessageBox::No) {
+        if (pDBMgr) {
+          removeStorage();
+          delete pDBMgr;
+        }
         return false;
       } else {
         QString options = dbURL.queryItem("options") + ",override";
@@ -782,6 +807,10 @@ bool KMyMoneyView::openDatabase (const KURL& url) {
       }
     }
   }
+  if (pDBMgr) {
+    removeStorage();
+    MyMoneyFile::instance()->attachStorage(pDBMgr);
+  }
   // single user mode; read some of the data into memory
   reader->setProgressCallback(&KMyMoneyView::progressCallback);
   if (!reader->readFile()) {
@@ -811,6 +840,7 @@ bool KMyMoneyView::initializeStorage()
     ft.commit();
   } catch(MyMoneyException *e) {
     delete e;
+    MyMoneyFile::instance()->blockSignals(blocked);
     return false;
   }
 
@@ -859,6 +889,7 @@ bool KMyMoneyView::initializeStorage()
       // Check if we have to modify the file before we allow to work with it
       IMyMoneyStorage* s = MyMoneyFile::instance()->storage();
       while (s->fileFixVersion() < s->currentFixVersion()) {
+        qDebug("%s", (QString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion())).data());
         switch (s->fileFixVersion()) {
           case 0:
             fixFile_0();
@@ -870,6 +901,13 @@ bool KMyMoneyView::initializeStorage()
             s->setFileFixVersion(2);
             break;
 
+          case 2:
+            fixFile_2();
+            s->setFileFixVersion(3);
+            break;
+
+          // add new levels above. Don't forget to increase currentFixVersion() for all
+          // the storage backends this fix applies to
           default:
             throw new MYMONEYEXCEPTION(i18n("Unknown fix level in input file"));
         }
@@ -877,6 +915,7 @@ bool KMyMoneyView::initializeStorage()
       ft.commit();
     } catch(MyMoneyException *e) {
       delete e;
+      MyMoneyFile::instance()->blockSignals(blocked);
       return false;
     }
   } else {
@@ -906,7 +945,7 @@ bool KMyMoneyView::initializeStorage()
   return true;
 }
 
-void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter, bool plaintext, const QString& key)
+void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter, bool plaintext, const QString& keyList)
 {
   QIODevice *dev = qfile;
   KFilterBase *base = 0;
@@ -914,7 +953,7 @@ void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter,
 
   bool encryptedOk = true;
   bool encryptRecover = false;
-  if(!key.isEmpty()) {
+  if(!keyList.isEmpty()) {
     if(!KGPGFile::GPGAvailable()) {
       KMessageBox::sorry(this, i18n("GPG does not seem to be installed on your system. Please make sure, that GPG can be found using the standard search path. This time, encryption is disabled."), i18n("GPG not found"));
       encryptedOk = false;
@@ -928,9 +967,13 @@ void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter,
       }
     }
 
-    if(!KGPGFile::keyAvailable(key)) {
-      KMessageBox::sorry(this, QString("<p>")+i18n("You have specified to encrypt your data for the user-id</p><p><center><b>%1</b>.</center></p>Unfortunately, a valid key for this user-id was not found in your keyring. Please make sure to import a valid key for this user-id. This time, encryption is disabled.").arg(key), i18n("GPG-Key not found"));
-      encryptedOk = false;
+    QStringList keys = QStringList::split(",", keyList);
+    QStringList::const_iterator it_s;
+    for(it_s = keys.begin(); it_s != keys.begin(); ++it_s) {
+      if(!KGPGFile::keyAvailable(*it_s)) {
+        KMessageBox::sorry(this, QString("<p>")+i18n("You have specified to encrypt your data for the user-id</p><p><center><b>%1</b>.</center></p>Unfortunately, a valid key for this user-id was not found in your keyring. Please make sure to import a valid key for this user-id. This time, encryption is disabled.").arg(*it_s), i18n("GPG-Key not found"));
+        encryptedOk = false;
+      }
     }
 
     if(encryptedOk == true) {
@@ -947,16 +990,20 @@ void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter,
   MyMoneyFile::instance()->blockSignals(true);
   MyMoneyFileTransaction ft;
   MyMoneyFile::instance()->deletePair("kmm-encryption-key");
-  if(!key.isEmpty() && encryptedOk == true && !plaintext ) {
+  if(!keyList.isEmpty() && encryptedOk == true && !plaintext ) {
     qfile->close();
     base++;
     KGPGFile *kgpg = new KGPGFile(qfile->name());
     if(kgpg) {
-      kgpg->addRecipient(key.latin1());
+      QStringList keys = QStringList::split(",", keyList);
+      QStringList::const_iterator it_s;
+      for(it_s = keys.begin(); it_s != keys.end(); ++it_s) {
+        kgpg->addRecipient((*it_s).latin1());
+      }
       if(encryptRecover) {
         kgpg->addRecipient(RECOVER_KEY_ID);
       }
-      MyMoneyFile::instance()->setValue("kmm-encryption-key", key);
+      MyMoneyFile::instance()->setValue("kmm-encryption-key", keyList);
     }
     statusDevice = dev = kgpg;
     if(!dev || !dev->open(IO_WriteOnly)) {
@@ -1005,7 +1052,7 @@ void KMyMoneyView::saveToLocalFile(QFile* qfile, IMyMoneyStorageFormat* pWriter,
     qfile->close();
 }
 
-const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
+bool KMyMoneyView::saveFile(const KURL& url, const QString& keyList)
 {
   QString filename = url.path();
 
@@ -1014,6 +1061,7 @@ const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
     return false;
   }
 
+#if 0
   if(KMessageBox::warningContinueCancel(this, i18n(
       "Since this version of KMyMoney only writes data files in its new "
       "format, files written with this version cannot be read by KMyMoney version 0.4. "
@@ -1022,6 +1070,7 @@ const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
       "If you want to abort this operation, please press Cancel now"),
       QString::null, KStdGuiItem::cont(), "WarningNewFileVersion0.5") == KMessageBox::Cancel)
     return false;
+#endif
 
   emit kmmFilePlugin (preSave);
   IMyMoneyStorageFormat* pWriter = NULL;
@@ -1067,7 +1116,7 @@ const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
         KSaveFile qfile(filename, fmode);
         if(qfile.status() == 0) {
           try {
-            saveToLocalFile(qfile.file(), pWriter, plaintext, key);
+            saveToLocalFile(qfile.file(), pWriter, plaintext, keyList);
           } catch (MyMoneyException* e) {
             qfile.abort();
             delete e;
@@ -1080,7 +1129,7 @@ const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
       chown(filename, static_cast<uid_t>(-1), gid);
     } else {
       KTempFile tmpfile;
-      saveToLocalFile(tmpfile.file(), pWriter, plaintext, key);
+      saveToLocalFile(tmpfile.file(), pWriter, plaintext, keyList);
       if(!KIO::NetAccess::upload(tmpfile.name(), url, NULL))
         throw new MYMONEYEXCEPTION(i18n("Unable to upload to '%1'").arg(url.url()));
       tmpfile.unlink();
@@ -1097,7 +1146,7 @@ const bool KMyMoneyView::saveFile(const KURL& url, const QString& key)
   return rc;
 }
 
-const bool KMyMoneyView::saveAsDatabase(const KURL& url)
+bool KMyMoneyView::saveAsDatabase(const KURL& url)
 {
   bool rc = false;
   if (!fileOpen()) {
@@ -1183,7 +1232,7 @@ bool KMyMoneyView::dirty(void)
   return MyMoneyFile::instance()->dirty();
 }
 
-bool KMyMoneyView::startReconciliation(const MyMoneyAccount& account, const MyMoneyMoney& endingBalance)
+bool KMyMoneyView::startReconciliation(const MyMoneyAccount& account, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance)
 {
   bool  ok = true;
 
@@ -1197,7 +1246,7 @@ bool KMyMoneyView::startReconciliation(const MyMoneyAccount& account, const MyMo
     if(account.isAssetLiability()) {
       showPage(pageIndex(m_ledgerViewFrame));
       // prepare reconciliation mode
-      emit reconciliationStarts(account, endingBalance);
+      emit reconciliationStarts(account, reconciliationDate, endingBalance);
     } else {
       ok = false;
     }
@@ -1208,7 +1257,7 @@ bool KMyMoneyView::startReconciliation(const MyMoneyAccount& account, const MyMo
 
 void KMyMoneyView::finishReconciliation(const MyMoneyAccount& /* account */)
 {
-  emit reconciliationStarts(MyMoneyAccount(), MyMoneyMoney());
+  emit reconciliationStarts(MyMoneyAccount(), QDate(), MyMoneyMoney());
 }
 
 void KMyMoneyView::newFile(void)
@@ -1593,6 +1642,53 @@ void KMyMoneyView::slotRememberPage(QWidget* w)
 /* DO NOT ADD code to this function or any of it's called ones.
    Instead, create a new function, fixFile_n, and modify the initializeStorage()
    logic above to call it */
+
+void KMyMoneyView::fixFile_2(void)
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+  MyMoneyTransactionFilter filter;
+  filter.setReportAllSplits( false );
+  QValueList<MyMoneyTransaction> transactionList;
+  file->transactionList(transactionList, filter);
+
+  // scan the transactions and modify transactions with two splits
+  // which reference an account and a category to have the memo text
+  // of the account.
+  QValueList<MyMoneyTransaction>::Iterator it_t;
+  int count = 0;
+  for(it_t = transactionList.begin(); it_t != transactionList.end(); ++it_t) {
+    if((*it_t).splitCount() == 2) {
+      QCString accountId;
+      QCString categoryId;
+      QString accountMemo;
+      QString categoryMemo;
+      const QValueList<MyMoneySplit>& splits = (*it_t).splits();
+      QValueList<MyMoneySplit>::const_iterator it_s;
+      for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+        MyMoneyAccount acc = file->account((*it_s).accountId());
+        if(acc.isIncomeExpense()) {
+          categoryId = (*it_s).id();
+          categoryMemo = (*it_s).memo();
+        } else {
+          accountId = (*it_s).id();
+          accountMemo = (*it_s).memo();
+        }
+      }
+
+      if(!accountId.isEmpty() && !categoryId.isEmpty()
+      && accountMemo != categoryMemo) {
+        MyMoneyTransaction t(*it_t);
+        MyMoneySplit s(t.splitById(categoryId));
+        s.setMemo(accountMemo);
+        t.modifySplit(s);
+        file->modifyTransaction(t);
+        ++count;
+      }
+    }
+  }
+  qDebug("%d transactions fixed in fixFile_2", count);
+}
+
 void KMyMoneyView::fixFile_1(void)
 {
   // we need to fix reports. If the account filter list contains
@@ -1870,7 +1966,7 @@ void KMyMoneyView::fixTransactions_0(void)
   QValueList<MyMoneySchedule>::Iterator it_x;
   QCStringList interestAccounts;
 
-  QString prevMsg = kmymoney2->slotStatusMsg(i18n("Fix transactions"));
+  KMSTATUS(i18n("Fix transactions"));
   kmymoney2->slotStatusProgressBar(0, scheduleList.count() + transactionList.count());
 
   int cnt = 0;
@@ -2067,7 +2163,6 @@ void KMyMoneyView::fixTransactions_0(void)
   }
 
   kmymoney2->slotStatusProgressBar(-1, -1);
-  kmymoney2->slotStatusMsg(prevMsg);
 }
 
 void KMyMoneyView::fixDuplicateAccounts_0(MyMoneyTransaction& t)
