@@ -208,6 +208,7 @@ private:
     */
   void fixFile_0(void);
   void fixFile_1(void);
+  void fixFile_2(void);
 
   /**
     */
@@ -265,14 +266,14 @@ public:
     *
     * @param url The URL to save into.
     *            If no protocol is specified, file:// is assumed.
-    * @param key QString containing the key to be used for encryption
-    *            If @p key is empty, the file will be saved unencrypted
-    *            (the default)
+    * @param keyList QString containing a comma separated list of keys
+    *            to be used for encryption. If @p keyList is empty,
+    *            the file will be saved unencrypted (the default)
     *
     * @retval false save operation failed
     * @retval true save operation was successful
     */
-  const bool saveFile(const KURL& url, const QString& key = QString());
+  bool saveFile(const KURL& url, const QString& keyList = QString());
   /**
    * Saves the data into permanent storage on a new or empty SQL database.
    *
@@ -290,7 +291,7 @@ public:
    * @retval false save operation failed
    * @retval true save operation was successful
    */
-  const bool saveAsDatabase(const KURL& url);
+  bool saveAsDatabase(const KURL& url);
 
   /**
     * Call this to find out if the currently open file is native KMM
@@ -298,7 +299,7 @@ public:
     * @retval true file is native
     * @retval false file is foreign
     */
-  const bool isNativeFile() { return (m_fileType < MaxNativeFileType);};
+  bool isNativeFile() { return (m_fileOpen && (m_fileType < MaxNativeFileType)); }
 
   /**
    * Call this to find out if the currently open file is a sql database
@@ -306,8 +307,8 @@ public:
    * @retval true file is database
    * @retval false file is serial
    */
-  const bool isDatabase()
-    { return ((m_fileType == KmmDbFile) || (m_fileType == KmmDbSingleUser) || (m_fileType == KmmDbMultiUser));};
+  bool isDatabase()
+    { return (m_fileOpen && ((m_fileType == KmmDbFile) || (m_fileType == KmmDbSingleUser) || (m_fileType == KmmDbMultiUser))); }
 
   /**
    * Call this to find out if the currently open file is a SQL database
@@ -316,8 +317,8 @@ public:
    * @retval true file is synchronous
    * @retval false file is asynchronous
    */
-  const bool isSyncDatabase()
-  { return ((m_fileType == KmmDbSingleUser) || (m_fileType == KmmDbMultiUser));};
+  bool isSyncDatabase()
+  { return (m_fileOpen && ((m_fileType == KmmDbSingleUser) || (m_fileType == KmmDbMultiUser))); }
 
   /**
     * Call this to see if the MyMoneyFile contains any unsaved data.
@@ -366,7 +367,7 @@ public:
     * @retval true Yes, view allows to create a transaction (tooltip is not changed)
     * @retval false No, view cannot to create a transaction (tooltip is updated with message)
     */
-  bool canCreateTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const;
+  bool canCreateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
 
   /**
     * check if the current view allows to modify (edit/delete) the selected transactions
@@ -379,9 +380,11 @@ public:
     * @retval true Yes, view allows to edit/delete transactions (tooltip is not changed)
     * @retval false No, view cannot edit/delete transactions (tooltip is updated with message)
     */
-  bool canModifyTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const;
+  bool canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
 
-  /**
+  bool canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
+
+      /**
     * check if the current view allows to edit the selected transactions
     *
     * @param list list of selected transactions
@@ -392,7 +395,7 @@ public:
     * @retval true Yes, view allows to enter/edit transactions
     * @retval false No, view cannot enter/edit transactions
     */
-  bool canEditTransactions(const QValueList<KMyMoneyRegister::SelectedTransaction>& list, QString& tooltip) const;
+  bool canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
 
   /**
     * check if the current view allows to print something
@@ -402,7 +405,7 @@ public:
     */
   bool canPrint(void);
 
-  TransactionEditor* startEdit(const QValueList<KMyMoneyRegister::SelectedTransaction>&);
+  TransactionEditor* startEdit(const KMyMoneyRegister::SelectedTransactions&);
 
   bool createNewTransaction(void);
 
@@ -416,7 +419,7 @@ public:
     * @retval true Reconciliation started
     * @retval false Account cannot be reconciled
     */
-  bool startReconciliation(const MyMoneyAccount& account, const MyMoneyMoney& endingBalance);
+  bool startReconciliation(const MyMoneyAccount& account, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
 
   /**
     * Used to finish reconciliation of account @a account. It switches the
@@ -553,12 +556,12 @@ private:
     * @param qf pointer to QFile representing the opened file
     * @param writer pointer to the formatter
     * @param plaintext whether to override any compression & encryption settings
-    * @param key QString containing the key to be used for encryption
-    *            If @p key is empty, the file will be saved unencrypted
+    * @param keyList QString containing a comma separated list of keys to be used for encryption
+    *            If @p keyList is empty, the file will be saved unencrypted
     *
     * @note This method will close the file when it is written.
     */
-  void saveToLocalFile(QFile* qf, IMyMoneyStorageFormat* writer, bool plaintext=false, const QString& key = QString());
+  void saveToLocalFile(QFile* qf, IMyMoneyStorageFormat* writer, bool plaintext=false, const QString& keyList = QString());
 
   /**
     * Internal method used by slotAccountNew() and slotAccountCategory().
@@ -590,7 +593,7 @@ signals:
     * @param endingBalance collected ending balance when reconciliation starts
     *                0 otherwise
     */
-  void reconciliationStarts(const MyMoneyAccount& account, const MyMoneyMoney& endingBalance);
+  void reconciliationStarts(const MyMoneyAccount& account, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
 
 };
 
@@ -605,7 +608,7 @@ class KMyMoneyViewBase : public QWidget
   Q_OBJECT
 public:
   KMyMoneyViewBase(QWidget* parent, const char *name, const QString& title);
-  virtual ~KMyMoneyViewBase() {};
+  virtual ~KMyMoneyViewBase() {}
 
   void setTitle(const QString& title);
   QVBoxLayout* layout(void) const { return m_viewLayout; }
