@@ -88,7 +88,7 @@ public:
   };
 
   KTransactionPtrVector() { m_sortType = SortPostDate; };
-  ~KTransactionPtrVector() {};
+  ~KTransactionPtrVector() {}
 
   /**
     * This method is used to set a different sort type.
@@ -103,7 +103,7 @@ public:
     * @return transactionSortE value of sort order. See
     *         KTransactionPtrVector::TransactionSortE for possible values.
     */
-  const TransactionSortE sortType(void) const { return m_sortType; };
+  TransactionSortE sortType(void) const { return m_sortType; };
 
   /**
     * This method is used to set the account id to have a chance to
@@ -217,6 +217,7 @@ protected:
   void loadPayees(void);
   void selectedPayees(QValueList<MyMoneyPayee>& payeesList) const;
   void ensurePayeeVisible(const QCString& id);
+  void clearItemData(void);
 
 protected slots:
   /**
@@ -237,6 +238,7 @@ protected slots:
     * This slot marks the current selected payee as modified (dirty).
     */
   void slotPayeeDataChanged(void);
+  void slotKeyListChanged(void);
 
   /**
     * This slot is called when the name of a payee is changed inside
