@@ -84,7 +84,7 @@ class KMyMoneyCurrencySelector : public KMyMoneySecuritySelector
 {
 public:
   KMyMoneyCurrencySelector(QWidget *parent=0, const char *name=0);
-  virtual ~KMyMoneyCurrencySelector() {};
+  virtual ~KMyMoneyCurrencySelector() {}
 };
 
 #endif
