@@ -130,6 +130,10 @@ QValidator::State kMyMoneyMoneyValidator::validate( QString & input, int & _p )
       return Invalid;
   }
 
+  // If we have just a single minus sign, we are done
+  if(s == QString("-"))
+    return Acceptable;
+
   QValidator::State rc = QDoubleValidator::validate( s, _p );
 
   if(rc == Acceptable) {
@@ -270,7 +274,7 @@ void kMyMoneyEdit::setPrecision(const int prec)
   }
 }
 
-const bool kMyMoneyEdit::isValid(void) const
+bool kMyMoneyEdit::isValid(void) const
 {
   return !(m_edit->text().isEmpty());
 }
@@ -463,7 +467,7 @@ void kMyMoneyEdit::calculatorOpen(QKeyEvent* k)
   // usually, the calculator widget is shown underneath the MoneyEdit widget
   // if it does not fit on the screen, we show it above this widget
   QPoint p = mapToGlobal(QPoint(0,0));
-  if(p.y() + h > QApplication::desktop()->height())
+  if(p.y() + height() + h > QApplication::desktop()->height())
     p.setY(p.y() - h);
   else
     p.setY(p.y() + height());
