@@ -33,6 +33,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kdebug.h>
+#include <kurldrag.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -42,8 +43,9 @@
 #include <kmymoney/kmymoneycategory.h>
 #include <kmymoney/register.h>
 #include <kmymoney/transactionform.h>
-
-#include "../kmymoneyutils.h"
+#include <kmymoney/stdtransactiondownloaded.h>
+#include <kmymoney/stdtransactionmatched.h>
+#include "scheduledtransaction.h"
 #include "../kmymoneyglobalsettings.h"
 
 const int LinesPerMemo = 3;
@@ -65,7 +67,7 @@ static QString sortOrderText[] = {
 
 using namespace KMyMoneyRegister;
 
-static char fancymarker_bg_image[] = {
+static unsigned char fancymarker_bg_image[] = {
 /* 200x49 */
   0x89,0x50,0x4E,0x47,0x0D,0x0A,0x1A,0x0A,
   0x00,0x00,0x00,0x0D,0x49,0x48,0x44,0x52,
@@ -101,6 +103,25 @@ static char fancymarker_bg_image[] = {
 QPixmap* GroupMarker::m_bg = 0;
 int GroupMarker::m_bgRefCnt = 0;
 
+void ItemPtrVector::sort(void)
+{
+  if(count() > 0) {
+    // get rid of 0 pointers in the list
+    KMyMoneyRegister::ItemPtrVector::iterator it_l;
+    RegisterItem *item;
+    for(it_l = begin(); it_l != end(); ++it_l) {
+      if(*it_l == 0) {
+        item = last();
+        *it_l = item;
+        pop_back();
+        --it_l;
+      }
+    }
+
+    std::sort(begin(), end(), item_cmp);
+  }
+}
+
 bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
 {
   const QValueList<TransactionSortField>& sortOrder = i1->parent()->sortOrder();
@@ -112,9 +133,13 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
   MyMoneyMoney tmp;
 
   for(it = sortOrder.begin(); it != sortOrder.end(); ++it) {
-    switch(static_cast<TransactionSortField>(abs(*it))) {
+    TransactionSortField sortField = static_cast<TransactionSortField>(abs(*it));
+    switch(sortField) {
       case PostDateSort:
         rc = i2->sortPostDate().daysTo(i1->sortPostDate());
+        if(rc == 0) {
+          rc = i1->sortSamePostDate() - i2->sortSamePostDate();
+        }
         break;
 
       case EntryDateSort:
@@ -183,39 +208,21 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
         break;
     }
 
-    if(rc == 0) {
-      if(dynamic_cast<GroupMarker*>(i1) == 0) {
-        // only one item is a non-marker
-        if(dynamic_cast<GroupMarker*>(i2) == 0) {
-          // no, both are non-markers, then just continue with the next criteria
-          continue;
-        }
-        // the marker 'wins'
-        return false;
-      } else if(dynamic_cast<GroupMarker*>(i2) != 0) {
-        // we have two markers to compare
-        bool fm1 = dynamic_cast<FiscalYearGroupMarker*>(i1) != 0;
-        bool fm2 = dynamic_cast<FiscalYearGroupMarker*>(i2) != 0;
-        // if one of them is a fiscal year marker give it precedence
-        if(fm1 || fm2) {
-          if(fm1)
-            return false;
-        }
-      }
-      return true;
-    }
-
-    return (*it < 0) ? rc >= 0 : rc < 0;
+    // the items differ for this sort key so we can return a result
+    if(rc != 0)
+      return (*it < 0) ? rc >= 0 : rc < 0;
   }
 
-  if(rc == 0)
+  if(rc == 0) {
     rc = qstrcmp(i1->sortEntryOrder(), i2->sortEntryOrder());
+  }
 
   return rc < 0;
 }
 
-GroupMarker::GroupMarker(Register *parent) :
+GroupMarker::GroupMarker(Register *parent, const QString& txt) :
   RegisterItem(parent),
+  m_txt(txt),
   m_drawCounter(parent->drawCounter()-1)   // make sure we get painted the first time around
 {
   int h;
@@ -234,10 +241,7 @@ GroupMarker::GroupMarker(Register *parent) :
   // convert the backgroud once
   if(m_bg == 0) {
     m_bg = new QPixmap;
-    QByteArray a;
-    a.setRawData(fancymarker_bg_image, sizeof(fancymarker_bg_image));
-    m_bg->loadFromData(a);
-    a.resetRawData(fancymarker_bg_image, sizeof(fancymarker_bg_image));
+    m_bg->loadFromData(fancymarker_bg_image, sizeof(fancymarker_bg_image));
 
     // for now, we can't simply resize the m_bg member as Qt does not support
     // alpha resizing. So we take the (slow) detour through a QImage object
@@ -334,11 +338,16 @@ int GroupMarker::rowHeightHint(void) const
   return m_bg->height();
 }
 
+StatementGroupMarker::StatementGroupMarker(Register* parent, CashFlowDirection dir, const QDate& date, const QString& txt) :
+  FancyDateGroupMarker(parent, date, txt),
+  m_dir(dir)
+{
+}
+
 FancyDateGroupMarker::FancyDateGroupMarker(Register* parent, const QDate& date, const QString& txt) :
-  GroupMarker(parent)
+  GroupMarker(parent, txt),
+  m_date(date)
 {
-  m_txt = txt;
-  m_date = date;
 }
 
 FiscalYearGroupMarker::FiscalYearGroupMarker(Register* parent, const QDate& date, const QString& txt) :
@@ -424,15 +433,13 @@ TypeGroupMarker::TypeGroupMarker(Register* parent, CashFlowDirection dir, MyMone
 }
 
 PayeeGroupMarker::PayeeGroupMarker(Register* parent, const QString& name) :
-  GroupMarker(parent)
+  GroupMarker(parent, name)
 {
-  m_txt = name;
 }
 
 CategoryGroupMarker::CategoryGroupMarker(Register* parent, const QString& category) :
-  GroupMarker(parent)
+  GroupMarker(parent, category)
 {
-  m_txt = category;
 }
 
 ReconcileGroupMarker::ReconcileGroupMarker(Register* parent, MyMoneySplit::reconcileFlagE state) :
@@ -463,6 +470,8 @@ class RegisterToolTip : public QToolTip
 public:
   RegisterToolTip(QWidget* parent, Register* reg);
   void maybeTip(const QPoint& pos);
+  virtual ~RegisterToolTip() {}
+
 private:
   Register* m_register;
 };
@@ -538,7 +547,7 @@ Register::Register(QWidget *parent, const char *name ) :
   horizontalHeader()->setLabel(ReconcileFlagColumn, i18n("C"));
   horizontalHeader()->setLabel(PaymentColumn, i18n("Payment"));
   horizontalHeader()->setLabel(DepositColumn, i18n("Deposit"));
-  horizontalHeader()->setLabel(AmountColumn, i18n("Amount"));
+  horizontalHeader()->setLabel(QuantityColumn, i18n("Quantity"));
   horizontalHeader()->setLabel(PriceColumn, i18n("Price"));
   horizontalHeader()->setLabel(ValueColumn, i18n("Value"));
   horizontalHeader()->setLabel(BalanceColumn, i18n("Balance"));
@@ -563,8 +572,53 @@ Register::Register(QWidget *parent, const char *name ) :
 
   // double clicking the header turns on auto column sizing
   connect(horizontalHeader(), SIGNAL(sectionSizeChanged(int)), this, SLOT(slotAutoColumnSizing(int)));
+
+  //DND
+  setAcceptDrops(true);
 }
 
+// DND
+Transaction* Register::dropTransaction(QPoint cPos) const
+{
+  Transaction* t = 0;
+  cPos -= QPoint( verticalHeader()->width(), horizontalHeader()->height() );
+  if(cPos.y() >= 0) {
+    cPos += QPoint(contentsX(), contentsY());
+    int row = rowAt(cPos.y());
+    int col = columnAt(cPos.x());
+    t = dynamic_cast<Transaction*>(itemAtRow(row));
+  }
+}
+
+void Register::dragMoveEvent(QDragMoveEvent* event)
+{
+  if ( KURLDrag::canDecode(event) ) {
+    event->ignore();
+    Transaction* t = dropTransaction(event->pos());
+    if(t && !t->isScheduled()) {
+      event->accept();
+    }
+  }
+}
+
+void Register::dropEvent(QDropEvent* event)
+{
+  qDebug("Register::dropEvent");
+  if ( KURLDrag::canDecode(event) ) {
+    event->ignore();
+    Transaction* t = dropTransaction(event->pos());
+    if(t && !t->isScheduled()) {
+      qDebug("Drop was ok");
+      KURL::List urls;
+      KURLDrag::decode(event, urls);
+      qDebug("List is '%s'", urls.toStringList().join(";").data());
+      event->accept();
+    }
+  }
+}
+// DND end
+
+
 Register::~Register()
 {
   clear();
@@ -725,7 +779,7 @@ void Register::setupRegister(const MyMoneyAccount& account, bool showAccountColu
 
     case MyMoneyAccount::Investment:
       showColumn(SecurityColumn);
-      showColumn(AmountColumn);
+      showColumn(QuantityColumn);
       showColumn(PriceColumn);
       showColumn(ValueColumn);
       break;
@@ -758,10 +812,6 @@ void Register::setupRegister(const MyMoneyAccount& account, bool showAccountColu
   }
 
   switch(account.accountType()) {
-    case MyMoneyAccount::Investment:
-      m_lastCol = ValueColumn;
-      break;
-
     default:
       m_lastCol = BalanceColumn;
       break;
@@ -1427,12 +1477,15 @@ int Register::rowToIndex(int row) const
   return -1;
 }
 
-void Register::selectedTransactions(QValueList<SelectedTransaction>& list) const
+void Register::selectedTransactions(SelectedTransactions& list) const
 {
   if(m_focusItem && m_focusItem->isSelected() && m_focusItem->isVisible()) {
     Transaction* t = dynamic_cast<Transaction*>(m_focusItem);
     if(t) {
-      SelectedTransaction s(t->transaction(), t->split());
+      QCString id;
+      if(t->isScheduled())
+        id = t->transaction().id();
+      SelectedTransaction s(t->transaction(), t->split(), id);
       list << s;
     }
   }
@@ -1445,7 +1498,10 @@ void Register::selectedTransactions(QValueList<SelectedTransaction>& list) const
     if(item && item->isSelected() && item->isVisible()) {
       Transaction* t = dynamic_cast<Transaction*>(item);
       if(t) {
-        SelectedTransaction s(t->transaction(), t->split());
+        QCString id;
+        if(t->isScheduled())
+          id = t->transaction().id();
+        SelectedTransaction s(t->transaction(), t->split(), id);
         list << s;
       }
     }
@@ -1513,7 +1569,7 @@ void Register::selectItem(int row, int col, int button, const QPoint& /* mousePo
             break;
 
           case Qt::LeftButton:
-            if(t && col == ReconcileFlagColumn && selectedItemsCount() == 1)
+            if(t && col == ReconcileFlagColumn && selectedItemsCount() == 1 && !t->isScheduled())
               emit reconcileStateColumnClicked(t);
             break;
 
@@ -1527,9 +1583,14 @@ void Register::selectItem(int row, int col, int button, const QPoint& /* mousePo
   }
 }
 
-void Register::setFocusItem(RegisterItem* focusItem)
+void Register::setAnchorItem(RegisterItem* anchorItem)
 {
-  if(focusItem->canHaveFocus()) {
+  m_selectAnchor = anchorItem;
+}
+
+bool Register::setFocusItem(RegisterItem* focusItem)
+{
+  if(focusItem && focusItem->canHaveFocus()) {
     if(m_focusItem) {
       m_focusItem->setFocus(false);
       // issue a repaint here only if we move the focus
@@ -1547,7 +1608,20 @@ void Register::setFocusItem(RegisterItem* focusItem)
       updateRegister(KMyMoneyGlobalSettings::ledgerLens() | !KMyMoneyGlobalSettings::transactionForm());
     ensureItemVisible(m_focusItem);
     repaintItems(m_focusItem);
+    return true;
+  } else
+    return false;
+}
+
+bool Register::setFocusToTop(void)
+{
+  RegisterItem* rgItem=m_firstItem;
+  while (rgItem) {
+    if (setFocusItem(rgItem))
+      return true;
+    rgItem=rgItem->nextItem();
   }
+  return false;
 }
 
 void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
@@ -1565,8 +1639,15 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
 
   if(item->isSelectable()) {
     QCString id = item->id();
+    QValueList<RegisterItem*> itemList = selectedItems();
     bool okToSelect = true;
-    int cnt = selectedItemsCount();
+    int cnt = itemList.count();
+    bool sameEntryType = true;
+    if(cnt > 0) {
+      if(typeid(*itemList.begin()) != typeid(item))
+        sameEntryType = false;
+    }
+
     if(buttonState & Qt::LeftButton) {
       if(!(buttonState & (Qt::ShiftButton | Qt::ControlButton))) {
         if((cnt != 1) || ((cnt == 1) && !item->isSelected())) {
@@ -1586,6 +1667,9 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
       if(m_selectionMode == Multi) {
         switch(buttonState & (Qt::ShiftButton | Qt::ControlButton)) {
           case Qt::ControlButton:
+            okToSelect = sameEntryType;
+            if(typeid(*item) == typeid(StdTransactionScheduled))
+              okToSelect = false;
             // toggle selection state of current item
             emit aboutToSelectItem(item, okToSelect);
             if(okToSelect) {
@@ -1597,6 +1681,9 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
             break;
 
           case Qt::ShiftButton:
+            okToSelect = sameEntryType;
+            if(typeid(*item) == typeid(StdTransactionScheduled))
+              okToSelect = false;
             emit aboutToSelectItem(item, okToSelect);
             if(okToSelect) {
               // pointer 'item' might have changed. reconstruct it.
@@ -1617,6 +1704,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
       // b) multiple transactions are selected and the one to be selected is not
       if(!(buttonState & (Qt::ShiftButton | Qt::ControlButton))) {
         if((cnt > 0) && (!item->isSelected())) {
+          okToSelect = sameEntryType;
           emit aboutToSelectItem(item, okToSelect);
           if(okToSelect) {
             // pointer 'item' might have changed. reconstruct it.
@@ -1643,8 +1731,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
       }
     }
     if(okToSelect) {
-      QValueList<SelectedTransaction> list;
-      selectedTransactions(list);
+      SelectedTransactions list(this);
       emit selectionChanged(list);
     }
   }
@@ -1739,7 +1826,7 @@ void Register::slotEnsureItemVisible(void)
 TransactionSortField KMyMoneyRegister::textToSortOrder(const QString& text)
 {
   for(int idx = 1; idx < static_cast<int>(MaxSortFields); ++idx) {
-    if(text == sortOrderText[idx]) {
+    if(text == i18n(sortOrderText[idx])) {
       return static_cast<TransactionSortField>(idx);
     }
   }
@@ -1893,16 +1980,97 @@ RegisterItem* Register::itemById(const QCString& id) const
   return 0;
 }
 
-RegisterItem* Register::scrollPage(int key)
+void Register::handleItemChange(RegisterItem* old, bool shift, bool control)
 {
+  if(m_selectionMode == Multi) {
+    if(shift) {
+      selectRange(m_selectAnchor ? m_selectAnchor : old,
+                  m_focusItem, false, true, (m_selectAnchor && !control) ? true : false);
+    } else if(!control) {
+      selectItem(m_focusItem, false);
+    }
+  }
+}
+
+void Register::selectRange(RegisterItem* from, RegisterItem* to, bool invert, bool includeFirst, bool clearSel)
+{
+  if(!from || !to)
+    return;
+  if(from == to && !includeFirst)
+    return;
+  bool swap = false;
+  if(to == from->prevItem())
+    swap = true;
+
+  RegisterItem* item;
+  if(!swap && from != to && from != to->prevItem()) {
+    bool found = false;
+    for(item = from; item; item = item->nextItem()) {
+      if(item == to) {
+        found = true;
+        break;
+      }
+    }
+    if(!found)
+      swap = true;
+  }
+
+  if(swap) {
+    item = from;
+    from = to;
+    to = item;
+    if(!includeFirst)
+      to = to->prevItem();
+
+  } else if(!includeFirst) {
+    from = from->nextItem();
+  }
+
+  bool changed = false;
+  if(clearSel) {
+    for(item = firstItem(); item; item = item->nextItem()) {
+      if(item->isSelected() && item->isVisible()) {
+        item->setSelected(false);
+        changed = true;
+      }
+    }
+  }
+
+  for(item = from; item; item = item->nextItem()) {
+    if(item->isSelectable()) {
+      if(!invert) {
+        if(!item->isSelected() && item->isVisible()) {
+          item->setSelected(true);
+          changed = true;
+        }
+      } else {
+        bool sel = !item->isSelected();
+        if((item->isSelected() != sel) && (sel || !sel)) {
+          if(item->isVisible()) {
+            item->setSelected(sel);
+            changed = true;
+          }
+        }
+      }
+    }
+    if(item == to)
+      break;
+  }
+}
+
+void Register::scrollPage(int key, ButtonState state)
+{
+  RegisterItem* oldFocusItem = m_focusItem;
+
   // make sure we have a focus item
   if(!m_focusItem)
     setFocusItem(m_firstItem);
+  if(!m_focusItem && m_firstItem)
+    setFocusItem(m_firstItem->nextItem());
   if(!m_focusItem)
-    return 0;
+    return;
 
   RegisterItem* item = m_focusItem;
-  RegisterItem* newItem = item;
   int height = 0;
 
   switch(key) {
@@ -1913,8 +2081,6 @@ RegisterItem* Register::scrollPage(int key)
           if(item->isVisible())
             height += item->rowHeightHint();
         } while((!item->isSelectable() || !item->isVisible()) && item->prevItem());
-        if(item)
-          newItem = item;
       }
       break;
     case Qt::Key_PageDown:
@@ -1924,8 +2090,6 @@ RegisterItem* Register::scrollPage(int key)
             height += item->rowHeightHint();
           item = item->nextItem();
         } while((!item->isSelectable() || !item->isVisible()) && item->nextItem());
-        if(item)
-          newItem = item;
       }
       break;
 
@@ -1934,8 +2098,6 @@ RegisterItem* Register::scrollPage(int key)
         do {
           item = item->prevItem();
         } while((!item->isSelectable() || !item->isVisible()) && item->prevItem());
-        if(item)
-          newItem = item;
       }
       break;
 
@@ -1944,8 +2106,6 @@ RegisterItem* Register::scrollPage(int key)
         do {
           item = item->nextItem();
         } while((!item->isSelectable() || !item->isVisible()) && item->nextItem());
-        if(item)
-          newItem = item;
       }
       break;
 
@@ -1953,26 +2113,35 @@ RegisterItem* Register::scrollPage(int key)
       item = m_firstItem;
       while((!item->isSelectable() || !item->isVisible()) && item->nextItem())
         item = item->nextItem();
-      if(item)
-        newItem = item;
       break;
 
     case Qt::Key_End:
       item = m_lastItem;
       while((!item->isSelectable() || !item->isVisible()) && item->prevItem())
         item = item->prevItem();
-      if(item)
-        newItem = item;
       break;
   }
 
   // make sure to avoid selecting a possible empty transaction at the end
-  Transaction* t = dynamic_cast<Transaction*>(newItem);
+  Transaction* t = dynamic_cast<Transaction*>(item);
   if(t && t->transaction().id().isEmpty()) {
-    if(t->prevItem())
-      newItem = t->prevItem();
+    if(t->prevItem()) {
+      item = t->prevItem();
+    }
   }
-  return newItem;
+
+  if(!(state & ShiftButton) || !m_selectAnchor)
+    m_selectAnchor = item;
+
+  setFocusItem(item);
+
+  if(item->isSelectable()) {
+    handleItemChange(oldFocusItem, state & Qt::ShiftButton, state & Qt::ControlButton);
+  }
+
+  if(m_focusItem && !m_focusItem->isSelected() && m_selectionMode == Single)
+    selectItem(item);
+
 }
 
 void Register::keyPressEvent(QKeyEvent* ev)
@@ -1994,10 +2163,7 @@ void Register::keyPressEvent(QKeyEvent* ev)
     case Qt::Key_End:
     case Qt::Key_Down:
     case Qt::Key_Up:
-      setFocusItem(scrollPage(ev->key()));
-      ensureItemVisible(m_focusItem);
-      if(m_selectionMode == Single)
-        selectItem(m_focusItem);
+      scrollPage(ev->key(), ev->state());
       break;
 
     default:
@@ -2028,9 +2194,15 @@ Transaction* Register::transactionFactory(Register *parent, const MyMoneyTransac
     case MyMoneyAccount::Income:
     case MyMoneyAccount::Expense:
     case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Equity:
       if(s.accountId().isEmpty())
         s.setAccountId(parent->account().id());
-      t = new KMyMoneyRegister::StdTransaction(parent, transaction, s, uniqueId);
+      if(transaction.isImported())
+        t = new KMyMoneyRegister::StdTransactionDownloaded(parent, transaction, s, uniqueId);
+      else if(s.isMatched())
+        t = new KMyMoneyRegister::StdTransactionMatched(parent, transaction, s, uniqueId);
+      else
+        t = new KMyMoneyRegister::StdTransaction(parent, transaction, s, uniqueId);
       break;
 
     case MyMoneyAccount::Investment:
@@ -2040,7 +2212,6 @@ Transaction* Register::transactionFactory(Register *parent, const MyMoneyTransac
     case MyMoneyAccount::CertificateDep:
     case MyMoneyAccount::MoneyMarket:
     case MyMoneyAccount::Stock:
-    case MyMoneyAccount::Equity:
     default:
       qDebug("Register::transactionFactory: invalid accountTypeE %d", parent->account().accountType());
       break;
@@ -2082,7 +2253,14 @@ void Register::addGroupMarkers(void)
 
       if(KMyMoneyGlobalSettings::showFancyMarker()) {
         if(m_account.lastReconciliationDate().isValid())
-          new KMyMoneyRegister::FancyDateGroupMarker(this, m_account.lastReconciliationDate(), i18n("Last reconciliation"));
+          new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, m_account.lastReconciliationDate(), i18n("Last reconciliation"));
+
+        if(!m_account.value("lastImportedTransactionDate").isEmpty()
+        && !m_account.value("lastStatementBalance").isEmpty()) {
+          MyMoneyMoney balance(m_account.value("lastStatementBalance"));
+          QString txt = i18n("Online Statement Balance: %1").arg(balance.formatMoney(m_account.fraction()));
+          new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, QDate::fromString(m_account.value("lastImportedTransactionDate"), Qt::ISODate), txt);
+        }
 
         new KMyMoneyRegister::FancyDateGroupMarker(this, thisYear, i18n("This year"));
         new KMyMoneyRegister::FancyDateGroupMarker(this, lastMonth, i18n("Last month"));
@@ -2092,6 +2270,9 @@ void Register::addGroupMarkers(void)
         new KMyMoneyRegister::FancyDateGroupMarker(this, yesterday, i18n("Yesterday"));
         new KMyMoneyRegister::FancyDateGroupMarker(this, today, i18n("Today"));
         new KMyMoneyRegister::FancyDateGroupMarker(this, today.addDays(1), i18n("Future transactions"));
+        new KMyMoneyRegister::FancyDateGroupMarker(this, thisWeek.addDays(7), i18n("Next week"));
+        new KMyMoneyRegister::FancyDateGroupMarker(this, thisMonth.addMonths(1), i18n("Next month"));
+
       } else {
         new KMyMoneyRegister::SimpleDateGroupMarker(this, today.addDays(1), i18n("Future transactions"));
       }
@@ -2103,6 +2284,7 @@ void Register::addGroupMarkers(void)
         QDate previousFiscalYear = currentFiscalYear.addYears(-1);
         new KMyMoneyRegister::FiscalYearGroupMarker(this, currentFiscalYear, i18n("Current fiscal year"));
         new KMyMoneyRegister::FiscalYearGroupMarker(this, currentFiscalYear.addYears(-1), i18n("Previous fiscal year"));
+        new KMyMoneyRegister::FiscalYearGroupMarker(this, currentFiscalYear.addYears(1), i18n("Next fiscal year"));
       }
       break;
 
@@ -2186,14 +2368,15 @@ void Register::addGroupMarkers(void)
 
 void Register::removeUnwantedGroupMarkers(void)
 {
-  // remove all trailing group markers
+  // remove all trailing group markers except statement markers
   KMyMoneyRegister::RegisterItem* q;
   KMyMoneyRegister::RegisterItem* p = lastItem();
   while(p) {
     q = p;
-    KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
-    if(t)
+    if(dynamic_cast<KMyMoneyRegister::Transaction*>(p)
+    || dynamic_cast<KMyMoneyRegister::StatementGroupMarker*>(p))
       break;
+
     p = p->prevItem();
     delete q;
   }
@@ -2207,7 +2390,8 @@ void Register::removeUnwantedGroupMarkers(void)
     p = p->prevItem();
     if(m) {
       m->markVisible(true);
-      if(lastWasGroupMarker) {
+      // make adjacent group marker invisible except those that show statement information
+      if(lastWasGroupMarker && (dynamic_cast<KMyMoneyRegister::StatementGroupMarker*>(m) == 0)) {
         m->markVisible(false);
       }
       lastWasGroupMarker = true;
