@@ -18,6 +18,11 @@
 #ifndef REGISTER_H
 #define REGISTER_H
 
+// Some STL headers in GCC4.3 contain operator new. Memory checker mangles these
+#ifdef _CHECK_MEMORY
+  #undef new
+#endif
+
 #include <algorithm>
 
 // ----------------------------------------------------------------------------
@@ -36,6 +41,9 @@
 
 // ----------------------------------------------------------------------------
 // Project Includes
+#ifdef _CHECK_MEMORY
+  #include <kmymoney/mymoneyutils.h>
+#endif
 
 #include <kmymoney/mymoneyaccount.h>
 #include <kmymoney/registeritem.h>
@@ -80,7 +88,7 @@ TransactionSortField textToSortOrder(const QString& text);
 class QWidgetContainer : public QMap<QString, QWidget*>
 {
 public:
-  QWidgetContainer() {};
+  QWidgetContainer() {}
 
   QWidget* haveWidget(const QString& name) const {
     QWidgetContainer::const_iterator it_w;
@@ -108,8 +116,10 @@ public:
 class GroupMarker : public RegisterItem
 {
 public:
-  GroupMarker(Register* parent);
+  GroupMarker(Register* parent, const QString& txt = QString());
   ~GroupMarker();
+  void setText(const QString& txt) { m_txt = txt; }
+  const QString& text(void) const { return m_txt; }
   bool isSelectable(void) const { return false; }
   bool canHaveFocus(void) const { return false; }
   int numRows(void) const { return 1; }
@@ -124,6 +134,7 @@ public:
   int rowHeightHint(void) const;
 
   bool matches(const QString&) const { return true; }
+  virtual int sortSamePostDate(void) const { return 0; }
 
 protected:
   void setupColors(QColorGroup& cg);
@@ -149,6 +160,16 @@ private:
   QDate                    m_date;
 };
 
+class StatementGroupMarker : public FancyDateGroupMarker
+{
+public:
+  StatementGroupMarker(Register* parent, CashFlowDirection dir, const QDate& date, const QString& txt );
+  CashFlowDirection sortType(void) const { return m_dir; }
+  virtual int sortSamePostDate(void) const { return 4; }
+private:
+  CashFlowDirection        m_dir;
+};
+
 class SimpleDateGroupMarker : public FancyDateGroupMarker
 {
 public:
@@ -172,6 +193,7 @@ class FiscalYearGroupMarker : public FancyDateGroupMarker
 public:
   FiscalYearGroupMarker(Register* parent, const QDate& date, const QString& txt);
   virtual const char* className(void) { return "FiscalYearGroupMarker"; }
+  virtual int sortSamePostDate(void) const { return 1; }
 
 protected:
   void setupColors(QColorGroup& cg);
@@ -209,7 +231,7 @@ class ItemPtrVector : public QValueVector<RegisterItem *>
 public:
   ItemPtrVector() {}
 
-  void sort(void) { std::sort(begin(), end(), item_cmp); }
+  void sort(void);
 
 protected:
   /**
@@ -264,7 +286,7 @@ public:
     *
     * @param list reference to QValueList receiving the SelectedTransaction()'s
     */
-  void selectedTransactions(QValueList<SelectedTransaction>& list) const;
+  void selectedTransactions(SelectedTransactions&  list) const;
 
   QString text(int row, int col) const;
   QWidget* createEditor(int row, int col, bool initFromCell) const;
@@ -273,7 +295,7 @@ public:
   void endEdit(int row, int col, bool accept, bool replace);
   void paintCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg);
 
-  void resizeData(int) {};
+  void resizeData(int) {}
   QTableItem* item(int, int) { return 0; }
   void setItem(int, int, QTableItem*) {}
   void clearCell(int, int) {}
@@ -290,7 +312,21 @@ public:
   void updateCell(int /* row */, int /* col */) {}
 
   RegisterItem* focusItem(void) const { return m_focusItem; }
-  void setFocusItem(RegisterItem* focusItem);
+  RegisterItem* anchorItem(void) const { return m_selectAnchor; }
+
+  /**
+    * set focus to specific item.
+    * @return true if the item got focus
+    */
+  bool setFocusItem(RegisterItem* focusItem);
+
+  void setAnchorItem(RegisterItem* anchorItem);
+
+  /**
+    * Set focus to the first focussable item
+    * @return true if a focussable item was found
+    */
+  bool setFocusToTop(void);
 
   /**
     * Select @a item and unselect all others if @a dontChangeSelections
@@ -416,9 +452,11 @@ public:
   void setSelectionMode(SelectionMode mode) { m_selectionMode = mode; }
 
 protected:
+
   void drawContents(QPainter *p, int cx, int cy, int cw, int ch);
 
   void contentsMouseReleaseEvent( QMouseEvent *e );
+
   void unselectItems(int from = -1, int to = -1) { doSelectItems(from, to, false); }
   void selectItems(int from, int to) { doSelectItems(from, to, true); }
   void doSelectItems(int from, int to, bool selected);
@@ -437,10 +475,10 @@ protected:
     * The height to scroll is determined by visibleHeight()
     *
     * @param key Qt::Page_Up or Qt::Page_Down depending on the direction to scroll
-    *
-    * @return pointer to selectable register item
+    * @param state state of Qt::ShiftButton, Qt::ControlButton, Qt::AltButton and
+    *              Qt::MetaButton.
     */
-  RegisterItem* scrollPage(int key);
+  void scrollPage(int key, ButtonState state);
 
   /**
     * This method determines the pointer to a RegisterItem
@@ -461,6 +499,15 @@ protected:
 
   bool eventFilter(QObject* o, QEvent* e);
 
+  void handleItemChange(RegisterItem* old, bool shift, bool control);
+
+  void selectRange(RegisterItem* from, RegisterItem* to, bool invert, bool includeFirst, bool clearSel);
+
+  // DND
+  void dragMoveEvent(QDragMoveEvent* event);
+  void dropEvent(QDropEvent* event);
+  Transaction* dropTransaction(QPoint cPos) const;
+
 protected slots:
   void resize(void);
 
@@ -473,7 +520,7 @@ protected slots:
 
 signals:
   void selectionChanged(void);
-  void selectionChanged(const QValueList<KMyMoneyRegister::SelectedTransaction>& list);
+  void selectionChanged(const KMyMoneyRegister::SelectedTransactions& list);
   /**
     * This signal is emitted when the focus and selection changes to @p item.
     *
