@@ -82,9 +82,12 @@ $country{"nl"} = "Netherlands";
 $country{"pl"} = "Poland";
 $country{"pt_BR"} = "Brazil";
 $country{"pt"} = "Portugal";
+$country{"ro"} = "Romania";
 $country{"ru"} = "Russia";
 $country{"sk"} = "Slovakia";
 $country{"sl"} = "Slovenia";
+$country{"sv"} = "Sweden";
+$country{"tr"} = "Turkey";
 $country{"zh_CN"} = "China";
 
 $language{"ca"} = "Catalan";
@@ -102,14 +105,18 @@ $language{"nl"} = "Dutch";
 $language{"pl"} = "Polish";
 $language{"pt_BR"} = "Portuguese (Brazil)";
 $language{"pt"} = "Portuguese (Portugal)";
+$language{"ro"} = "Romanian";
 $language{"ru"} = "Russian";
 $language{"sk"} = "Slovak";
 $language{"sl"} = "Slovenian";
+$language{"sv"} = "Swedish";
+$language{"tr"} = "Turkish";
 $language{"zh_CN"} = "Simplified Chinese";
 
 $flags{"es_AR"} = "ar";
 $flags{"en_GB"} = "gb";
 $flags{"pt_BR"} = "br";
+$flags{"pt"} = "pt";
 $flags{"da"} = "dk";
 $flags{"gl"} = "Galicia";
 $flags{"zh_CN"} = "cn";
